@@ -42,6 +42,7 @@
 #include "messages.h"
 #include "misc.h"
 #include "sanitize.h"
+#include "sort.h" /* num_to_sort_name() */
 #include "spawn.h"
 
 /* Get the executable's path of the action ACTION
@@ -81,7 +82,8 @@ get_plugin_path(char *action, int *status)
 
 	/* Not in local dir. Let's check the system data dir as well */
 	if (data_dir && dir_path == 0) {
-		cmd_len = action_len + strlen(data_dir)	+ strlen(PROGRAM_NAME) + 11;
+		cmd_len = action_len + strlen(data_dir)
+			+ (sizeof(PROGRAM_NAME) - 1) + 11;
 		cmd = xnrealloc(cmd, cmd_len, sizeof(char));
 		snprintf(cmd, cmd_len, "%s/%s/plugins/%s", data_dir,
 			PROGRAM_NAME, action);
@@ -95,12 +97,78 @@ get_plugin_path(char *action, int *status)
 	return (char *)NULL;
 }
 
+static void
+export_status_values(void)
+{
+	if (cur_cscheme && *cur_cscheme)
+		setenv("CLIFM_COLOR_SCHEME", cur_cscheme, 1);
+	if (conf.colorize != 1)
+		setenv("CLIFM_COLORLESS", "1", 1);
+	setenv("CLIFM_CUR_WS", xitoa(cur_ws + 1), 1);
+	setenv("CLIFM_DIRS_FIRST", conf.list_dirs_first == 1 ? "1" : "0", 1);
+	setenv("CLIFM_FILES_COUNTER", conf.files_counter == 1 ? "1" : "0", 1);
+	if (filter.str && *filter.str) {
+		setenv("CLIFM_FILES_FILTER", filter.str, 1);
+		setenv("CLIFM_FILTER_REVERSE", filter.rev == 1 ? "1" : "0", 1);
+	}
+	setenv("CLIFM_FOLLOW_LINKS", conf.follow_symlinks == 1 ? "1" : "0", 1);
+	setenv("CLIFM_LIGHT_MODE", conf.light_mode == 1 ? "1" : "0", 1);
+	setenv("CLIFM_LONG_VIEW", conf.long_view == 1 ? "1" : "0", 1);
+	if (conf.max_files >= 0)
+		setenv("CLIFM_MAX_FILES", xitoa(conf.max_files), 1);
+	setenv("CLIFM_ONLY_DIRS", conf.only_dirs == 1 ? "1" : "0", 1);
+	if (plugins_helper_file && *plugins_helper_file)
+		setenv("CLIFM_PLUGINS_HELPER", plugins_helper_file, 1);
+	setenv("CLIFM_PROFILE", alt_profile ? alt_profile : "default", 1);
+	if (sel_file && *sel_file)
+		setenv("CLIFM_SELFILE", sel_file, 1);
+	if (sel_n > 0)
+		setenv("CLIFM_SEL_FILES", xitoa((long long)sel_n), 1);
+	setenv("CLIFM_SHOW_HIDDEN", conf.show_hidden == 1 ? "1" : "0", 1);
+	setenv("CLIFM_SORT_REVERSE", conf.sort_reverse == 1 ? "1" : "0", 1);
+	setenv("CLIFM_SORT_STYLE", num_to_sort_name(conf.sort), 1);
+	if (trash_n > 0)
+		setenv("CLIFM_TRASH_FILES", xitoa((long long)trash_n), 1);
+	setenv("CLIFM_TRIM_NAMES", conf.trim_names == 1 ? "1" : "0", 1);
+}
+
+static void
+unset_export_values(void) {
+	unsetenv("CLIFM_COLOR_SCHEME");
+	unsetenv("CLIFM_COLORLESS");
+	unsetenv("CLIFM_CUR_WS");
+	unsetenv("CLIFM_DIRS_FIRST");
+	unsetenv("CLIFM_FILES_COUNTER");
+	unsetenv("CLIFM_FILES_FILTER");
+	unsetenv("CLIFM_FILTER_REVERSE");
+	unsetenv("CLIFM_FOLLOW_LINKS");
+	unsetenv("CLIFM_LIGHT_MODE");
+	unsetenv("CLIFM_LONG_VIEW");
+	unsetenv("CLIFM_MAX_FILES");
+	unsetenv("CLIFM_ONLY_DIRS");
+	unsetenv("CLIFM_PLUGINS_HELPER");
+	unsetenv("CLIFM_PROFILE");
+	unsetenv("CLIFM_SEL_FILES");
+	unsetenv("CLIFM_SELFILE");
+	unsetenv("CLIFM_SHOW_HIDDEN");
+	unsetenv("CLIFM_SORT_REVERSE");
+	unsetenv("CLIFM_SORT_STYLE");
+	unsetenv("CLIFM_TRASH_FILES");
+	unsetenv("CLIFM_TRIM_NAMES");
+}
+
 int
 run_action(char *action, char **args)
 {
 	if (!action || !*action)
 		return FUNC_FAILURE;
 
+	if (xargs.secure_cmds == 1) {
+		fprintf(stderr, _("%s: Plugins are not allowed in "
+			"secure-cmds mode\n"), PROGRAM_NAME);
+		return FUNC_FAILURE;
+	}
+
 		/* #####################################
 		 * #    1) CREATE CMD TO BE EXECUTED   #
 		 * ##################################### */
@@ -151,7 +219,9 @@ run_action(char *action, char **args)
 		return errno;
 	}
 
+	export_status_values();
 	setenv("CLIFM_BUS", fifo_path, 1);
+
 	if (xargs.cwd_in_title == 1)
 		set_term_title(action);
 
@@ -239,13 +309,13 @@ run_action(char *action, char **args)
 		if (_cmd) {
 			char **alias_cmd = check_for_alias(_cmd);
 			if (alias_cmd) {
-				exit_status = exec_cmd(alias_cmd);
+				exit_status = exec_cmd_tm(alias_cmd);
 				for (i = 0; alias_cmd[i]; i++)
 					free(alias_cmd[i]);
 				free(alias_cmd);
 			} else {
 				if (!(flags & FAILED_ALIAS))
-					exit_status = exec_cmd(_cmd);
+					exit_status = exec_cmd_tm(_cmd);
 				flags &= ~FAILED_ALIAS;
 				for (i = 0; i <= args_n; i++)
 					free(_cmd[i]);
@@ -263,6 +333,7 @@ END:
 		set_term_title(workspaces[cur_ws].path);
 
 	unsetenv("CLIFM_BUS");
+	unset_export_values();
 	return exit_status;
 }
 
@@ -287,17 +358,7 @@ edit_actions(char *app)
 
 	const time_t mtime_bfr = attr.st_mtime;
 
-	int ret = FUNC_SUCCESS;
-
-	if (app && *app) {
-		char *cmd[] = {app, actions_file, NULL};
-		ret = launch_execv(cmd, FOREGROUND, E_NOSTDERR);
-	} else {
-		open_in_foreground = 1;
-		ret = open_file(actions_file);
-		open_in_foreground = 0;
-	}
-
+	const int ret = open_config_file(app, actions_file);
 	if (ret != FUNC_SUCCESS)
 		return ret;
 
