@@ -417,7 +417,7 @@ try_standard_data_dirs(void)
 	struct stat a;
 
 	for (i = 0; data_dirs[i]; i++) {
-		char tmp[PATH_MAX + 5 + 10];
+		char tmp[PATH_MAX + 5 + ((sizeof(PROGRAM_NAME) - 1) * 2)];
 		snprintf(tmp, sizeof(tmp), "%s/%s/%src", data_dirs[i],
 			PROGRAM_NAME, PROGRAM_NAME);
 
@@ -658,7 +658,7 @@ set_sort_by_name(const char *name)
 	fprintf(stderr, _("%s: --sort: '%s': Invalid value\n"
 		"Valid values: atime, btime, ctime, mtime, extension, group, "
 		"inode, name,\n              none, owner, size, version, "
-		"blocks, links.\n"), PROGRAM_NAME, name);
+		"blocks, links, type.\n"), PROGRAM_NAME, name);
 	exit(EXIT_FAILURE);
 }
 
@@ -813,7 +813,7 @@ set_bell_style(const char *opt)
 		exit(EXIT_FAILURE);
 	}
 
-	xargs.bell_style = a;
+	xargs.bell_style = conf.bell_style = a;
 }
 
 static void
@@ -971,25 +971,25 @@ set_alt_config_file(char *file)
 static char *
 resolve_path(char *file)
 {
-	char *_path = (char *)NULL;
+	char *s_path = (char *)NULL;
 
 	if (*file == '.') {
-		_path = normalize_path(file, strlen(file));
-		if (!_path) {
+		s_path = normalize_path(file, strlen(file));
+		if (!s_path) {
 			fprintf(stderr, "%s: '%s': %s\n", PROGRAM_NAME, file, strerror(errno));
 			exit(errno);
 		}
 
 	} else if (*file == '~') {
-		_path = tilde_expand(file);
-		if (!_path) {
+		s_path = tilde_expand(file);
+		if (!s_path) {
 			fprintf(stderr, _("%s: '%s': Error expanding tilde\n"),
 				PROGRAM_NAME, file);
 			exit(EXIT_FAILURE);
 		}
 
 	} else if (*file == '/') {
-		_path = savestring(file, strlen(file));
+		s_path = savestring(file, strlen(file));
 
 	} else {
 		char tmp[PATH_MAX + 1] = "";
@@ -1001,61 +1001,61 @@ resolve_path(char *file)
 		}
 
 		const size_t len = strlen(cwd) + strlen(file) + 2;
-		_path = xnmalloc(len, sizeof(char));
-		snprintf(_path, len, "%s/%s", cwd, file);
+		s_path = xnmalloc(len, sizeof(char));
+		snprintf(s_path, len, "%s/%s", cwd, file);
 	}
 
-	return _path;
+	return s_path;
 }
 
 static char *
 resolve_starting_path(char *file)
 {
-	char *_path = (char *)NULL;
+	char *s_path = (char *)NULL;
 
 	if (IS_FILE_URI(file)) {
-		_path = savestring(file + 7, strlen(file + 7));
+		s_path = savestring(file + 7, strlen(file + 7));
 	} else if (is_url(file) == FUNC_SUCCESS) {
 		open_reg_exit(file, 1, 0); /* noreturn */
 	} else {
-		_path = resolve_path(file);
+		s_path = resolve_path(file);
 	}
 
 	struct stat a;
-	if (stat(_path, &a) == -1) {
+	if (stat(s_path, &a) == -1) {
 		fprintf(stderr, "%s: '%s': %s\n", PROGRAM_NAME, file, strerror(errno));
-		free(_path);
+		free(s_path);
 		exit(errno);
 	}
 
 	if (!S_ISDIR(a.st_mode)) {
 		fprintf(stderr, "%s: '%s': %s\n", PROGRAM_NAME, file, strerror(ENOTDIR));
-		free(_path);
+		free(s_path);
 		exit(ENOTDIR);
 	}
 
 	xargs.path = 1;
-	return _path;
+	return s_path;
 }
 
 static void
-set_starting_path(char *_path)
+set_starting_path(char *s_path)
 {
-	if (xchdir(_path, SET_TITLE) == 0) {
+	if (xchdir(s_path, SET_TITLE) == 0) {
 		if (cur_ws == UNSET)
 			cur_ws = DEF_CUR_WS;
 
 		free(workspaces[cur_ws].path);
-		workspaces[cur_ws].path = savestring(_path, strlen(_path));
+		workspaces[cur_ws].path = savestring(s_path, strlen(s_path));
 
 	} else { /* Error changing directory */
 		if (xargs.list_and_quit == 1) {
-			xerror("%s: '%s': %s\n", PROGRAM_NAME, _path, strerror(errno));
+			xerror("%s: '%s': %s\n", PROGRAM_NAME, s_path, strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 
 		err('w', PRINT_PROMPT, "%s: '%s': %s\n", PROGRAM_NAME,
-			_path, strerror(errno));
+			s_path, strerror(errno));
 	}
 }
 
@@ -1221,7 +1221,7 @@ set_trash_as_rm(void)
 #ifndef _NO_TRASH
 	xargs.trasrm = conf.tr_as_rm = 1;
 #else
-	fprintf(stderr, "%s: trash: %s\n", PROGRAM_NAME, _(NOT_AVAILABLE));
+	fprintf(stderr, "%s: trash: %s\n", PROGRAM_NAME, NOT_AVAILABLE);
 	exit(EXIT_FAILURE);
 #endif /* !_NO_TRASH */
 }
@@ -1300,19 +1300,6 @@ xset_pager_view(char *arg)
 }
 #endif /* !_BE_POSIX */
 
-__attribute__ ((noreturn))
-static void
-print_version(void)
-{
-#ifdef _BE_POSIX
-	char *posix = "-POSIX";
-#else
-	char *posix = "";
-#endif /* _BE_POSIX */
-	printf("%s%s\n", VERSION, posix);
-	exit(EXIT_SUCCESS);
-}
-
 #ifdef _BE_POSIX
 static void
 set_tab_mode(const char *opt)
@@ -1351,8 +1338,8 @@ parse_cmdline_args(const int argc, char **argv)
 
 	while ((optc = getopt(argc, argv, OPTSTRING)) != EOF) {
 		switch (optc) {
-		case 'a': conf.show_hidden = xargs.hidden = 1; break;
-		case 'A': conf.show_hidden = xargs.hidden = 0; break;
+		case 'a': xargs.show_hidden = conf.show_hidden = 1; break;
+		case 'A': xargs.show_hidden = conf.show_hidden = 0; break;
 		case 'b': xargs.bm_file = 1; set_alt_bm_file(optarg); break;
 		case 'B': set_tab_mode(optarg); break;
 		case 'c': xargs.config = 1; set_alt_config_file(optarg); break;
@@ -1375,14 +1362,14 @@ parse_cmdline_args(const int argc, char **argv)
 #ifndef _NO_ICONS
 			xargs.icons = conf.icons = 1; break;
 #else
-			fprintf(stderr, "%s: icons: %s\n", PROGRAM_NAME, _(NOT_AVAILABLE));
+			fprintf(stderr, "%s: icons: %s\n", PROGRAM_NAME, NOT_AVAILABLE);
 			exit(EXIT_FAILURE);
 #endif /* !_NO_ICONS */
 		case 'I': set_alt_trash_dir(optarg); break;
 		case 'j': set_stat(optc, optarg); break;
 		case 'J': set_stat(optc, optarg); break;
 		case 'k': set_alt_kbinds_file(optarg); break;
-		case 'l': conf.long_view = xargs.longview = 1; break;
+		case 'l': xargs.long_view = conf.long_view = 1; break;
 		case 'L':
 			xargs.follow_symlinks_long = conf.follow_symlinks_long = 1; break;
 		case 'm': xargs.fuzzy_match = conf.fuzzy_match = 1; break;
@@ -1392,7 +1379,7 @@ parse_cmdline_args(const int argc, char **argv)
 		case 'o': set_opener(optarg); break;
 		case 'O':
 #ifdef _NO_LIRA
-			fprintf(stderr, "%s: open: %s\n", PROGRAM_NAME, _(NOT_AVAILABLE));
+			fprintf(stderr, "%s: open: %s\n", PROGRAM_NAME, NOT_AVAILABLE);
 			exit(EXIT_FAILURE);
 #else
 			open_prev_file = optarg;
@@ -1402,7 +1389,7 @@ parse_cmdline_args(const int argc, char **argv)
 		case 'p': set_alt_profile(optarg); break;
 		case 'P':
 #ifdef _NO_LIRA
-			fprintf(stderr, "%s: preview: %s\n", PROGRAM_NAME, _(NOT_AVAILABLE));
+			fprintf(stderr, "%s: preview: %s\n", PROGRAM_NAME, NOT_AVAILABLE);
 			exit(EXIT_FAILURE);
 #else
 			open_prev_file = optarg;
@@ -1418,10 +1405,10 @@ parse_cmdline_args(const int argc, char **argv)
 		case 't': set_color_scheme(optarg, "-t"); break;
 		case 'T': xargs.trim_names = conf.trim_names = 0; break;
 		case 'u': xargs.disk_usage_analyzer = 1; break;
-		case 'v': print_version(); /* noreturn */
+		case 'v': version_function(0); break; /* noreturn */
 		case 'V': set_virtual_dir(optarg, "-V"); break;
 		case 'w': set_workspace(optarg); break;
-		case 'W': xargs.printsel = conf.print_selfiles = 1; break;
+		case 'W': xargs.print_selfiles = conf.print_selfiles = 1; break;
 		case 'x':
 			xargs.secure_env = 1;
 			xsecure_env(SECURE_ENV_IMPORT);
@@ -1430,14 +1417,14 @@ parse_cmdline_args(const int argc, char **argv)
 			xargs.secure_env_full = 1;
 			xsecure_env(SECURE_ENV_FULL);
 			break;
-		case 'y': conf.light_mode = xargs.light = 1; break;
+		case 'y': conf.light_mode = xargs.light_mode = 1; break;
 		case 'Y':
 			xargs.secure_cmds = xargs.secure_env = 1;
 			xsecure_env(SECURE_ENV_IMPORT);
 			break;
 		case 'z': set_sort(optarg); break;
 		case 'Z':
-			set_max_value(optarg, &xargs.max_files, &max_files);
+			set_max_value(optarg, &xargs.max_files, &conf.max_files);
 			break;
 
 		/* Handle error */
@@ -1497,8 +1484,8 @@ parse_cmdline_args(const int argc, char **argv)
 
 		switch (optc) {
 		/* Short options */
-		case 'a': conf.show_hidden = xargs.hidden = 1; break;
-		case 'A': conf.show_hidden = xargs.hidden = 0; break;
+		case 'a': xargs.show_hidden = conf.show_hidden = 1; break;
+		case 'A': xargs.show_hidden = conf.show_hidden = 0; break;
 		case 'b': xargs.bm_file = 1; set_alt_bm_file(optarg); break;
 		case 'c': xargs.config = 1; set_alt_config_file(optarg); break;
 
@@ -1512,34 +1499,34 @@ parse_cmdline_args(const int argc, char **argv)
 #endif /* RUN_CMD */
 
 		case 'D': set_alt_config_dir(optarg); break;
-		case 'e': xargs.noeln = conf.no_eln = 1; break;
+		case 'e': xargs.no_eln = conf.no_eln = 1; break;
 		case 'E': xargs.eln_use_workspace_color = 1; break;
-		case 'f': conf.list_dirs_first = xargs.dirs_first = 1; break;
-		case 'F': conf.list_dirs_first = xargs.dirs_first = 0; break;
-		case 'g': conf.pager = xargs.pager = 1; break;
-		case 'G': conf.pager = xargs.pager = 0; break;
+		case 'f': xargs.list_dirs_first = conf.list_dirs_first = 1; break;
+		case 'F': xargs.list_dirs_first = conf.list_dirs_first = 0; break;
+		case 'g': xargs.pager = conf.pager = 1; break;
+		case 'G': xargs.pager = conf.pager = 0; break;
 		case 'h': help_function(); break; /* noreturn */
 		case 'H': xargs.horizontal_list = 1; conf.listing_mode = HORLIST; break;
-		case 'i': conf.case_sens_list = xargs.case_sens_list = 0; break;
-		case 'I': conf.case_sens_list = xargs.case_sens_list = 1; break;
+		case 'i': xargs.case_sens_list = conf.case_sens_list = 0; break;
+		case 'I': xargs.case_sens_list = conf.case_sens_list = 1; break;
 		case 'k': set_alt_kbinds_file(optarg); break;
-		case 'l': conf.long_view = xargs.longview = 1; break;
+		case 'l': xargs.long_view = conf.long_view = 1; break;
 		case 'L':
 			xargs.follow_symlinks_long = conf.follow_symlinks_long = 1; break;
-		case 'm': conf.dirhist_map = xargs.dirmap = 1; break;
-		case 'o': conf.autols = xargs.autols = 1; break;
-		case 'O': conf.autols = xargs.autols = 0; break;
+		case 'm': xargs.dirhist_map = conf.dirhist_map = 1; break;
+		case 'o': xargs.autols = conf.autols = 1; break;
+		case 'O': xargs.autols = conf.autols = 0; break;
 		case 'p': path_value = optarg; xargs.path = 1; break;
 		case 'P': set_alt_profile(optarg); break;
 		case 'r': xargs.refresh_on_empty_line = 0; break;
-		case 's': conf.splash_screen = xargs.splash = 1; break;
+		case 's': xargs.splash_screen = conf.splash_screen = 1; break;
 		case 'S': xargs.stealth_mode = 1; break;
 		case 't': xargs.disk_usage_analyzer = 1; break;
 		case 'T': set_alt_trash_dir(optarg); break;
-		case 'v': print_version(); /* noreturn */
+		case 'v': version_function(0); break; /* noreturn */
 		case 'w': set_workspace(optarg); break;
-		case 'x': conf.ext_cmd_ok = xargs.ext = 0; break;
-		case 'y': conf.light_mode = xargs.light = 1; break;
+		case 'x': xargs.ext_cmd_ok = conf.ext_cmd_ok = 0; break;
+		case 'y': xargs.light_mode = conf.light_mode = 1; break;
 		case 'z': set_sort(optarg); break;
 
 		/* Only-long options */
@@ -1594,7 +1581,7 @@ parse_cmdline_args(const int argc, char **argv)
 #endif /* !_NO_ICONS */
 
 		case LOPT_INT_VARS:
-			xargs.int_vars = int_vars = 1; break;
+			xargs.int_vars = conf.int_vars = 1; break;
 		case LOPT_LIST_AND_QUIT:
 			xargs.list_and_quit = 1;
 			xargs.no_dirjump = 1;
@@ -1605,10 +1592,11 @@ parse_cmdline_args(const int argc, char **argv)
 			set_max_value(optarg, &xargs.max_dirhist, &conf.max_dirhist);
 			break;
 		case LOPT_MAX_FILES:
-			set_max_value(optarg, &xargs.max_files, &max_files);
+			set_max_value(optarg, &xargs.max_files, &conf.max_files);
 			break;
 		case LOPT_MAX_PATH:
-			set_max_value(optarg, &xargs.max_path, &conf.max_path);
+			set_max_value(optarg, &xargs.prompt_p_max_path,
+				&conf.prompt_p_max_path);
 			break;
 		case LOPT_MNT_UDISKS2:
 			xargs.mount_cmd = MNT_UDISKS2; break;
@@ -1625,17 +1613,17 @@ parse_cmdline_args(const int argc, char **argv)
 		case LOPT_NO_COLORS:
 			set_no_colors(); break;
 		case LOPT_NO_COLUMNS:
-			xargs.columns = conf.columned = 0; break;
+			xargs.columned = conf.columned = 0; break;
 		case LOPT_NO_DIR_JUMPER:
 			xargs.no_dirjump = 1; break;
 		case LOPT_NO_FILE_CAP:
-			xargs.check_cap = check_cap = 0; break;
+			xargs.check_cap = conf.check_cap = 0; break;
 		case LOPT_NO_FILE_EXT:
-			xargs.check_ext = check_ext = 0; break;
+			xargs.check_ext = conf.check_ext = 0; break;
 		case LOPT_NO_FILES_COUNTER:
 			xargs.files_counter = conf.files_counter = 0; break;
 		case LOPT_NO_FOLLOW_SYMLINKS:
-			xargs.follow_symlinks = follow_symlinks = 0; break;
+			xargs.follow_symlinks = conf.follow_symlinks = 0; break;
 		case LOPT_NO_FZFPREVIEW:
 			xargs.fzf_preview = conf.fzf_preview = 0; break;
 		case LOPT_NO_HIGHLIGHT:
@@ -1685,7 +1673,7 @@ parse_cmdline_args(const int argc, char **argv)
 			set_opener(optarg); break;
 		case LOPT_PAGER_VIEW: xset_pager_view(optarg); break;
 		case LOPT_PRINT_SEL:
-			xargs.printsel = conf.print_selfiles = 1; break;
+			xargs.print_selfiles = conf.print_selfiles = 1; break;
 		case LOPT_PROP_FIELDS: xset_prop_fields(optarg); break;
 		case LOPT_READONLY: xargs.readonly = conf.readonly = 1; break;
 		case LOPT_RL_VI_MODE:
@@ -1712,7 +1700,7 @@ parse_cmdline_args(const int argc, char **argv)
 		case LOPT_SHOTGUN_FILE:
 #ifdef _NO_LIRA
 			fprintf(stderr, "%s: --shotgun-file: %s\n",
-				PROGRAM_NAME, _(NOT_AVAILABLE));
+				PROGRAM_NAME, NOT_AVAILABLE);
 			exit(EXIT_FAILURE);
 #else
 			set_shotgun_file(optarg); break;
