@@ -44,10 +44,48 @@
 #include "aux.h"
 #include "misc.h"
 #include "checks.h"
+#include "file_operations.h" /* open_file() */
 #ifndef _NO_HIGHLIGHT
 # include "highlight.h"
 #endif /* !_NO_HIGHLIGHT */
-#include "spawn.h"
+#include "spawn.h" /* launch_execv() */
+
+/* Open the file FILE with APP (if not NULL, or with the default associated
+ * application otherwise). Returns the exit code returned by the opening
+ * application. */
+int
+open_config_file(char *app, char *file)
+{
+	if (!file || !*file)
+		return FUNC_FAILURE;
+
+	if (app && *app) {
+		char *cmd[] = {app, file, NULL};
+		return launch_execv(cmd, FOREGROUND, E_NOFLAG);
+	}
+
+	open_in_foreground = 1;
+	const int ret = open_file(file);
+	open_in_foreground = 0;
+
+	return ret;
+}
+
+/* Return the number of bytes in a UTF-8 sequence by inspecting only the
+ * leading byte (C).
+ * Taken from
+ * https://stackoverflow.com/questions/22790900/get-length-of-multibyte-utf-8-sequence */
+int
+utf8_bytes(unsigned char c)
+{
+    c >>= 4;
+    c &= 7;
+
+    if (c == 4)
+		return 2;
+
+	return c - 3;
+}
 
 void
 press_any_key_to_continue(const int init_newline)
@@ -63,6 +101,30 @@ press_any_key_to_continue(const int init_newline)
 	errno = saved_errno;
 }
 
+/* Print the file name FNAME, quoted if it contains an space.
+ * A slash is appended if FNAME is a directory (ISDIR >= 1). */
+void
+print_file_name(char *fname, const int isdir)
+{
+	char *tmp_name = (char *)NULL;
+	if (wc_xstrlen(fname) == 0)
+		tmp_name = replace_invalid_chars(fname);
+
+	char *name = tmp_name ? tmp_name : fname;
+
+	if (detect_space(name) == 1) {
+		if (strchr(name, '\''))
+			printf("\"%s%s\"\n", name, isdir >= 1 ? "/" : "");
+		else
+			printf("'%s%s'\n", name, isdir >= 1 ? "/" : "");
+	} else {
+		fputs(name, stdout);
+		puts(isdir >= 1 ? "/" : "");
+	}
+
+	free(tmp_name);
+}
+
 /* Return the value of the environment variable S, allocated via malloc if
  * ALLOC is 1, or just a pointer to the value if 0. */
 char *
@@ -206,12 +268,9 @@ set_fzf_preview_border_type(void)
 static void
 kitty_clear(void)
 {
-//	printf("\033_Ga=d,t=d\033\\");
-//	fflush(stdout);
-//	char *cmd[] = { "printf", "\033_Ga=d\033\\", NULL };
-	char *cmd[] = {"kitty", "icat", "--clear", "--silent",
-		"--transfer-mode=stream", NULL};
-	launch_execv(cmd, 0, 0);
+	char *cmd[] = {"kitty", "icat", "--clear", "--transfer-mode=stream",
+		"--stdin=no", NULL};
+	launch_execv(cmd, FOREGROUND, E_NOFLAG);
 }
 
 /* Remove any image printed by ueberzug.
@@ -278,10 +337,11 @@ find_digit(char *str)
 /* Check whether a given command needs ELN's to be expanded/completed/suggested.
  * Returns 1 if yes or 0 if not. */
 int
-should_expand_eln(const char *text)
+should_expand_eln(const char *text, char *cmd_name)
 {
-	char *l = rl_line_buffer;
-	             /* Do not expand numbers starting with zero */
+	char *l = cmd_name ? cmd_name : rl_line_buffer;
+
+	/* Do not expand numbers starting with zero */
 	if (!l || !*l || *text == '0' || !is_number(text))
 		return 0;
 
@@ -310,6 +370,7 @@ should_expand_eln(const char *text)
 		return 1;
 
 	*p = '\0';
+
 	flags |= STATE_COMPLETING;
 	if (is_internal_c(l) && !is_internal_f(l)) {
 		*p = t;
@@ -570,7 +631,7 @@ normalize_path(char *src, const size_t src_len)
 void
 rl_ring_bell(void)
 {
-	switch (bell) {
+	switch (conf.bell_style) {
 	case BELL_AUDIBLE:
 		RING_BELL; fflush(stderr); return;
 
@@ -834,27 +895,47 @@ get_rgb(char *hex, int *attr, int *r, int *g, int *b)
 		return (-1);
 
 	if (*hex == '#') {
-		if (!*(hex + 1))
+		if (!hex[1])
 			return (-1);
 		hex++;
 	}
 
+	char *h = hex;
+
+	/* Convert 3-digits HEX to 6-digits */
+	static char buf[9];
+	if (h[0] && h[1] && h[2] && (!h[3] || h[3] == '-') ) {
+		buf[0] = buf[1] = h[0];
+		buf[2] = buf[3] = h[1];
+		buf[4] = buf[5] = h[2];
+
+		if (!h[3] || !h[4]) {
+			buf[6] = '\0';
+		} else {
+			buf[6] = '-';
+			buf[7] = h[4];
+			buf[8] = '\0';
+		}
+
+		h = buf;
+	}
+
 	char tmp[3];
 	tmp[2] = '\0';
 
-	tmp[0] = *hex; tmp[1] = *(hex + 1);
+	tmp[0] = h[0]; tmp[1] = h[1];
 	*r = hex2int(tmp);
 
-	tmp[0] = *(hex + 2); tmp[1] = *(hex + 3);
+	tmp[0] = h[2]; tmp[1] = h[3];
 	*g = hex2int(tmp);
 
-	tmp[0] = *(hex + 4); tmp[1] = *(hex + 5);
+	tmp[0] = h[4]; tmp[1] = h[5];
 	*b = hex2int(tmp);
 
 	*attr = -1; /* Attribute unset */
-	if (*(hex + 6) == '-' && *(hex + 7) && *(hex + 7) >= '0'
-	&& *(hex + 7) <= '9' && !*(hex + 8))
-		*attr = *(hex + 7) - '0';
+	if (h[6] == '-' && h[7] && h[7] >= '0'
+	&& h[7] <= '9' && !h[8])
+		*attr = h[7] - '0';
 
 	if (xargs.no_bold == 1 && *attr == 1)
 		*attr = -1;
