@@ -55,16 +55,19 @@ mode_t get_dt(const mode_t mode);
 int  get_link_ref(const char *link);
 char *hex2rgb(char *hex);
 char *normalize_path(char *src, const size_t src_len);
+int  open_config_file(char *app, char *file);
 FILE *open_fread(const char *name, int *fd);
 FILE *open_fwrite(const char *name, int *fd);
 FILE *open_fappend(const char *name);
 void press_any_key_to_continue(const int init_newline);
+void print_file_name(char *fname, const int isdir);
 int  read_octal(char *str);
 void rl_ring_bell(void);
 void set_fzf_preview_border_type(void);
-int  should_expand_eln(const char *text);
+int  should_expand_eln(const char *text, char *cmd_name);
 char *url_encode(char *str);
 char *url_decode(char *str);
+int  utf8_bytes(unsigned char c);
 filesn_t xatof(const char *s);
 int  xatoi(const char *s);
 const char *xitoa(long long n);
