@@ -106,16 +106,29 @@ old_chown(int fd, const char *path, uid_t owner, gid_t group, int flag)
 
 /* strnlen(3) is not specified in POSIX-1.2001 */
 size_t
-x_strnlen(const char *s, size_t max)
+x_strnlen(const char *s, size_t len)
 {
-	size_t n = 0;
+	size_t i;
 
-	while (*s && n < max) {
-		s++;
-		n++;
-	}
+	for (i = 0; i < len && s[i]; i++);
+	return i;
+}
 
-	return n;
+/* ----------------- realpath ------------------------ */
+
+/* According to POSIX-1.2001, realpath(3) does not support RESOLVED_PATH
+ * to be NULL. So, if it is NULL, lets allocate memory ourselves. */
+char *
+old_realpath(const char *restrict path, char *restrict resolved_path)
+{
+	if (resolved_path != NULL)
+		return realpath(path, resolved_path);
+
+	char *ptr = malloc(PATH_MAX + 1);
+	if (!ptr)
+		return (char *)NULL;
+
+	return realpath(path, ptr);
 }
 
 /* ------------------------- scandir ------------------------ */
@@ -310,6 +323,13 @@ nx_getdelim_append(char **lineptr, size_t *bufsize, size_t count, char ch)
 	return (-1);
 }
 
+#ifdef __HAIKU__
+/* Haiku complains about -ENOMEM overflowing int. */
+# define XENOMEM 1
+#else
+# define XENOMEM ENOMEM
+#endif /* __HAIKU__ */
+
 /* Read data into a dynamically resizable buffer until EOF or until a
  * delimiter character is found. The returned data will be null terminated
  * (unless there's an error allocating memory that prevents it).
@@ -340,7 +360,7 @@ nx_getdelim(char **lineptr, size_t *n, int delim, FILE *stream)
 
 		/* Check for error adding to the buffer (ie., out of memory) */
 		if (result < 0) {
-			err = -ENOMEM;
+			err = -XENOMEM;
 			break;
 		}
 
@@ -370,7 +390,7 @@ nx_getdelim(char **lineptr, size_t *n, int delim, FILE *stream)
 
 	if (feof(stream) && (count == 0)) {
 		if (nx_getdelim_append(&line, &size, count, 0) < 0) {
-			return -ENOMEM;
+			return -XENOMEM;
 		}
 	}
 
