@@ -27,8 +27,9 @@
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
-#include <unistd.h>   /* access */
-#include <sys/wait.h> /* waitpid */
+#include <unistd.h>   /* access() */
+#include <sys/wait.h> /* waitpid() */
+#include <time.h>     /* clock_gettime() */
 
 #ifdef __OpenBSD__
 typedef char *rl_cpvfunc_t;
@@ -138,7 +139,7 @@ check_paths_timestamps(void)
  * installed, renamed, or removed from some of the paths in PATH
  * while in CliFM, this latter needs to be restarted in order
  * to be able to recognize the new program for TAB completion */
-static inline void
+static void
 reload_binaries(void)
 {
 	if (check_paths_timestamps() == FUNC_SUCCESS)
@@ -260,7 +261,7 @@ check_shell_cmd_conditions(char **args)
 	/* No command name ends with a slash */
 	const size_t len = (args && args[0]) ? strlen(args[0]) : 0;
 	if (len > 0 && args[0][len - 1] == '/') {
-		xerror("%s: %s: %s\n", conf.autocd == 1 ? "cd" : "open",
+		xerror("%s: '%s': %s\n", conf.autocd == 1 ? "cd" : "open",
 			args[0], strerror(ENOENT));
 		return conf.autocd == 1 ? FUNC_FAILURE : E_NOTFOUND;
 	}
@@ -328,26 +329,26 @@ static int
 set_max_files(char **args)
 {
 	if (!args[1]) { /* Inform about the current value */
-		if (max_files == -1)
+		if (conf.max_files == UNSET)
 			puts(_("Max files: unset"));
 		else
-			printf(_("Max files: %d\n"), max_files);
+			printf(_("Max files: %d\n"), conf.max_files);
 		return FUNC_SUCCESS;
 	}
 
 	if (IS_HELP(args[1])) { puts(_(MF_USAGE)); return FUNC_SUCCESS;	}
 
 	if (*args[1] == 'u' && strcmp(args[1], "unset") == 0) {
-		max_files = -1;
+		conf.max_files = UNSET;
 		if (conf.autols == 1) reload_dirlist();
 		print_reload_msg(_("Max files unset\n"));
 		return FUNC_SUCCESS;
 	}
 
 	if (*args[1] == '0' && !args[1][1]) {
-		max_files = 0;
+		conf.max_files = 0;
 		if (conf.autols == 1) reload_dirlist();
-		print_reload_msg(_("Max files set to %d\n"), max_files);
+		print_reload_msg(_("Max files set to %d\n"), conf.max_files);
 		return FUNC_SUCCESS;
 	}
 
@@ -357,9 +358,9 @@ set_max_files(char **args)
 		return (exit_code = FUNC_FAILURE);
 	}
 
-	max_files = (int)inum;
+	conf.max_files = (int)inum;
 	if (conf.autols == 1) reload_dirlist();
-	print_reload_msg(_("Max files set to %d\n"), max_files);
+	print_reload_msg(_("Max files set to %d\n"), conf.max_files);
 
 	return FUNC_SUCCESS;
 }
@@ -1088,7 +1089,7 @@ sort_func(char **args)
 	return sort_function(args);
 }
 
-static inline int
+static int
 check_pinned_file(char **args)
 {
 	int i = (int)args_n + 1;
@@ -1102,7 +1103,7 @@ check_pinned_file(char **args)
 	return FUNC_SUCCESS;
 }
 
-static inline int
+static int
 check_actions(char **args)
 {
 	if (actions_n == 0)
@@ -1151,7 +1152,7 @@ launch_shell(const char *arg)
 	return (-1);
 }
 
-static inline void
+static void
 expand_and_deescape(char **arg, char **deq_str)
 {
 	if (*(*arg) == '~') {
@@ -1350,17 +1351,27 @@ lira_function(char **args)
 #endif /* !_NO_LIRA */
 }
 
-static inline int
-check_comments(const char *name)
+static int
+check_comments(char *name)
 {
-	if (*name != '#')
+	const int maybe_comment =
+		((*name == '\\' && name[1] == '#') || *name == '#');
+
+	if (maybe_comment == 0)
 		return FUNC_FAILURE;
 
+	char *p = (*name == '\\' || strchr(name + 1, '\\'))
+		? unescape_str(name, 0) : (char *)NULL;
+	char * n = p ? p : name;
+
 	/* Skip lines starting with '#' if there is no such file name
 	 * in the current directory. This implies that no command starting
 	 * with '#' will be executed */
 	struct stat a;
-	if (lstat(name, &a) == -1)
+	const int ret = lstat(n, &a);
+	free(p);
+
+	if (ret == -1)
 		return FUNC_SUCCESS;
 
 	if (conf.autocd == 1 && S_ISDIR(a.st_mode))
@@ -2071,7 +2082,7 @@ toggle_follow_links(const char *arg)
  * This will be the value returned by this function. Used by the \z
  * escape code in the prompt to print the exit status of the last
  * executed command */
-int
+static int
 exec_cmd(char **comm)
 {
 	if (zombies > 0)
@@ -2152,7 +2163,6 @@ exec_cmd(char **comm)
 
 	/*   ################ DIRECTORY JUMPER ##################     */
 	else if (*comm[0] == 'j' && (!comm[0][1] || ((comm[0][1] == 'c'
-//	|| comm[0][1] == 'p' || comm[0][1] == 'e' || comm[0][1] == 'o'
 	|| comm[0][1] == 'p' || comm[0][1] == 'e'
 	|| comm[0][1] == 'l') && !comm[0][2])))
 		return (exit_code = dirjump(comm, NO_SUG_JUMP));
@@ -2256,7 +2266,7 @@ exec_cmd(char **comm)
 				return FUNC_SUCCESS;
 			}
 			if (!sel_is_last && comm[1] && !comm[2])
-				xrename = 1;
+				alt_prompt = 1;
 
 			use_force = is_force_param(comm[1]);
 			set_mv_cmd(&comm[0], use_force);
@@ -2543,7 +2553,7 @@ exec_cmd(char **comm)
 
 	/* #### CONFIG #### */
 	else if (*comm[0] == 'c' && strcmp(comm[0], "config") == 0)
-		return (exit_code = edit_function(comm));
+		return (exit_code = config_edit(comm));
 
 	/* #### HISTORY #### */
 	else if (*comm[0] == 'h' && strcmp(comm[0], "history") == 0)
@@ -2603,7 +2613,7 @@ exec_cmd(char **comm)
 
 	else if (*comm[0] == 'v' && (strcmp(comm[0], "ver") == 0
 	|| strcmp(comm[0], "version") == 0)) {
-		version_function();	return FUNC_SUCCESS;
+		version_function(1); return FUNC_SUCCESS;
 	}
 
 	else if (*comm[0] == 'b' && strcmp(comm[0], "bonus") == 0) {
@@ -2657,19 +2667,48 @@ CHECK_EVENTS:
 	return exit_code;
 }
 
-static inline void
+/* Run the command CMD and, if the '\b' prompt code is used, store execution
+ * time in last_cmd_time (global). */
+int
+exec_cmd_tm(char **cmd)
+{
+	struct timespec begin, end;
+	int reta = -1;
+
+	if (conf.prompt_b_is_set == 1)
+		reta = clock_gettime(CLOCK_REALTIME, &begin);
+
+	const int ret = exec_cmd(cmd);
+
+	if (conf.prompt_b_is_set == 1) {
+		const int retb = clock_gettime(CLOCK_REALTIME, &end);
+
+		if (reta == -1 || retb == -1) {
+			last_cmd_time = 0.0;
+			return ret;
+		}
+
+		last_cmd_time =
+			(double)(end.tv_nsec - begin.tv_nsec) / 1000000000.0 +
+			(double)(end.tv_sec  - begin.tv_sec);
+	}
+
+	return ret;
+}
+
+static void
 run_chained_cmd(char **cmd, size_t *err_code)
 {
 	size_t i;
 	char **alias_cmd = check_for_alias(cmd);
 	if (alias_cmd) {
-		if (exec_cmd(alias_cmd) != 0)
+		if (exec_cmd_tm(alias_cmd) != 0)
 			*err_code = 1;
 		for (i = 0; alias_cmd[i]; i++)
 			free(alias_cmd[i]);
 		free(alias_cmd);
 	} else {
-		if ((flags & FAILED_ALIAS) || exec_cmd(cmd) != 0)
+		if ((flags & FAILED_ALIAS) || exec_cmd_tm(cmd) != 0)
 			*err_code = 1;
 		flags &= ~FAILED_ALIAS;
 		for (i = 0; i <= args_n; i++)
@@ -2708,23 +2747,25 @@ exec_chained_cmds(char *cmd)
 			continue;
 		}
 
-		if (cmd[i] == '&') cond_exec = 1;
+		if (cmd[i] == '&')
+			cond_exec = 1;
 
 		char **tmp_cmd = parse_input_str((*str == ' ') ? str + 1 : str);
 		free(str);
 
-		if (!tmp_cmd) continue;
+		if (!tmp_cmd)
+			continue;
 
 		run_chained_cmd(tmp_cmd, &error_code);
 
 		/* Do not continue if the execution was condtional and
 		 * the previous command failed. */
-		if (cond_exec && error_code)
+		if (cond_exec == 1 && error_code == 1)
 			break;
 	}
 }
 
-static inline void
+static void
 run_profile_line(char *cmd)
 {
 	if (xargs.secure_cmds == 1
@@ -2769,7 +2810,7 @@ exec_profile(void)
 		if (line[line_len - 1] == '\n')
 			line[line_len - 1] = '\0';
 
-		if (int_vars == 1 && strchr(line, '=') && !IS_DIGIT(*line))
+		if (conf.int_vars == 1 && strchr(line, '=') && !IS_DIGIT(*line))
 			create_usr_var(line);
 		else
 			run_profile_line(line);
