@@ -1499,7 +1499,7 @@ run_cp_mv_cmd(char **cmd, const int skip_force)
 		return FUNC_FAILURE;
 
 	char *new_name = (char *)NULL;
-	if (xrename == 1) {
+	if (alt_prompt == 1) {
 		if (!cmd[1])
 			return EINVAL;
 
@@ -1517,7 +1517,7 @@ run_cp_mv_cmd(char **cmd, const int skip_force)
 			}
 			if (i == -1) {
 				xerror(_("%s: %s: No such ELN\n"), PROGRAM_NAME, cmd[1]);
-				xrename = 0;
+				alt_prompt = 0;
 				return ENOENT;
 			}
 		} else {
@@ -1526,7 +1526,7 @@ run_cp_mv_cmd(char **cmd, const int skip_force)
 			const int ret = lstat(p ? p : cmd[1], &a);
 			free(p);
 			if (ret == -1) {
-				xrename = 0;
+				alt_prompt = 0;
 				xerror("m: %s: %s\n", cmd[1], strerror(errno));
 				return errno;
 			}
@@ -1700,30 +1700,6 @@ cp_mv_file(char **args, const int copy_and_rename, const int force)
 	return FUNC_SUCCESS;
 }
 
-/* Print the file name FNAME, quoted if it contains an space.
- * A slash is appended if FNAME is a directory (ISDIR >= 1). */
-static void
-print_file_name(char *fname, const int isdir)
-{
-	char *tmp_name = (char *)NULL;
-	if (wc_xstrlen(fname) == 0)
-		tmp_name = replace_invalid_chars(fname);
-
-	char *name = tmp_name ? tmp_name : fname;
-
-	if (detect_space(name) == 1) {
-		if (strchr(name, '\''))
-			printf("\"%s%s\"\n", name, isdir >= 1 ? "/" : "");
-		else
-			printf("'%s%s'\n", name, isdir >= 1 ? "/" : "");
-	} else {
-		fputs(name, stdout);
-		puts(isdir >= 1 ? "/" : "");
-	}
-
-	free(tmp_name);
-}
-
 static void
 print_removed_file_info(const struct rm_info info)
 {
@@ -1865,7 +1841,7 @@ remove_files(char **args)
 		 * stat(2) will take it as the symlink it is and rm(1) will remove
 		 * the symlink (not the target) without complains. */
 		const size_t len = strlen(args[i]);
-		if (len > 0 && args[i][len - 1] == '/')
+		if (len > 1 && args[i][len - 1] == '/')
 			args[i][len - 1] = '\0';
 
 		/* Check if at least one file is in the current directory. If not,
