@@ -62,7 +62,7 @@ print_tips(const int all)
 		"Manage default associated applications with the 'mime' command",
 		"Customize previewing applications: 'view edit' or F7",
 		"List mountpoints: 'mp' or Alt-m",
-		"Compress and decompress files using the 'ac' and 'ad' "
+		"Compress and decompress files using the 'ac' and 'ad' " /* NOLINT */
 		"commands respectively. E.g.: 'ac sel' or 'ad file.zip'",
 		"Disallow the use of shell commands with the -x option: 'clifm -x'",
 		"Don't like ELN's? Disable them using the -e command line switch",
@@ -564,16 +564,10 @@ __attribute__ ((noreturn))
 void
 help_function(void)
 {
-#ifdef _BE_POSIX
-	const char *posix = "-POSIX";
-#else
-	const char *posix = "";
-#endif /* _BE_POSIX */
-
 	fputs(NC, stdout);
 	printf("%s\n", ASCII_LOGO);
-	printf(_("%s %s%s (%s), by %s\n"), PROGRAM_NAME, VERSION,
-		posix, DATE, AUTHOR);
+	printf(_("%s %s (%s), by %s\n"), PROGRAM_NAME, VERSION,
+		DATE, AUTHOR);
 #ifdef _BE_POSIX
 	printf("\nUSAGE: %s %s\n%s\n", PROGRAM_NAME, GRAL_USAGE,
 		_(OPTIONS_LIST));
