@@ -28,8 +28,8 @@
 #define PROGRAM_NAME_UPPERCASE "Clifm"
 #define PROGRAM_NAME "clifm"
 #define PROGRAM_DESC "The command line file manager"
-#define VERSION "1.20"
-#define DATE "Aug 16, 2024"
+#define VERSION "1.21"
+#define DATE "Sep 30, 2024"
 #define AUTHOR "L. Abramovich"
 #define CONTACT "https://github.com/leo-arch/clifm"
 #define LICENSE "GPL2+"
@@ -630,8 +630,6 @@ extern time_t curdir_mtime;
 #define RL_NC "\001\x1b[0m\002"
 
 #define UNSET  (-1)
-/* Some options take -1 as a valid value. So, let's use -2 to mark it unset */
-#define UNSET2 (-2)
 
 /* Macros for the cp and mv cmds */
 #define CP_CP            0 /* cp -iRp */
@@ -672,7 +670,8 @@ extern time_t curdir_mtime;
 #define SGRP       11
 #define SBLK       12
 #define SLNK       13
-#define SORT_TYPES 13
+#define STYPE      14
+#define SORT_TYPES 14
 
 /* Macros for the colors_list function */
 #define NO_ELN        0
@@ -722,6 +721,8 @@ extern time_t curdir_mtime;
 #define PROFILE_SUG    30
 #define BM_PREFIX_SUG  31 /* Bookmark name (b:NAME) */
 #define DIRHIST_SUG    32
+#define WS_PREFIX_SUG  33 /* Workspace name (w:NAME) */
+#define WS_NUM_PREFIX_SUG 34
 
 /* 46 == \x1b[00;38;02;000;000;000;00;48;02;000;000;000m\0 (24bit, RGB
  * true color format including foreground and background colors, the SGR
@@ -861,7 +862,7 @@ extern time_t curdir_mtime;
 /* Flags to skip fuzzy matching based on what we're comparing. */
 #define FUZZY_FILES_ASCII 0
 #define FUZZY_FILES_UTF8  1
-#define FUZZY_BM_NAMES    2
+/*#define FUZZY_BM_NAMES    2 */
 #define FUZZY_HISTORY     3
 #define FUZZY_ALGO_MAX    2 /* We have two fuzzy algorithms */
 
@@ -927,7 +928,7 @@ extern time_t curdir_mtime;
 
 /* Do we have the sort method S in light mode? */
 #define ST_IN_LIGHT_MODE(s) ((s) == SNAME || (s) == SVER || (s) == SINO \
-		|| (s) == SEXT || (s) == SNONE)
+		|| (s) == SEXT || (s) == SNONE || (s) == STYPE)
 
 #define UNUSED(x) (void)(x) /* Just silence the compiler's warning */
 #define TOUPPER(c) (((c) >= 'a' && (c) <= 'z') ? ((c) - 'a' + 'A') : (c))
@@ -1099,6 +1100,7 @@ struct config_t {
 	char *term;
 	char *time_str;
 	char *ptime_str;
+	char *rprompt_str;
 	char *welcome_message_str;
 	char *wprompt_str;
 #ifndef _NO_SUGGESTIONS
@@ -1113,11 +1115,14 @@ struct config_t {
 	int auto_open;
 	int autocd;
 	int autols;
+	int bell_style;
 	int case_sens_dirjump;
 	int case_sens_path_comp;
 	int case_sens_search;
 	int case_sens_list; /* files list */
 	int cd_on_quit;
+	int check_cap;
+	int check_ext;
 	int classify;
 	int clear_screen;
 	int cmd_desc_sug;
@@ -1130,6 +1135,7 @@ struct config_t {
 	int disk_usage;
 	int ext_cmd_ok;
 	int files_counter;
+	int follow_symlinks;
 	int follow_symlinks_long;
 	int full_dir_size;
 	int fuzzy_match;
@@ -1137,6 +1143,7 @@ struct config_t {
 	int fzf_preview;
 	int highlight;
 	int icons;
+	int int_vars;
 	int light_mode;
 	int link_creat_mode;
 	int list_dirs_first;
@@ -1147,10 +1154,10 @@ struct config_t {
 	int max_dirhist;
 	int max_hist;
 	int max_jump_total_rank;
+	int max_files;
 	int max_log;
 	int max_name_len;
 	int max_name_len_bk;
-	int max_path;
 	int max_printselfiles;
 	int min_jump_rank;
 	int min_name_trim;
@@ -1164,6 +1171,13 @@ struct config_t {
 	int print_dir_cmds;
 	int print_selfiles;
 	int private_ws_settings;
+	int prompt_b_is_set;
+	int prompt_b_min;
+	int prompt_b_precision;
+	int prompt_f_dir_len;
+	int prompt_f_full_len_dirs;
+	int prompt_p_max_path;
+	int prompt_is_multiline;
 	int prop_fields_gap;
 	int quoting_style;
 	int read_autocmd_files;
@@ -1187,12 +1201,13 @@ struct config_t {
 	int trim_names;
 #ifndef _NO_TRASH
 	int tr_as_rm;
+	int trash_force;
 #else
 	int pad1; /* Keep the struct alignment */
+	int pad2;
 #endif /* !_NO_TRASH */
 	int warning_prompt;
 	int welcome_message;
-	int pad2;
 };
 
 extern struct config_t conf;
@@ -1431,11 +1446,11 @@ struct param_t {
 	int clear_screen;
 	int color_lnk_as_target;
 	int colorize;
-	int columns;
+	int columned;
 	int config;
 	int cwd_in_title;
 	int desktop_notifications;
-	int dirmap;
+	int dirhist_map;
 	int disk_usage;
 	int cd_on_quit;
 	int check_cap;
@@ -1444,8 +1459,7 @@ struct param_t {
 	int color_scheme;
 	int disk_usage_analyzer;
 	int eln_use_workspace_color;
-	int ext;
-	int dirs_first;
+	int ext_cmd_ok;
 	int files_counter;
 	int follow_symlinks;
 	int follow_symlinks_long;
@@ -1458,7 +1472,6 @@ struct param_t {
 	int fnftab;
 	int smenutab;
 #endif /* !_NO_FZF */
-	int hidden;
 #ifndef _NO_HIGHLIGHT
 	int highlight;
 #endif /* !_NO_HIGHLIGHT */
@@ -1470,23 +1483,24 @@ struct param_t {
 	int icons_use_file_color;
 	int int_vars;
 	int list_and_quit;
-	int light;
-	int longview;
+	int light_mode;
+	int list_dirs_first;
+	int long_view;
 	int lscolors;
 	int max_dirhist;
 	int max_files;
-	int max_path;
 	int mount_cmd;
 	int no_bold;
 	int no_dirjump;
-	int noeln;
+	int no_eln;
 	int only_dirs;
 	int open;
 	int pager;
 	int pager_view;
 	int path;
 	int preview;
-	int printsel;
+	int print_selfiles;
+	int prompt_p_max_path;
 	int prop_fields_str;
 	int ptime_style;
 	int readonly;
@@ -1499,10 +1513,11 @@ struct param_t {
 	int secure_env_full;
 	int sel_file;
 	int share_selbox;
+	int show_hidden;
 	int si; /* Sizes in powers of 1000 instead of 1024 */
 	int sort;
 	int sort_reverse;
-	int splash;
+	int splash_screen;
 	int stat;
 	int stealth_mode;
 #ifndef _NO_SUGGESTIONS
@@ -1610,8 +1625,11 @@ struct prompts_t {
 	char *name;
 	char *regular;
 	char *warning;
+	char *right;
 	int notifications;
 	int warning_prompt_enabled;
+	int multiline; /* Regular prompt is multiline */
+	int pad0;
 };
 
 extern struct prompts_t *prompts;
@@ -1711,7 +1729,7 @@ extern struct ext_t *ext_colors;
 #define EXT4_FSTYPE 0x004
 struct ext_mnt_t {
 	char *mnt_point;
-	int  type; /* One of EXTNFSTYPE macros */
+	int  type; /* One of EXTN_FSTYPE macros */
 	int  pad0;
 };
 
@@ -1803,6 +1821,7 @@ enum comp_type {
 	TCMP_OWNERSHIP =  34,
 	TCMP_DIRHIST =    35,
 	TCMP_MIME_LIST =  36,
+	TCMP_WS_PREFIX =  37, /* 'w:' keyword expansion */
 	TCMP_MIME_FILES = TCMP_FILE_TYPES_FILES /* Same behavior */
 };
 
@@ -1820,36 +1839,30 @@ extern int
 
 /* Internal state flags */
 extern int
+	alt_prompt, /* We're running a secondary prompt for the rename function */
 	argc_bk, /* A copy of argc taken from main() */
 	autocmd_set,
-	bell,
 	bg_proc,
-	check_cap,
-	check_ext,
 	cmdhist_flag,
 	config_ok,
 	cur_ws,
 	curcol,
 	dequoted,
-	dir_changed, /* flag to know is dir was changed: used by autocmds */
+	dir_changed, /* flag to know if dir was changed: used by autocmds */
 	dirhist_cur_index,
 	dirhist_total_index,
 	exit_code,
-	follow_symlinks,
 	fzftab,
 	fzf_border_type,
 	fzf_height_set,
 	fzf_preview_border_type,
 	hist_status,
 	home_ok,
-	int_vars,
 	internal_cmd,
 	is_sel,
 	is_cdpath,
 	jump_total_rank,
 	kbind_busy,
-	max_files,
-	mime_match,
 	nesting_level, /* Is this a nested instance? */
 	no_log,
 	open_in_foreground, /* Overrides mimelist file value: used by mime_open */
@@ -1872,10 +1885,10 @@ extern int
 	trash_ok,
 #endif /* !_NO_TRASH */
 	virtual_dir,
-	wrong_cmd,
-	xrename; /* We're running a secondary prompt for the rename function */
+	wrong_cmd;
 
 extern unsigned short term_cols, term_lines;
+extern double last_cmd_time;
 
 extern size_t
 	actions_n,
@@ -1956,6 +1969,7 @@ extern char
 	*msgs_log_file,
 	*pinned_dir,
 	*plugins_dir,
+	*plugins_helper_file,
 	*profile_file,
 	*prompts_file,
 	*quote_chars,
