@@ -409,18 +409,7 @@ edit_history(char **args)
 
 	const time_t mtime_bfr = attr.st_mtime;
 
-	int ret = FUNC_SUCCESS;
-
-	/* If we have an opening application (2nd argument) */
-	if (args[2]) {
-		char *cmd[] = {args[2], hist_file, NULL};
-		ret = launch_execv(cmd, FOREGROUND, E_NOFLAG);
-	} else {
-		open_in_foreground = 1;
-		ret = open_file(hist_file);
-		open_in_foreground = 0;
-	}
-
+	int ret = open_config_file(args[2], hist_file);
 	if (ret != FUNC_SUCCESS)
 		return ret;
 
@@ -472,9 +461,12 @@ print_history_list(const int timestamp)
 		if (timestamp == 1 && history[i].date != -1) {
 			char tdate[MAX_TIME_STR];
 			gen_time_str(tdate, sizeof(tdate), history[i].date);
-			printf(" %s# %s%s\n", "\x1b[0;2m", tdate, "\x1b[0m");
+			printf(" %s%-*zu%s %s%s%s %s\n", el_c, n, i + 1, df_c,
+				conf.colorize == 1 ? "\x1b[0;2m" : "",
+				tdate, "\x1b[0m", history[i].cmd);
+		} else {
+			printf(" %s%-*zu%s %s\n", el_c, n, i + 1, df_c, history[i].cmd);
 		}
-		printf(" %s%-*zu%s %s\n", el_c, n, i + 1, df_c, history[i].cmd);
 	}
 
 	return FUNC_SUCCESS;
