@@ -60,6 +60,7 @@
 #include "jump.h" /* add_to_jumpdb() */
 #include "misc.h"
 #include "navigation.h"
+#include "prompt.h" /* set_prompt_options() */
 #include "sanitize.h"
 #include "selection.h"
 #include "sort.h"
@@ -143,7 +144,7 @@ init_workspaces_opts(void)
 		workspace_opts[i].light_mode = conf.light_mode;
 		workspace_opts[i].list_dirs_first = conf.list_dirs_first;
 		workspace_opts[i].long_view = conf.long_view;
-		workspace_opts[i].max_files = max_files;
+		workspace_opts[i].max_files = conf.max_files;
 		workspace_opts[i].max_name_len = conf.max_name_len;
 		workspace_opts[i].only_dirs = conf.only_dirs;
 		workspace_opts[i].pager = conf.pager;
@@ -180,23 +181,27 @@ init_conf_struct(void)
 	conf.auto_open = UNSET;
 	conf.autocd = UNSET;
 	conf.autols = UNSET;
+	conf.bell_style = DEF_BELL_STYLE;
 	conf.case_sens_dirjump = UNSET;
 	conf.case_sens_path_comp = UNSET;
-	conf.case_sens_search = UNSET;
+	conf.case_sens_search = DEF_CASE_SENS_SEARCH;
 	conf.case_sens_list = UNSET;
+	conf.check_cap = DEF_CHECK_CAP;
+	conf.check_ext = DEF_CHECK_EXT;
 	conf.cd_on_quit = UNSET;
 	conf.classify = UNSET;
 	conf.clear_screen = UNSET;
-	conf.cmd_desc_sug = UNSET;
+	conf.cmd_desc_sug = DEF_CMD_DESC_SUG;
 	conf.colorize = UNSET;
 	conf.color_lnk_as_target = UNSET;
-	conf.columned = UNSET;
-	conf.cp_cmd = UNSET;
+	conf.columned = DEF_COLUMNS;
+	conf.cp_cmd = DEF_CP_CMD;
 	conf.desktop_notifications = UNSET;
 	conf.dirhist_map = UNSET;
 	conf.disk_usage = UNSET;
 	conf.ext_cmd_ok = UNSET;
 	conf.files_counter = UNSET;
+	conf.follow_symlinks = DEF_FOLLOW_SYMLINKS;
 	conf.follow_symlinks_long = DEF_FOLLOW_SYMLINKS_LONG;
 	conf.full_dir_size = UNSET;
 	conf.fuzzy_match = UNSET;
@@ -212,49 +217,57 @@ init_conf_struct(void)
 #else
 	conf.icons = 0;
 #endif /* !_NO_ICONS */
+	conf.int_vars = DEF_INT_VARS;
 	conf.light_mode = UNSET;
 	conf.link_creat_mode = DEF_LINK_CREATION_MODE;
 	conf.list_dirs_first = UNSET;
 	conf.listing_mode = UNSET;
-	conf.log_cmds = UNSET;
-	conf.log_msgs = UNSET;
+	conf.log_cmds = DEF_LOG_CMDS;
+	conf.log_msgs = DEF_LOG_MSGS;
 	conf.long_view = UNSET;
 	conf.max_dirhist = UNSET;
-	conf.max_hist = UNSET;
-	conf.max_log = UNSET;
-	conf.max_jump_total_rank = UNSET;
+	conf.max_files = DEF_MAX_FILES;
+	conf.max_hist = DEF_MAX_HIST;
+	conf.max_log = DEF_MAX_LOG;
+	conf.max_jump_total_rank = DEF_MAX_JUMP_TOTAL_RANK;
 	conf.max_name_len = DEF_MAX_NAME_LEN;
 	conf.max_name_len_bk = 0;
-	conf.max_path = UNSET;
-	conf.max_printselfiles = UNSET2; /* -1 is a valid value */
-	conf.min_jump_rank = UNSET2; /* UNSET (-1) is a valid value for MinJumpRank */
-	conf.min_name_trim = UNSET;
-	conf.mv_cmd = UNSET;
+	conf.max_printselfiles = DEF_MAX_PRINTSEL;
+	conf.min_jump_rank = DEF_MIN_JUMP_RANK;
+	conf.min_name_trim = DEF_MIN_NAME_TRIM;
+	conf.mv_cmd = DEF_MV_CMD;
 	conf.no_eln = UNSET;
 	conf.only_dirs = UNSET;
 	conf.pager = UNSET;
 	conf.pager_once = 0;
 	conf.pager_view = UNSET;
-	conf.print_dir_cmds = UNSET;
+	conf.print_dir_cmds = DEF_PRINT_DIR_CMDS;
 	conf.print_selfiles = UNSET;
-	conf.private_ws_settings = UNSET;
-	conf.prop_fields_gap = UNSET;
-	conf.purge_jumpdb = UNSET;
+	conf.private_ws_settings = DEF_PRIVATE_WS_SETTINGS;
+	conf.prompt_b_is_set = 0;
+	conf.prompt_b_min = DEF_PROMPT_B_MIN;
+	conf.prompt_b_precision = DEF_PROMPT_B_PRECISION;
+	conf.prompt_f_dir_len = DEF_PROMPT_F_DIR_LEN;
+	conf.prompt_f_full_len_dirs = DEF_PROMPT_F_FULL_LEN_DIRS;
+	conf.prompt_p_max_path = UNSET;
+	conf.prompt_is_multiline = 0;
+	conf.prop_fields_gap = DEF_PROP_FIELDS_GAP;
+	conf.purge_jumpdb = DEF_PURGE_JUMPDB;
 	conf.quoting_style = DEF_QUOTING_STYLE;
 	conf.read_autocmd_files = DEF_READ_AUTOCMD_FILES;
 	conf.read_dothidden = DEF_READ_DOTHIDDEN;
 	conf.readonly = DEF_READONLY;
-	conf.relative_time = UNSET;
+	conf.relative_time = DEF_RELATIVE_TIME;
 	conf.restore_last_path = UNSET;
-	conf.rm_force = UNSET;
-	conf.search_strategy = UNSET;
+	conf.rm_force = DEF_RM_FORCE;
+	conf.search_strategy = DEF_SEARCH_STRATEGY;
 	conf.share_selbox = UNSET;
 	conf.show_hidden = UNSET;
 	conf.skip_non_alnum_prefix = DEF_SKIP_NON_ALNUM_PREFIX;
 	conf.sort = UNSET;
 	conf.sort_reverse = 0;
 	conf.splash_screen = UNSET;
-	conf.suggest_filetype_color = UNSET;
+	conf.suggest_filetype_color = DEF_SUG_FILETYPE_COLOR;
 	conf.suggestions = UNSET;
 	conf.time_follows_sort = DEF_TIME_FOLLOWS_SORT;
 	conf.timestamp_mark = DEF_TIMESTAMP_MARK;
@@ -262,6 +275,7 @@ init_conf_struct(void)
 	conf.trim_names = UNSET;
 #ifndef _NO_TRASH
 	conf.tr_as_rm = UNSET;
+	conf.trash_force = DEF_TRASH_FORCE;
 #endif /* !_NO_TRASH */
 	conf.warning_prompt = UNSET;
 	conf.welcome_message = UNSET;
@@ -276,6 +290,7 @@ init_conf_struct(void)
 	conf.term = (char *)NULL;
 	conf.time_str = (char *)NULL;
 	conf.ptime_str = (char *)NULL;
+	conf.rprompt_str = (char *)NULL;
 	conf.usr_cscheme = (char *)NULL;
 	conf.wprompt_str = (char *)NULL;
 	conf.welcome_message_str = (char *)NULL;
@@ -1084,7 +1099,7 @@ load_jumpdb(void)
 
 		if (*line == '@') {
 			if (is_number(line + 1)) {
-				int a = atoi(line + 1);
+				const int a = atoi(line + 1);
 				jump_total_rank = a == INT_MIN ? 0 : a;
 			}
 			continue;
@@ -1547,9 +1562,11 @@ unset_prompt_values(const size_t n)
 {
 	prompts[n].name = (char *)NULL;
 	prompts[n].regular = (char *)NULL;
+	prompts[n].right = (char *)NULL;
 	prompts[n].warning = (char *)NULL;
 	prompts[n].notifications = DEF_PROMPT_NOTIF;
 	prompts[n].warning_prompt_enabled = DEF_WARNING_PROMPT;
+	prompts[n].multiline = 0;
 }
 
 static char *
@@ -1684,13 +1701,22 @@ load_prompts(void)
 				ret_len + 1, sizeof(char));
 			xstrsncpy(prompts[n].warning, ret, ret_len + 1);
 		}
+
+		if (strncmp(line, "RightPrompt=", 12) == 0) {
+			prompts[n].right = xnrealloc(prompts[n].right,
+				ret_len + 1, sizeof(char));
+			xstrsncpy(prompts[n].right, ret, ret_len + 1);
+			if (prompts[n].regular)
+				prompts[n].multiline =
+					strstr(prompts[n].regular, "\\n") ? 1 : 0;
+		}
 	}
 
 	free(line);
 	fclose(fp);
 
 	if (prompts[n].name) {
-		++n;
+		n++;
 		prompts[n].name = (char *)NULL;
 	}
 
@@ -1722,16 +1748,15 @@ unset_xargs(void)
 	xargs.color_scheme = UNSET;
 	xargs.color_lnk_as_target = UNSET;
 	xargs.colorize = UNSET;
-	xargs.columns = UNSET;
+	xargs.columned = UNSET;
 	xargs.config = UNSET;
 	xargs.cwd_in_title = UNSET;
 	xargs.desktop_notifications = UNSET;
-	xargs.dirmap = UNSET;
+	xargs.dirhist_map = UNSET;
 	xargs.disk_usage = UNSET;
 	xargs.disk_usage_analyzer = UNSET;
 	xargs.eln_use_workspace_color = UNSET;
-	xargs.ext = UNSET;
-	xargs.dirs_first = UNSET;
+	xargs.ext_cmd_ok = UNSET;
 	xargs.files_counter = UNSET;
 	xargs.follow_symlinks = UNSET;
 	xargs.follow_symlinks_long = UNSET;
@@ -1744,7 +1769,6 @@ unset_xargs(void)
 	xargs.fnftab = UNSET;
 	xargs.smenutab = UNSET;
 #endif /* !_NO_FZF */
-	xargs.hidden = UNSET;
 #ifndef _NO_HIGHLIGHT
 	xargs.highlight = UNSET;
 #endif /* !_NO_HIGHLIGHT */
@@ -1755,22 +1779,23 @@ unset_xargs(void)
 	xargs.icons_use_file_color = UNSET;
 #endif /* !_NO_ICONS */
 	xargs.int_vars = UNSET;
-	xargs.light = UNSET;
+	xargs.light_mode = UNSET;
 	xargs.list_and_quit = UNSET;
-	xargs.longview = UNSET;
+	xargs.list_dirs_first = UNSET;
+	xargs.long_view = UNSET;
 	xargs.lscolors = UNSET;
 	xargs.max_dirhist = UNSET;
-	xargs.max_path = UNSET;
 	xargs.mount_cmd = UNSET;
 	xargs.no_bold = UNSET;
 	xargs.no_dirjump = UNSET;
-	xargs.noeln = UNSET;
+	xargs.no_eln = UNSET;
 	xargs.only_dirs = UNSET;
 	xargs.open = UNSET;
 	xargs.pager = UNSET;
 	xargs.pager_view = UNSET;
 	xargs.path = UNSET;
-	xargs.printsel = UNSET;
+	xargs.print_selfiles = UNSET;
+	xargs.prompt_p_max_path = UNSET;
 	xargs.prop_fields_str = UNSET;
 	xargs.ptime_style = UNSET;
 	xargs.readonly = UNSET;
@@ -1783,10 +1808,11 @@ unset_xargs(void)
 	xargs.secure_cmds = UNSET;
 	xargs.sel_file = UNSET;
 	xargs.share_selbox = UNSET;
+	xargs.show_hidden = UNSET;
 	xargs.si = UNSET;
 	xargs.sort = UNSET;
 	xargs.sort_reverse = UNSET;
-	xargs.splash = UNSET;
+	xargs.splash_screen = UNSET;
 	xargs.stat = 0;
 	xargs.stealth_mode = UNSET;
 #ifndef _NO_SUGGESTIONS
@@ -2515,13 +2541,17 @@ get_aliases(void)
 			char *s = strchr(line, ' ');
 			if (!s || !*(++s))
 				continue;
+
 			char *p = strchr(s, '=');
 			if (!p || !*(p + 1))
 				continue;
+
 			*p = '\0';
 			p++;
 
-			if (alias_exists(s) == 1) continue;
+			if (alias_exists(s) == 1)
+				continue;
+
 			write_alias(s, p);
 		}
 	}
@@ -2748,22 +2778,10 @@ check_options(void)
 			conf.trim_names = xargs.trim_names;
 	}
 
-	if (conf.columned == UNSET)
-		conf.columned = DEF_COLUMNS;
-
 	conf.max_name_len_bk = conf.max_name_len;
 	if (conf.trim_names == 0)
 		conf.max_name_len = UNSET;
 
-	if (conf.relative_time == UNSET)
-		conf.relative_time = DEF_RELATIVE_TIME;
-
-	if (conf.cmd_desc_sug == UNSET)
-		conf.cmd_desc_sug = DEF_CMD_DESC_SUG;
-
-	if (conf.purge_jumpdb == UNSET)
-		conf.purge_jumpdb = DEF_PURGE_JUMPDB;
-
 	if (conf.fuzzy_match == UNSET) {
 		conf.fuzzy_match = xargs.fuzzy_match == UNSET
 			? DEF_FUZZY_MATCH : xargs.fuzzy_match;
@@ -2774,12 +2792,6 @@ check_options(void)
 			? DEF_FUZZY_MATCH_ALGO : xargs.fuzzy_match_algo;
 	}
 
-	if (conf.private_ws_settings == UNSET)
-		conf.private_ws_settings = DEF_PRIVATE_WS_SETTINGS;
-
-	if (conf.rm_force == UNSET)
-		conf.rm_force = DEF_RM_FORCE;
-
 	if (conf.desktop_notifications == UNSET) {
 		if (xargs.desktop_notifications == UNSET)
 			conf.desktop_notifications = DEF_DESKTOP_NOTIFICATIONS;
@@ -2787,17 +2799,11 @@ check_options(void)
 			conf.desktop_notifications = xargs.desktop_notifications;
 	}
 
-	if (conf.prop_fields_gap == UNSET)
-		conf.prop_fields_gap = DEF_PROP_FIELDS_GAP;
-
 	if (!*prop_fields_str)
 		xstrsncpy(prop_fields_str, DEF_PROP_FIELDS, sizeof(prop_fields_str));
 	set_prop_fields(prop_fields_str);
 	check_time_str();
 
-	if (conf.search_strategy == UNSET)
-		conf.search_strategy = DEF_SEARCH_STRATEGY;
-
 	if (xargs.eln_use_workspace_color == UNSET)
 		xargs.eln_use_workspace_color = DEF_ELN_USE_WORKSPACE_COLOR;
 
@@ -2807,11 +2813,6 @@ check_options(void)
 	if (print_removed_files == UNSET)
 		print_removed_files = DEF_PRINT_REMOVED_FILES;
 
-	if (xargs.bell_style == UNSET)
-		bell = DEF_BELL_STYLE;
-	else
-		bell = xargs.bell_style;
-
 	if (xargs.refresh_on_resize == UNSET)
 		xargs.refresh_on_resize = DEF_REFRESH_ON_RESIZE;
 
@@ -2846,35 +2847,11 @@ check_options(void)
 	if (xargs.secure_env_full == UNSET)
 		xargs.secure_env_full = DEF_SECURE_ENV_FULL;
 
-	if (conf.cp_cmd == UNSET)
-		conf.cp_cmd = DEF_CP_CMD;
-
-	if (check_cap == UNSET)
-		check_cap = DEF_CHECK_CAP;
-
-	if (check_ext == UNSET)
-		check_ext = DEF_CHECK_EXT;
-
-	if (follow_symlinks == UNSET)
-		follow_symlinks = DEF_FOLLOW_SYMLINKS;
-
-	if (conf.mv_cmd == UNSET)
-		conf.mv_cmd = DEF_MV_CMD;
-
-	if (conf.min_name_trim == UNSET)
-		conf.min_name_trim = DEF_MIN_NAME_TRIM;
-
-	if (conf.min_jump_rank == UNSET2)
-		conf.min_jump_rank = DEF_MIN_JUMP_RANK;
-
-	if (conf.max_jump_total_rank == UNSET)
-		conf.max_jump_total_rank = DEF_MAX_JUMP_TOTAL_RANK;
-
 	if (conf.no_eln == UNSET) {
-		if (xargs.noeln == UNSET)
+		if (xargs.no_eln == UNSET)
 			conf.no_eln = DEF_NOELN;
 		else
-			conf.no_eln = xargs.noeln;
+			conf.no_eln = xargs.no_eln;
 	}
 
 	if (prompt_notif == UNSET)
@@ -2943,7 +2920,8 @@ check_options(void)
 		if (conf.colorize == 1 || !getenv("FZF_DEFAULT_OPTS")) {
 			if (conf.colorize == 1) {
 				conf.fzftab_options =
-					savestring(DEF_FZFTAB_OPTIONS, sizeof(DEF_FZFTAB_OPTIONS) - 1);
+					savestring(DEF_FZFTAB_OPTIONS,
+					sizeof(DEF_FZFTAB_OPTIONS) - 1);
 			} else {
 				conf.fzftab_options =
 					savestring(DEF_FZFTAB_OPTIONS_NO_COLOR,
@@ -3004,28 +2982,15 @@ check_options(void)
 
 	if (!conf.suggestion_strategy)
 		conf.suggestion_strategy = savestring(DEF_SUG_STRATEGY, SUG_STRATS);
-
-	if (conf.suggest_filetype_color == UNSET)
-		conf.suggest_filetype_color = DEF_SUG_FILETYPE_COLOR;
 #endif /* _NO_SUGGESTIONS */
 
-	if (int_vars == UNSET) {
-		if (xargs.int_vars == UNSET)
-			int_vars = DEF_INT_VARS;
-		else
-			int_vars = xargs.int_vars;
-	}
-
 	if (conf.print_selfiles == UNSET) {
-		if (xargs.printsel == UNSET)
+		if (xargs.print_selfiles == UNSET)
 			conf.print_selfiles = DEF_PRINTSEL;
 		else
-			conf.print_selfiles = xargs.printsel;
+			conf.print_selfiles = xargs.print_selfiles;
 	}
 
-	if (conf.max_printselfiles == UNSET2) /* -1 (UNSET) is a valid value */
-		conf.max_printselfiles = DEF_MAX_PRINTSEL;
-
 	if (conf.case_sens_list == UNSET) {
 		if (xargs.case_sens_list == UNSET)
 			conf.case_sens_list = DEF_CASE_SENS_LIST;
@@ -3033,9 +2998,6 @@ check_options(void)
 			conf.case_sens_list = xargs.case_sens_list;
 	}
 
-	if (conf.case_sens_search == UNSET)
-		conf.case_sens_search = DEF_CASE_SENS_SEARCH;
-
 	if (conf.case_sens_dirjump == UNSET) {
 		if (xargs.case_sens_dirjump == UNSET)
 			conf.case_sens_dirjump = DEF_CASE_SENS_DIRJUMP;
@@ -3067,10 +3029,10 @@ check_options(void)
 	}
 
 	if (conf.splash_screen == UNSET) {
-		if (xargs.splash == UNSET)
+		if (xargs.splash_screen == UNSET)
 			conf.splash_screen = DEF_SPLASH_SCREEN;
 		else
-			conf.splash_screen = xargs.splash;
+			conf.splash_screen = xargs.splash_screen;
 	}
 
 	if (conf.welcome_message == UNSET) {
@@ -3081,10 +3043,10 @@ check_options(void)
 	}
 
 	if (conf.show_hidden == UNSET) {
-		if (xargs.hidden == UNSET)
+		if (xargs.show_hidden == UNSET)
 			conf.show_hidden = DEF_SHOW_HIDDEN;
 		else
-			conf.show_hidden = xargs.hidden;
+			conf.show_hidden = xargs.show_hidden;
 	}
 
 	if (conf.files_counter == UNSET) {
@@ -3095,17 +3057,17 @@ check_options(void)
 	}
 
 	if (conf.long_view == UNSET) {
-		if (xargs.longview == UNSET)
+		if (xargs.long_view == UNSET)
 			conf.long_view = DEF_LONG_VIEW;
 		else
-			conf.long_view = xargs.longview;
+			conf.long_view = xargs.long_view;
 	}
 
 	if (conf.ext_cmd_ok == UNSET) {
-		if (xargs.ext == UNSET)
+		if (xargs.ext_cmd_ok == UNSET)
 			conf.ext_cmd_ok = DEF_EXT_CMD_OK;
 		else
-			conf.ext_cmd_ok = xargs.ext;
+			conf.ext_cmd_ok = xargs.ext_cmd_ok;
 	}
 
 	if (conf.pager == UNSET) {
@@ -3130,10 +3092,10 @@ check_options(void)
 	}
 
 	if (conf.list_dirs_first == UNSET) {
-		if (xargs.dirs_first == UNSET)
+		if (xargs.list_dirs_first == UNSET)
 			conf.list_dirs_first = DEF_LIST_DIRS_FIRST;
 		else
-			conf.list_dirs_first = xargs.dirs_first;
+			conf.list_dirs_first = xargs.list_dirs_first;
 	}
 
 	if (conf.autols == UNSET) {
@@ -3143,24 +3105,23 @@ check_options(void)
 			conf.autols = xargs.autols;
 	}
 
-	if (conf.max_path == UNSET) {
-		if (xargs.max_path == UNSET)
-			conf.max_path = DEF_MAX_PATH;
+	if (xargs.prompt_p_max_path != UNSET)
+		err('n', PRINT_PROMPT, "%s: --max-path: This option is "
+			"deprecated. Use the CLIFM_PROMPT_P_MAX_PATH environment "
+			"variable instead.\n", PROGRAM_NAME);
+
+	if (conf.prompt_p_max_path == UNSET) {
+		if (xargs.prompt_p_max_path == UNSET)
+			conf.prompt_p_max_path = DEF_PROMPT_P_MAX_PATH;
 		else
-			conf.max_path = xargs.max_path;
+			conf.prompt_p_max_path = xargs.prompt_p_max_path;
 	}
 
-	if (conf.log_msgs == UNSET)
-		conf.log_msgs = DEF_LOG_MSGS;
-
-	if (conf.log_cmds == UNSET)
-		conf.log_cmds = DEF_LOG_CMDS;
-
 	if (conf.light_mode == UNSET) {
-		if (xargs.light == UNSET)
+		if (xargs.light_mode == UNSET)
 			conf.light_mode = DEF_LIGHT_MODE;
 		else
-			conf.light_mode = xargs.light;
+			conf.light_mode = xargs.light_mode;
 	}
 
 	if (conf.classify == UNSET) {
@@ -3220,10 +3181,10 @@ check_options(void)
 	}
 
 	if (conf.dirhist_map == UNSET) {
-		if (xargs.dirmap == UNSET)
+		if (xargs.dirhist_map == UNSET)
 			conf.dirhist_map = DEF_DIRHIST_MAP;
 		else
-			conf.dirhist_map = xargs.dirmap;
+			conf.dirhist_map = xargs.dirhist_map;
 	}
 
 	if (conf.disk_usage == UNSET) {
@@ -3240,33 +3201,6 @@ check_options(void)
 			conf.restore_last_path = xargs.restore_last_path;
 	}
 
-	if (conf.max_hist == UNSET)
-		conf.max_hist = DEF_MAX_HIST;
-
-	if (conf.max_log == UNSET)
-		conf.max_log = DEF_MAX_LOG;
-
-	/* This block was needed when Shell was an option in the config file.
-	 * Let's keep it in case we readd this option. For the time being, the
-	 * shell used to run external commands is set via environment variables,
-	 * either CLIFM_SHELL, or SHELL. */
-/*	if (!user.shell) {
-		struct user_t tmp_user = get_user_data();
-		user.shell = tmp_user.shell;
-
-		// We don't need these values of the user struct: free them
-		free(tmp_user.name);
-		free(tmp_user.home);
-		free(tmp_user.groups);
-
-		if (!user.shell)
-			user.shell = savestring(FALLBACK_SHELL, sizeof(FALLBACK_SHELL) - 1);
-
-		free(user.shell_basename);
-		user.shell_basename = (char *)NULL;
-		shell = get_sys_shell();
-	} */
-
 	if (!conf.term)
 		conf.term = savestring(DEF_TERM_CMD, sizeof(DEF_TERM_CMD) - 1);
 
@@ -3285,6 +3219,8 @@ check_options(void)
 		}
 	}
 
+	set_prompt_options();
+
 	if (!conf.wprompt_str) {
 		if (conf.colorize == 1)
 			conf.wprompt_str = savestring(DEF_WPROMPT_STR, sizeof(DEF_WPROMPT_STR) - 1);
