@@ -145,16 +145,7 @@ kbinds_edit(char *app)
 
 	const time_t mtime_bfr = attr.st_mtime;
 
-	int ret = FUNC_SUCCESS;
-	if (app && *app) {
-		char *cmd[] = {app, kbinds_file, NULL};
-		ret = launch_execv(cmd, FOREGROUND, E_NOFLAG);
-	} else {
-		open_in_foreground = 1;
-		ret = open_file(kbinds_file);
-		open_in_foreground = 0;
-	}
-
+	const int ret = open_config_file(app, kbinds_file);
 	if (ret != FUNC_SUCCESS)
 		return ret;
 
@@ -328,7 +319,7 @@ rl_update_prompt_old(void)
 }
 #endif /* __HAIKU__ || !_NO_PROFILES */
 
-/* Runs any command recognized by CliFM via a keybind. Example:
+/* Runs any command recognized by Clifm via a keybind. Example:
  * keybind_exec_cmd("sel *") */
 int
 keybind_exec_cmd(char *str)
@@ -346,7 +337,7 @@ keybind_exec_cmd(char *str)
 	putchar('\n');
 
 	if (cmd) {
-		exit_status = exec_cmd(cmd);
+		exit_status = exec_cmd_tm(cmd);
 
 		/* While in the bookmarks or mountpoints screen, the kbind_busy
 		 * flag will be set to 1 and no keybinding will work. Once the
@@ -810,18 +801,24 @@ rl_accept_suggestion(int count, int key)
 	case TAGT_SUG: /* fallthrough */
 	case TAGC_SUG: /* fallthrough */
 	case TAGS_SUG: /* fallthrough */
+	case WS_PREFIX_SUG: /* fallthrough */
+	case WS_NUM_PREFIX_SUG:
 	case BM_PREFIX_SUG: {
-		char prefix[3];
+		char prefix[3]; prefix[0] = '\0';
 		if (suggestion.type == TAGC_SUG) {
 			prefix[0] = ':'; prefix[1] = '\0';
 		} else if (suggestion.type == TAGT_SUG) {
 			prefix[0] = 't'; prefix[1] = ':'; prefix[2] = '\0';
 		} else if (suggestion.type == BM_PREFIX_SUG) {
 			prefix[0] = 'b'; prefix[1] = ':'; prefix[2] = '\0';
+		} else if (suggestion.type == WS_PREFIX_SUG
+		|| suggestion.type == WS_NUM_PREFIX_SUG) {
+			prefix[0] = 'w'; prefix[1] = ':'; prefix[2] = '\0';
 		}
 
 		rl_insert_text(prefix);
-		char *p = suggestion.type != BM_PREFIX_SUG
+		char *p = (suggestion.type != BM_PREFIX_SUG
+			&& suggestion.type != WS_PREFIX_SUG)
 			? escape_str(suggestion_buf) : (char *)NULL;
 
 		my_insert_text(p ? p : suggestion_buf, NULL, 0);
@@ -1207,7 +1204,7 @@ static int
 rl_clear_line(int count, int key)
 {
 	UNUSED(count); UNUSED(key);
-	if (kbind_busy == 1 && xrename == 0)
+	if (kbind_busy == 1 && alt_prompt == 0)
 		return FUNC_SUCCESS;
 
 	words_num = 0;
@@ -1781,7 +1778,7 @@ run_plugin(const int num)
 
 	char cmd[MAX_INT_STR + 7];
 	snprintf(cmd, sizeof(cmd), "plugin%d", num);
-	int ret = run_kb_cmd(cmd);
+	const int ret = run_kb_cmd(cmd);
 
 	unsetenv("CLIFM_LINE");
 
@@ -1816,6 +1813,90 @@ rl_plugin4(int count, int key)
 	return run_plugin(4);
 }
 
+static int
+rl_plugin5(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(5);
+}
+
+static int
+rl_plugin6(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(6);
+}
+
+static int
+rl_plugin7(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(7);
+}
+
+static int
+rl_plugin8(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(8);
+}
+
+static int
+rl_plugin9(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(9);
+}
+
+static int
+rl_plugin10(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(10);
+}
+
+static int
+rl_plugin11(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(11);
+}
+
+static int
+rl_plugin12(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(12);
+}
+
+static int
+rl_plugin13(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(13);
+}
+
+static int
+rl_plugin14(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(14);
+}
+
+static int
+rl_plugin15(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(15);
+}
+
+static int
+rl_plugin16(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return run_plugin(16);
+}
+
 static int
 rl_launch_view(int count, int key)
 {
@@ -2300,6 +2381,18 @@ set_keybinds_from_file(void)
 	rl_bind_keyseq(find_key("plugin2"), rl_plugin2);
 	rl_bind_keyseq(find_key("plugin3"), rl_plugin3);
 	rl_bind_keyseq(find_key("plugin4"), rl_plugin4);
+	rl_bind_keyseq(find_key("plugin5"), rl_plugin5);
+	rl_bind_keyseq(find_key("plugin6"), rl_plugin6);
+	rl_bind_keyseq(find_key("plugin7"), rl_plugin7);
+	rl_bind_keyseq(find_key("plugin8"), rl_plugin8);
+	rl_bind_keyseq(find_key("plugin9"), rl_plugin9);
+	rl_bind_keyseq(find_key("plugin10"), rl_plugin10);
+	rl_bind_keyseq(find_key("plugin11"), rl_plugin11);
+	rl_bind_keyseq(find_key("plugin12"), rl_plugin12);
+	rl_bind_keyseq(find_key("plugin13"), rl_plugin13);
+	rl_bind_keyseq(find_key("plugin14"), rl_plugin14);
+	rl_bind_keyseq(find_key("plugin15"), rl_plugin15);
+	rl_bind_keyseq(find_key("plugin16"), rl_plugin16);
 }
 
 static void
