@@ -182,8 +182,9 @@ init_checks_struct(void)
 		0;
 #endif /* !_NO_ICONS */
 
-	checks.id_names = (conf.long_view == 1 && prop_fields.ids == PROP_ID_NAME);
-	checks.lnk_char = (conf.color_lnk_as_target == 1 && follow_symlinks == 1
+	checks.id_names = (prop_fields.ids == PROP_ID_NAME
+		&& (conf.long_view == 1 || conf.sort == SOWN || conf.sort == SGRP));
+	checks.lnk_char = (conf.color_lnk_as_target == 1 && conf.follow_symlinks == 1
 		&& conf.icons == 0 && conf.light_mode == 0);
 	checks.min_name_trim = (conf.long_view == 1 && conf.max_name_len != UNSET
 		&& conf.min_name_trim > conf.max_name_len);
@@ -266,8 +267,8 @@ is_utf8_name(const char *name, size_t *bytes)
 #else /* char is signed (X86) */
 		/* If UTF-8 char, the first byte is >= 0xC0, whose decimal
 		 * value is 192, which is bigger than CHAR_MAX if char is signed,
-		 * becoming thus a negative value. In this way, the above two-steps
-		 * check can be written using a single comparison. */
+		 * becoming thus a negative value. In this way, the above three-steps
+		 * check can be written using only two checks. */
 		if (*name < ' ' || *name == 127)
 #endif /* CHAR_MIN >= 0 */
 			is_utf8 = 1;
@@ -279,6 +280,18 @@ is_utf8_name(const char *name, size_t *bytes)
 	return is_utf8;
 }
 
+/* Return the amount of ASCII/UTF-8 characters in the string S. */
+static size_t
+count_utf8_chars(const char *s)
+{
+	size_t count = 0;
+
+	for (; *s; s++)
+		count += ((*s & 0xc0) != 0x80);
+
+	return count;
+}
+
 /* Set the color of the dividing line: DL, is the color code is set,
  * or the color of the current workspace if not */
 static void
@@ -289,25 +302,29 @@ set_div_line_color(void)
 		return;
 	}
 
-	/* If div line color isn't set, use the current workspace color */
+	const char *def_color = term_caps.color >= 256 ? DEF_DL_C256 : DEF_DL_C;
+
+	/* If div line color isn't set, use the current workspace color. */
 	switch (cur_ws) {
-	case 0: fputs(*ws1_c ? ws1_c : DEF_DL_C, stdout); break;
-	case 1: fputs(*ws2_c ? ws2_c : DEF_DL_C, stdout); break;
-	case 2: fputs(*ws3_c ? ws3_c : DEF_DL_C, stdout); break;
-	case 3: fputs(*ws4_c ? ws4_c : DEF_DL_C, stdout); break;
-	case 4: fputs(*ws5_c ? ws5_c : DEF_DL_C, stdout); break;
-	case 5: fputs(*ws6_c ? ws6_c : DEF_DL_C, stdout); break;
-	case 6: fputs(*ws7_c ? ws7_c : DEF_DL_C, stdout); break;
-	case 7: fputs(*ws8_c ? ws8_c : DEF_DL_C, stdout); break;
-	default: fputs(DEF_DL_C, stdout); break;
+	case 0: fputs(*ws1_c ? ws1_c : def_color, stdout); break;
+	case 1: fputs(*ws2_c ? ws2_c : def_color, stdout); break;
+	case 2: fputs(*ws3_c ? ws3_c : def_color, stdout); break;
+	case 3: fputs(*ws4_c ? ws4_c : def_color, stdout); break;
+	case 4: fputs(*ws5_c ? ws5_c : def_color, stdout); break;
+	case 5: fputs(*ws6_c ? ws6_c : def_color, stdout); break;
+	case 6: fputs(*ws7_c ? ws7_c : def_color, stdout); break;
+	case 7: fputs(*ws8_c ? ws8_c : def_color, stdout); break;
+	default: fputs(def_color, stdout); break;
 	}
 }
 
-/* Print the line divinding files and prompt using DIV_LINE. If
- * DIV_LINE takes more than two columns to be printed (ASCII chars
- * take only one, but unicode chars could take two), print exactly the
- * content of DIV_LINE. Otherwise, repeat DIV_LINE to fulfill
- * all terminal columns. If DIV_LINE is '0', print no line at all */
+/* Print the line dividing files and prompt using DIV_LINE.
+ * If DIV_LINE is unset, draw a line using box-drawing characters.
+ * If it contains exactly one character, print DIV_LINE up to the
+ * right screen edge.
+ * If it contains more than one character, print exactly the
+ * content of DIV_LINE.
+ * If it is "0", print an empty line. */
 static void
 print_div_line(void)
 {
@@ -319,30 +336,28 @@ print_div_line(void)
 	if (conf.colorize == 1)
 		set_div_line_color();
 
-	if (!*div_line) { /* Let's draw the line with box drawing chars */
+	if (!*div_line) {
 		fputs("\x1b(0m", stdout);
-		int k;
-		for (k = 0; k < (int)term_cols - 2; k++)
+		int i;
+		for (i = 0; i < (int)term_cols - 2; i++)
 			putchar('q');
 		fputs("\x1b(0j\x1b(B", stdout);
 		putchar('\n');
 	} else if (*div_line == '0' && !div_line[1]) {
-		/* No line */
 		putchar('\n');
 	} else {
-		/* Custom line */
-		const size_t len = wc_xstrlen(div_line);
-		if (len <= 2) {
+		const size_t c = count_utf8_chars(div_line);
+		if (c > 1) {
+			puts(div_line);
+		} else {
 			/* Extend DIV_LINE to the end of the screen - 1.
 			 * We substract 1 to prevent an extra empty line after the
-			 * dividing line in some terminals (e.g. cons25). */
-			int i = len > 0 ? (int)(term_cols / len) : 0;
+			 * dividing line on some terminals (e.g. cons25). */
+			const size_t len = !div_line[1] ? 1 : wc_xstrlen(div_line);
+			int i = c > 0 ? (int)(term_cols / len) : 0;
 			for (; i > 1; i--)
 				fputs(div_line, stdout);
 			putchar('\n');
-		} else {
-			/* Print DIV_LINE exactly */
-			puts(div_line);
 		}
 	}
 
@@ -621,8 +636,9 @@ post_listing(DIR *dir, const int reset_pager, const filesn_t excluded_files)
 		conf.pager = 0;
 	}
 
-	if (pager_quit == 0 && max_files != UNSET && files > (filesn_t)max_files)
-		printf("... (%d/%jd)\n", max_files, (intmax_t)files);
+	if (pager_quit == 0 && conf.max_files != UNSET
+	&& files > (filesn_t)conf.max_files)
+		printf("... (%d/%jd)\n", conf.max_files, (intmax_t)files);
 
 	print_div_line();
 
@@ -787,8 +803,8 @@ set_events_checker(void)
 static void
 get_longest_filename(const filesn_t n, const size_t pad)
 {
-	const filesn_t c_max_files = (filesn_t)max_files;
-	filesn_t i = (max_files != UNSET && c_max_files < n) ? c_max_files : n;
+	const filesn_t c_max_files = (filesn_t)conf.max_files;
+	filesn_t i = (conf.max_files != UNSET && c_max_files < n) ? c_max_files : n;
 	filesn_t longest_index = -1;
 
 	/* Cast only once here instead of hundreds of times in the while loop. */
@@ -845,7 +861,7 @@ get_longest_filename(const filesn_t n, const size_t pad)
 
 		if (total_len > longest.name_len) {
 			longest_index = i;
-			if (conf.listing_mode == VERTLIST || max_files == UNSET
+			if (conf.listing_mode == VERTLIST || conf.max_files == UNSET
 			|| i < c_max_files)
 				longest.name_len = total_len;
 		}
@@ -943,7 +959,7 @@ compute_maxes(void)
 {
 	struct maxes_t maxes = {0};
 	filesn_t i = xargs.max_files > 0 ? (filesn_t)xargs.max_files
-		: (max_files > 0 ? max_files : files);
+		: (conf.max_files > 0 ? conf.max_files : files);
 
 	while (--i >= 0) {
 		int t = 0;
@@ -1055,7 +1071,7 @@ print_long_mode(size_t *counter, int *reset_pager, const int pad,
 
 	filesn_t i, k = files;
 	for (i = 0; i < k; i++) {
-		if (max_files != UNSET && i == max_files)
+		if (conf.max_files != UNSET && i == conf.max_files)
 			break;
 
 		if (conf.pager == 1 || (*reset_pager == 0 && conf.pager > 1
@@ -1644,8 +1660,8 @@ static void
 list_files_horizontal(size_t *counter, int *reset_pager,
 	const int pad, const size_t columns_n)
 {
-	const filesn_t nn = (max_files != UNSET && (filesn_t)max_files < files)
-		? (filesn_t)max_files : files;
+	const filesn_t nn = (conf.max_files != UNSET
+		&& (filesn_t)conf.max_files < files) ? (filesn_t)conf.max_files : files;
 
 	void (*print_entry_function)(int *, const filesn_t, const int, const int);
 	if (conf.colorize == 1)
@@ -1740,8 +1756,8 @@ list_files_vertical(size_t *counter, int *reset_pager,
 	const int pad, const size_t columns_n)
 {
 	/* Total amount of files to be listed. */
-	const filesn_t nn = (max_files != UNSET && (filesn_t)max_files < files)
-		? (filesn_t)max_files : files;
+	const filesn_t nn = (conf.max_files != UNSET
+		&& (filesn_t)conf.max_files < files) ? (filesn_t)conf.max_files : files;
 
 	/* How many lines (rows) do we need to print NN files? */
 	/* Division/modulo is slow, true. But the compiler will make a much
@@ -2434,8 +2450,8 @@ list_dir_light(void)
 		goto END;
 	}
 
-	const int pad = (max_files != UNSET && files > (filesn_t)max_files)
-		? DIGINUM(max_files) : DIGINUM(files);
+	const int pad = (conf.max_files != UNSET && files > (filesn_t)conf.max_files)
+		? DIGINUM(conf.max_files) : DIGINUM(files);
 
 	if (conf.sort != SNONE)
 		ENTSORT(file_info, (size_t)n, entrycmp);
@@ -2628,7 +2644,8 @@ load_file_gral_info(const struct stat *a, const filesn_t n)
 		get_id_names(n);
 
 #if defined(LINUX_FILE_XATTRS)
-	if (file_info[n].type != DT_LNK && (checks.xattr == 1 || check_cap == 1)
+	if (file_info[n].type != DT_LNK
+	&& (checks.xattr == 1 || conf.check_cap == 1)
 	&& listxattr(file_info[n].name, NULL, 0) > 0)
 		file_info[n].xattr = 1;
 #endif /* LINUX_FILE_XATTRS */
@@ -2656,7 +2673,7 @@ load_file_gral_info(const struct stat *a, const filesn_t n)
 			case SATIME: file_info[n].ltime = a->st_atime; break;
 			case SBTIME: file_info[n].ltime = btime; break;
 			case SCTIME: file_info[n].ltime = a->st_ctime; break;
-			case SMTIME: file_info[n].ltime = a->st_mtime; break;
+			case SMTIME: /* fallthrough */
 			default: file_info[n].ltime = a->st_mtime; break;
 			}
 		} else {
@@ -2730,7 +2747,7 @@ load_link_info(const int fd, const filesn_t n)
 	file_info[n].icon = ICON_LINK;
 #endif // !_NO_ICONS
 
-	if (follow_symlinks == 0) {
+	if (conf.follow_symlinks == 0) {
 		file_info[n].color = ln_c;
 		return;
 	}
@@ -2863,7 +2880,7 @@ load_regfile_info(const struct stat *a, const filesn_t n)
 #endif /* !_NO_ICONS */
 
 	/* Check file extension */
-	char *ext = (override_color == 1 && check_ext == 1)
+	char *ext = (override_color == 1 && conf.check_ext == 1)
 		? strrchr(file_info[n].name, '.') : (char *)NULL;
 
 	if (!ext || ext == file_info[n].name || !*(ext + 1))
@@ -3001,7 +3018,7 @@ list_dir(void)
 	file_info = xnmalloc(ENTRY_N + 2, sizeof(struct fileinfo));
 
 	const int stat_flag =
-		(follow_symlinks == 1 && conf.long_view == 1
+		(conf.follow_symlinks == 1 && conf.long_view == 1
 		&& conf.follow_symlinks_long == 1) ? 0 : AT_SYMLINK_NOFOLLOW;
 
 	while ((ent = readdir(dir))) {
@@ -3067,7 +3084,7 @@ list_dir(void)
 		}
 
 		if (conf.only_dirs == 1 && stat_ok == 1 && !S_ISDIR(attr.st_mode)
-		&& (follow_symlinks == 0 || !S_ISLNK(attr.st_mode)
+		&& (conf.follow_symlinks == 0 || !S_ISLNK(attr.st_mode)
 		|| get_link_ref(ename) != S_IFDIR)) {
 			excluded_files++;
 			continue;
@@ -3181,8 +3198,8 @@ list_dir(void)
 		goto END;
 	}
 
-	const int pad = (max_files != UNSET && files > (filesn_t)max_files)
-		? DIGINUM(max_files) : DIGINUM(files);
+	const int pad = (conf.max_files != UNSET && files > (filesn_t)conf.max_files)
+		? DIGINUM(conf.max_files) : DIGINUM(files);
 
 		/* #############################################
 		 * #    SORT FILES ACCORDING TO SORT METHOD    #
