@@ -114,7 +114,8 @@ const struct sort_t sort_methods[] = {
     {"group", 11, 0},
     {"blocks", 12, 0},
     {"links", 13, 0},
-    {NULL, 14, 0},
+    {"type", 14, 0},
+    {NULL, 15, 0},
 };
 
 /* pmsg holds the current program message type */
@@ -124,6 +125,7 @@ enum tab_mode tabmode = STD_TAB;
 
 struct param_t xargs = {0};
 unsigned short term_cols;
+double last_cmd_time = 0;
 
 /* Bit flag holders */
 int
@@ -148,16 +150,12 @@ regex_t regex_dirhist;
 
 /* Internal status flags */
 int
+	alt_prompt = 0,
 	argc_bk = 0,
 	autocmd_set = 0,
-	autojump = UNSET,
-	bell = UNSET,
 	bg_proc = 0,
-	check_cap = UNSET,
-	check_ext = UNSET,
 	cmdhist_flag = 0,
 	config_ok = 1,
-	control_d_exits = 0,
 	cur_ws = UNSET,
 	curcol = 0,
 	dequoted = 0,
@@ -165,33 +163,28 @@ int
 	dirhist_cur_index = 0,
 	dirhist_total_index = 0,
 	exit_code = 0,
-	follow_symlinks = UNSET,
+
 	fzftab = UNSET,
 	fzf_border_type = UNSET,
 	fzf_height_set = 0,
 	fzf_preview_border_type = 0,
+
 	hist_status = UNSET,
 	home_ok = 1,
-	int_vars = UNSET,
 	internal_cmd = 0,
 	is_sel = 0,
 	is_cdpath = 0,
 	jump_total_rank = 0,
 	kbind_busy = 0,
-	list_dirs_first = UNSET,
-	max_files = UNSET,
-	mime_match = 0,
 	nesting_level = 0,
 	no_log = 0,
 	open_in_foreground = 0,
 	prev_ws = UNSET,
 	print_msg = 0,
-	print_selfiles = UNSET,
 	print_removed_files = UNSET,
 	prompt_offset = UNSET,
 	prompt_notif = UNSET,
 	recur_perm_error_flag = 0,
-
 	rl_nohist = 0,
 	rl_notab = 0,
 	sel_is_last = 0,
@@ -205,8 +198,7 @@ int
 	trash_ok = 1,
 #endif /* !_NO_TRASH */
 	virtual_dir = 0,
-	wrong_cmd = 0,
-	xrename = 0;
+	wrong_cmd = 0;
 
 filesn_t files = 0;
 
@@ -286,6 +278,7 @@ char
 	*msgs_log_file = (char *)NULL,
 	*pinned_dir = (char *)NULL,
 	*plugins_dir = (char *)NULL,
+	*plugins_helper_file = (char *)NULL,
 	*profile_file = (char *)NULL,
 	*prompts_file = (char *)NULL,
 	*quote_chars = (char *)NULL,
@@ -776,6 +769,7 @@ const struct cmdslist_t param_str[] = {
 	{"st extension", 12},
 	{"st inode", 8},
 	{"st version", 10},
+	{"st type", 7},
 	{"sort none", 9},
 	{"sort name", 9},
 	{"sort blocks", 11},
@@ -790,6 +784,7 @@ const struct cmdslist_t param_str[] = {
 	{"sort extension", 14},
 	{"sort inode", 10},
 	{"sort version", 12},
+	{"sort type", 9},
 	{"st rev", 6},
 	{"sort rev", 8},
 	{"t list", 6},
@@ -915,7 +910,7 @@ run_main_loop(void)
 		if (alias_cmd) {
 			/* If an alias is found, check_for_alias() frees CMD and returns
 			 * ALIAS_CMD in its place to be executed by exec_cmd() */
-			exec_cmd(alias_cmd);
+			exec_cmd_tm(alias_cmd);
 
 			for (i = 0; alias_cmd[i]; i++)
 				free(alias_cmd[i]);
@@ -924,7 +919,7 @@ run_main_loop(void)
 		}
 
 		if (!(flags & FAILED_ALIAS))
-			exec_cmd(cmd);
+			exec_cmd_tm(cmd);
 		flags &= ~FAILED_ALIAS;
 
 		i = (int)args_n + 1;
