@@ -206,7 +206,7 @@ operation).\n\n\
   or, if autocd is enabled (default)\n\
     /var"
 
-#define COLORS_USAGE "Print the list of currently used color codes\n\n\
+#define COLORS_USAGE "Preview the current color scheme\n\n\
 \x1b[1mUSAGE\x1b[0m\n\
   colors"
 
@@ -841,7 +841,8 @@ or short). Use PagerView in the configuration file (or --pager-view in\n\
 the command line) to force the use of a specific mode. Possibles values:\n\n\
 'auto': Use the current listing mode (default)\n\
 'long': List files in long view\n\
-'short': List files in short view"
+'short': List files in short view\n\n\
+Note: You can also try the 'gg' plugin (just enter 'gg')."
 
 #define PC_USAGE "Interactively edit files permissions\n\n\
 \x1b[1mUSAGE\x1b[0m\n\
@@ -1027,15 +1028,15 @@ Recognized file types: (d)irectory, regular (f)ile, symbolic (l)ink,\n\
 
 #define SORT_USAGE "Change files sorting order\n\n\
 \x1b[1mUSAGE\x1b[0m\n\
-  st [METHOD] [rev]\nMETHOD: 0 = none, \
-1 = name, 2 = size, 3 = atime, 4 = btime, \n5 = ctime, \
-6 = mtime, 7 = version, 8 = extension, 9 = inode,\n\
-10 = owner, 11 = group, 12 = blocks, 13 = links\n\
-Note: Both numbers and names are allowed.\n\n\
+  st [METHOD] [rev]\n\n\
+Available methods: 0=none, 1=name, 2=size, 3=atime, 4=btime,\n\
+5=ctime, 6=mtime, 7=version, 8=extension, 9=inode, 10=owner,\n\
+11=group, 12=blocks, 13=links, and 14=type.\n\n\
 \x1b[1mEXAMPLES\x1b[0m\n\
 - List files by size\n\
     st size (or 'st <TAB>' to choose from a list)\n\
-- Revert the current sorting order (i.e. z-a instead of a-z)\n\
+    Sort numbers can be used as well (e.g. 'st 2')\n\
+- Revert the current sorting order (e.g. z-a instead of a-z)\n\
     st rev"
 
 #define TAG_USAGE "(Un)tag files and/or directories\n\n\
@@ -1101,7 +1102,7 @@ Mark the files you need via TAB and then press Enter or Right."
 - Set the executable bit on all selected files\n\
    te sel"
 
-#define TRASH_USAGE "Send one or multiple files to the trash can\n\n\
+#define TRASH_USAGE "Move files to the trash can\n\n\
 \x1b[1mUSAGE\x1b[0m\n\
   t, trash [FILE... | del | empty | list]\n\n\
 \x1b[1mEXAMPLES\x1b[0m\n\
@@ -1171,6 +1172,7 @@ Note: Use the 'trash' command to trash files. Try 'trash --help'."
     view edit (or F7)\n\
 - Edit the configuration file using vi\n\
     view edit vi\n\n\
+Select files using the TAB key.\n\
 Enter 'help file-previews' for more information."
 
 #define WRAPPERS_USAGE "c, m, and r commands are wrappers for \
@@ -1220,12 +1222,12 @@ Example: cp -abf ...\n\n\
     r sel\n\
 - Remove all selected files (non-interactively)\n\
     r -f sel\n\
-  Note: Use the 't' command to send files to the trash can. Try 't --help'.\n\n\
+  Note: Use the 't' command to move files to the trash can. Try 't --help'.\n\n\
 To create files and directories you can use the 'md' and 'n' commands.\n\
 Try 'md --help' and 'n --help' for more details.\n\n\
 Use the 'vv' command to copy files into a directory and bulk rename them\n\
 at once. Try 'vv --help'.\n\n\
-Use the 'cr' plugin to send a file to a remote location:\n\
+Use the 'cr' plugin to copy a file to a remote location:\n\
     cr FILE (run 'cr --edit' before to set up your remotes)\n\n\
 Use the 'l' command to create symbolic links, and 'le' to edit them."
 
@@ -1392,8 +1394,6 @@ and paths\
 \n      --lscolors\t\t Read file colors from LS_COLORS\
 \n      --max-dirhist=NUM\t\t Maximum number of visited directories to recall\
 \n      --max-files=NUM\t\t List only up to NUM files\
-\n      --max-path=NUM\t\t Abbreviate current directory in prompt after NUM characters \
-(if \\z is used in the prompt line)\
 \n      --mnt-udisks2\t\t Use udisks2(1) instead of udevil(1) for the 'media' command\
 \n      --no-apparent-size\t Inform file sizes as used blocks instead of used bytes (apparent size)\
 \n      --no-bold\t\t\t Disable bold colors (applies to all color schemes)\
@@ -1478,7 +1478,7 @@ For more information about a specific command run 'CMD -h' or 'CMD --help'.\n"
  bm, bookmarks      Manage bookmarks\n\
  br, bulk           Rename files in bulk\n\
  c, l, m, md, r     Copy, link, move, makedir, and remove\n\
- colors             List current file type colors\n\
+ colors             Preview the current color scheme\n\
  cd                 Change directory\n\
  cl, columns        Set columns on/off\n\
  cmd, commands      Jump to the COMMANDS section in the manpage\n\
@@ -1492,14 +1492,13 @@ For more information about a specific command run 'CMD -h' or 'CMD --help'.\n"
  f, forth           Go forth in the directory history list\n\
  fc                 Set the files counter on/off\n\
  ff, dirs-first     Toggle list-directories-first on/off\n\
- fs                 What is free software?\n\
  ft, filter         Set a files filter\n\
  fz                 Print directories full size (long view mode only)\n\
  hh, hidden         Toggle hidden files on/off\n\
  history            Manage the commands history\n\
  icons              Set icons on/off\n\
- k                  Toggle follow-links (long view only)\n\
- kk                 Toggle max-filename-len\n\
+ k                  Toggle follow-links on/off (long view only)\n\
+ kk                 Toggle max-filename-len on/off\n\
  j                  Jump to a visited directory\n\
  kb, keybinds       Manage keybindings\n\
  le                 Edit symbolic link target\n\
@@ -1533,7 +1532,7 @@ For more information about a specific command run 'CMD -h' or 'CMD --help'.\n"
  splash             Print the splash screen\n\
  st, sort           Change files sorting order\n\
  stats              Print files statistics\n\
- t, trash           Send files to the trash can\n\
+ t, trash           Move files to the trash can\n\
  tag                Tag files\n\
  te                 Toggle the executable bit on files\n\
  tips               Print tips\n\
@@ -1682,7 +1681,7 @@ le mylink            Edit the symbolic link 'mylink'\n\
 oc myfile            Edit file ownership of the file 'myfile'\n\
 pc myfile            Edit file properties of the file 'myfile'\n\
 te *.sh              Toggle the executable bit on all .sh files\n\
-t 12-18              Send the files whose ELN's are 12-18 to the trash can\n\
+t 12-18              Move the files whose ELN's are 12-18 to the trash can\n\
 t del | t del <TAB>  Permanently remove trashed files using a menu\n\
 t empty              Empty the trash can\n\
 u | u <TAB>          Undelete trashed files using a menu\n\
