@@ -60,6 +60,7 @@
 #include "spawn.h"
 
 static char *err_name = (char *)NULL;
+static int mime_match = 0;
 
 /* Expand all environment variables in the string S.
  * Returns the expanded string or NULL on error. */
@@ -144,7 +145,7 @@ skip_line_prefix(char *line)
 static int
 skip_line(char *line, char **pattern, char **cmds)
 {
-	if (*line == '#' || *line == '[' || *line == '\n')
+	if (SKIP_LINE(*line) || *line == '[')
 		return 1;
 
 	*pattern = skip_line_prefix(line);
@@ -340,6 +341,7 @@ get_app(const char *mime, const char *filename)
 
 		if (skip_line(line, &pattern, &cmds) == 1)
 			continue;
+
 		/* PATTERN points now to the beginning of the null terminated pattern,
 		 * while CMDS points to the beginning of the list of opening cmds. */
 
@@ -580,9 +582,13 @@ mime_import(char *file)
 				if (*line == '#' || *line == '\n')
 					continue;
 
-				const int index = strcntchr(line, '.');
-				if (index != -1)
-					line[index] = '\0';
+				char *a = strchr(line, '=');
+				if (!a || !a[1] || a == line)
+					continue;
+
+				char *ret = strchr(a + 1, '.');
+				if (ret)
+					*ret = '\0';
 
 				fprintf(mime_fp, "%s\n", line);
 				mime_defs++;
