@@ -116,7 +116,7 @@ is_blank_name(const char *s)
 char *
 get_newname(const char *msg, char *old_name, int *quoted)
 {
-	xrename = rl_nohist = 1;
+	alt_prompt = rl_nohist = 1;
 	int poffset_bk = prompt_offset;
 	prompt_offset = 3;
 
@@ -155,7 +155,7 @@ get_newname(const char *msg, char *old_name, int *quoted)
 
 END:
 	free(input);
-	xrename = rl_nohist = 0;
+	alt_prompt = rl_nohist = 0;
 	prompt_offset = poffset_bk;
 
 	return new_name;
@@ -165,17 +165,39 @@ END:
 void
 set_eln_color(void)
 {
+	char *cl = (char *)NULL;
+
 	switch (cur_ws) {
-	case 0: xstrsncpy(el_c, *ws1_c ? ws1_c : DEF_EL_C, sizeof(el_c)); break;
-	case 1: xstrsncpy(el_c, *ws2_c ? ws2_c : DEF_EL_C, sizeof(el_c)); break;
-	case 2: xstrsncpy(el_c, *ws3_c ? ws3_c : DEF_EL_C, sizeof(el_c)); break;
-	case 3: xstrsncpy(el_c, *ws4_c ? ws4_c : DEF_EL_C, sizeof(el_c)); break;
-	case 4: xstrsncpy(el_c, *ws5_c ? ws5_c : DEF_EL_C, sizeof(el_c)); break;
-	case 5: xstrsncpy(el_c, *ws6_c ? ws6_c : DEF_EL_C, sizeof(el_c)); break;
-	case 6: xstrsncpy(el_c, *ws7_c ? ws7_c : DEF_EL_C, sizeof(el_c)); break;
-	case 7: xstrsncpy(el_c, *ws8_c ? ws8_c : DEF_EL_C, sizeof(el_c)); break;
-	default: xstrsncpy(el_c, DEF_EL_C, sizeof(el_c)); break;
+	case 0: cl = ws1_c; break;
+	case 1: cl = ws2_c; break;
+	case 2: cl = ws3_c; break;
+	case 3: cl = ws4_c; break;
+	case 4: cl = ws5_c; break;
+	case 5: cl = ws6_c; break;
+	case 6: cl = ws7_c; break;
+	case 7: cl = ws8_c; break;
+	default: break;
 	}
+
+	if (!cl || !*cl) {
+		xstrsncpy(el_c, term_caps.color >= 256
+			? DEF_EL_C256 : DEF_EL_C, sizeof(el_c));
+		return;
+	}
+
+	/* Remove leading and trainling control characters (\001 and \002)*/
+	size_t cl_len = 0;
+	if (*cl == 001) {
+		cl++;
+		cl_len = strlen(cl);
+		if (cl_len > 0 && cl[cl_len - 1] == 002)
+			cl[cl_len - 1] = '\0';
+	}
+
+	xstrsncpy(el_c, cl, sizeof(el_c));
+
+	if (cl_len > 0)
+		cl[cl_len - 1] = 002;
 }
 
 /* Custom POSIX implementation of GNU asprintf() modified to log program
@@ -1103,6 +1125,15 @@ expand_prompt_name(char *name)
 				strlen(prompts[i].warning));
 		}
 
+		if (prompts[i].right) {
+			free(conf.rprompt_str);
+			conf.rprompt_str = savestring(prompts[i].right,
+				strlen(prompts[i].right));
+			if (prompts[i].regular)
+				conf.prompt_is_multiline =
+					strstr(prompts[i].regular, "\\n") ? 1 : 0;
+		}
+
 		prompt_notif = prompts[i].notifications;
 
 		if (xargs.warning_prompt != 0)
@@ -1124,6 +1155,7 @@ free_prompts(void)
 		free(prompts[i].name);
 		free(prompts[i].regular);
 		free(prompts[i].warning);
+		free(prompts[i].right);
 	}
 	free(prompts);
 	prompts = (struct prompts_t *)NULL;
@@ -1339,6 +1371,7 @@ free_stuff(void)
 /*	free(right_prompt); */
 	free_dirlist();
 	free(conf.opener);
+	free(conf.rprompt_str);
 	free(conf.wprompt_str);
 	free(conf.fzftab_options);
 	free(conf.welcome_message_str);
@@ -1502,6 +1535,7 @@ free_stuff(void)
 	free(cmds_log_file);
 	free(mime_file);
 	free(plugins_dir);
+	free(plugins_helper_file);
 	free(profile_file);
 	free(remotes_file);
 
@@ -1548,8 +1582,8 @@ free_stuff(void)
 	if (conf.colorize == 1 && xargs.list_and_quit != 1)
 		RESTORE_COLOR;
 
-	int ret = 0;
-	if ((ret = restore_shell()) < 0) {
+	const int ret = restore_shell();
+	if (ret < 0) {
 		fprintf(stderr, "%s: tcsetattr: %s\n", PROGRAM_NAME, strerror(ret));
 		exit(ret);
 	}
@@ -1565,11 +1599,23 @@ get_term_size(void)
 	if (ioctl(STDOUT_FILENO, TIOCGWINSZ, &w) == -1) {
 		term_cols = 80;
 		term_lines = 24;
-		return;
+	} else {
+		term_cols =  w.ws_col > 0 ? w.ws_col : 80;
+		term_lines = w.ws_row > 0 ? w.ws_row : 24;
 	}
 
-	term_cols =  w.ws_col > 0 ? w.ws_col : 80;
-	term_lines = w.ws_row > 0 ? w.ws_row : 24;
+	if (xargs.secure_env == 1 || xargs.secure_env_full == 1)
+		return;
+
+	char *env = getenv("CLIFM_COLUMNS");
+	int value = env ? atoi(env) : -1;
+	if (value > 0 && value <= USHRT_MAX)
+		term_cols = (unsigned short)value;
+
+	env = getenv("CLIFM_LINES");
+	value = env ? atoi(env) : -1;
+	if (value > 0 && value <= USHRT_MAX)
+		term_lines = (unsigned short)value;
 }
 
 #ifndef _BE_POSIX
@@ -1584,7 +1630,7 @@ sigwinch_handler(int sig)
 	get_term_size();
 	flags |= DELAYED_REFRESH;
 }
-#endif /* _BE_POSIX */
+#endif /* !_BE_POSIX */
 
 void
 set_signals_to_ignore(void)
@@ -1594,7 +1640,7 @@ set_signals_to_ignore(void)
 	signal(SIGTSTP, SIG_IGN); /* C-z */
 #ifndef _BE_POSIX
 	signal(SIGWINCH, sigwinch_handler);
-#endif /* _BE_POSIX */
+#endif /* !_BE_POSIX */
 }
 
 static int
@@ -1989,7 +2035,7 @@ unpin_dir(void)
 }
 
 void
-version_function(void)
+version_function(const int full)
 {
 	char *posix = "";
 	char *legacy = "";
@@ -2014,9 +2060,14 @@ version_function(void)
 # endif
 #endif /* SECURITY_PARANOID */
 
-	printf(_("%s %s%s%s%s%s (%s)\n%s\nLicense %s\nWritten by %s\n"),
-		PROGRAM_NAME, VERSION, posix, legacy, suckless, paranoid,
-		DATE, CONTACT, LICENSE, AUTHOR);
+	if (full == 1) { /* Running from within clifm (as 'ver')*/
+		printf(_("%s %s%s%s%s%s (%s)\n%s\nLicense %s\nWritten by %s\n"),
+			PROGRAM_NAME, VERSION, posix, legacy, suckless, paranoid,
+			DATE, CONTACT, LICENSE, AUTHOR);
+	} else { /* Running as --version (or -v) */
+		printf("%s%s%s%s%s\n", VERSION, posix, legacy, suckless, paranoid);
+		exit(EXIT_SUCCESS);
+	}
 }
 
 void
@@ -2067,7 +2118,7 @@ bonus_function(void)
 		"Keep it simple, stupid",
 		"If ain't broken, brake it",
 		"\"I only know that I know nothing\" (Socrates)",
-		"(Learned) Ignorance is the true outcome of wisdom (Nicholas "
+		"(Learned) Ignorance is the true outcome of wisdom (Nicholas " /* NOLINT */
 		"of Cusa)",
 		"True intelligence is about questions, not answers",
 		"Humanity is just an arrow released towards God",
