@@ -3,7 +3,7 @@
 /*
  * This file is part of CliFM
  *
- * Copyright (C) 2016-2023, L. Abramovich <leo.clifm@outlook.com>
+ * Copyright (C) 2016-2024, L. Abramovich <leo.clifm@outlook.com>
  * All rights reserved.
 
  * CliFM is free software; you can redistribute it and/or modify
@@ -25,18 +25,19 @@
 #ifndef NAVIGATION_H
 #define NAVIGATION_H
 
+#include "workspaces.h"
+
 __BEGIN_DECLS
 
-int  back_function(char **);
-int  backdir(char *);
-int  cd_function(char *, const int);
-char *fastback(char *);
-int  forth_function(char **);
-char **get_bd_matches(const char *, int *, const int);
-int  handle_workspaces(char **);
-void print_dirhist(char *);
-int  pwd_function(const char *);
-int  xchdir(char *, const int);
+int  back_function(char **args);
+int  backdir(char *str);
+int  cd_function(char *new_path, const int cd_flag);
+char *fastback(char *str);
+int  forth_function(char **args);
+char **get_bd_matches(const char *str, int *n, const int mode);
+void print_dirhist(char *query);
+int  pwd_function(const char *arg);
+int  xchdir(char *dir, const int cd_flag);
 
 __END_DECLS
 
