@@ -3,7 +3,7 @@
 /*
  * This file is part of CliFM
  *
- * Copyright (C) 2016-2023, L. Abramovich <leo.clifm@outlook.com>
+ * Copyright (C) 2016-2024, L. Abramovich <leo.clifm@outlook.com>
  * All rights reserved.
 
  * CliFM is free software; you can redistribute it and/or modify
@@ -28,8 +28,8 @@
 __BEGIN_DECLS
 
 int get_profile_names(void);
-int profile_function(char **);
-int profile_set(const char *);
+int profile_function(char **args);
+int profile_set(const char *prof);
 int validate_profile_name(const char *name);
 
 __END_DECLS
