@@ -35,8 +35,10 @@
 #include <readline/readline.h>
 #include <readline/history.h> /* history_expand() */
 #include <errno.h>
+#include <wchar.h> /* mbstowcs, wcschr, wcwidth */
 
 #include "aux.h"
+#include "checks.h" /* is_number() */
 #include "colors.h" /* update_warning_prompt_text_color() */
 #include "file_operations.h"
 #include "history.h"
@@ -52,6 +54,20 @@
 # include "suggestions.h"
 #endif /* !_NO_SUGGESTIONS */
 
+#if defined(__HAIKU__) || defined(__OpenBSD__) || defined(__ANDROID__)
+# define NO_WORDEXP
+#else
+# define MAX_PMOD_PATHS 8
+static size_t p_mod_paths_n = 0;
+
+struct p_mod_paths_t {
+	char path[PATH_MAX];
+	char *name;
+};
+
+static struct p_mod_paths_t p_mod_paths[MAX_PMOD_PATHS];
+#endif /* __HAIKU__ || __OpenBSD__ || __ANDROID__ */
+
 static inline char *
 gen_time(const int c)
 {
@@ -87,45 +103,136 @@ gen_time(const int c)
 }
 
 static inline char *
-get_dir_basename(const char *_path)
+get_dir_basename(const char *str)
 {
-	char *temp = (char *)NULL;
-	char *ret = (char *)NULL;
-
 	/* If not root dir (/), get last path component */
-	if (!(*_path == '/' && !*(_path + 1)))
-		ret = strrchr(_path, '/');
+	const char *ret = (*str == '/' && !str[1])
+		? (char *)NULL : strrchr(str, '/');
 
-	if (!ret)
-		temp = savestring(_path, strlen(_path));
-	else
-		temp = savestring(ret + 1, strlen(ret + 1));
+	if (!ret || !ret[1])
+		return savestring(str, strlen(str));
 
-	return temp;
+	return savestring(ret + 1, strlen(ret + 1));
 }
 
 static inline char *
-reduce_path(const char *_path)
+reduce_path(const char *str)
 {
 	char *temp = (char *)NULL;
+	const size_t slen = strlen(str);
 
-	if (strlen(_path) > (size_t)conf.max_path) {
-		char *ret = strrchr(_path, '/');
-		if (!ret)
-			temp = savestring(_path, strlen(_path));
+	if (slen > (size_t)conf.prompt_p_max_path) {
+		char *ret = strrchr(str, '/');
+		if (!ret || !ret[1])
+			temp = savestring(str, slen);
 		else
-			temp = savestring(ret + 1, strlen(ret + 1));
+			temp = savestring(ret + 1, (size_t)(str + slen - ret - 1));
 	} else {
-		temp = savestring(_path, strlen(_path));
+		temp = savestring(str, slen);
 	}
 
 	return temp;
 }
 
+static size_t
+copy_char(char *buf, char *s)
+{
+	const int bytes = ((*s & 0xc0) == 0xc0 || (*s & 0xc0) == 0x80)
+		? utf8_bytes((unsigned char)*s) : 1;
+
+	if (bytes == 1) {
+		*buf = *s;
+		return 1;
+	}
+
+	int c = 0;
+	while (c < bytes) {
+		buf[c] = *s;
+		c++;
+		s++;
+	}
+
+	return (size_t)c;
+}
+
+static inline char *
+reduce_path_fish(char *str)
+{
+	if ((*str == '~' || *str == '/') && !str[1])
+		return savestring(*str == '~' ? "~" : "/", 1);
+
+	if (conf.prompt_f_dir_len == 0)
+		return savestring(str, strlen(str));
+
+	char *s = str;
+	size_t total_comps = (*s == '~');
+
+	while (*s) {
+		if (*s == '/')
+			total_comps++;
+		s++;
+	}
+
+	if (conf.prompt_f_full_len_dirs > 1
+	&& total_comps > (size_t)conf.prompt_f_full_len_dirs - 1)
+		total_comps -= (size_t)conf.prompt_f_full_len_dirs - 1;
+
+	size_t slen = (size_t)(s - str);
+	s = str;
+
+	char *buf = xnmalloc(slen + 1, sizeof(char));
+	size_t i = 0;
+	size_t cur_comps = 0;
+
+	if (*s == '~') {
+		buf[i++] = *s;
+		cur_comps++;
+	}
+
+	while (*s) {
+		if (*s != '/') {
+			s++;
+			continue;
+		}
+
+		buf[i++] = '/';
+		cur_comps++;
+		s++;
+
+		if (cur_comps >= total_comps) {
+			xstrsncpy(buf + i, s, slen - i + 1);
+			break;
+		}
+
+		if (*s == '.') {
+			buf[i++] = *s;
+			s++;
+		}
+
+		if (conf.prompt_f_dir_len == 1) {
+			const size_t bytes = copy_char(buf + i, s);
+			i += bytes;
+			s += bytes;
+			continue;
+		}
+
+		size_t q = 0;
+		while (*s && *s != '/' && q < (size_t)conf.prompt_f_dir_len) {
+			const size_t bytes = copy_char(buf + i, s);
+			i += bytes;
+			s += bytes;
+			q++;
+		}
+	}
+
+	return buf;
+}
+
 static inline char *
 gen_pwd(const int c)
 {
-	char *temp = (char *)NULL, *tmp_path = (char *)NULL;
+	char *temp = (char *)NULL;
+	char *tmp_path = (char *)NULL;
 	int free_tmp_path = 0;
 
 	if (user.home
@@ -139,6 +246,8 @@ gen_pwd(const int c)
 		temp = get_dir_basename(tmp_path);
 	else if (c == 'p')
 		temp = reduce_path(tmp_path);
+	else if (c == 'f')
+		temp = reduce_path_fish(tmp_path);
 	else /* If c == 'w' */
 		temp = savestring(tmp_path, strlen(tmp_path));
 
@@ -151,7 +260,7 @@ gen_pwd(const int c)
 static inline char *
 gen_workspace(void)
 {
-		/* An int (or workspace name) + workspaces color + NUL byte */
+	/* An int (or workspace name) + workspaces color + NUL byte */
 	char s[NAME_MAX + sizeof(ws1_c) + 1];
 	char *cl = (char *)NULL;
 
@@ -240,27 +349,19 @@ gen_octal(char **line, int *c)
 static inline char *
 gen_profile(void)
 {
-	char *temp = (char *)NULL;
-
 	if (!alt_profile)
-		temp = savestring("default", 7);
-	else
-		temp = savestring(alt_profile, strlen(alt_profile));
+		return savestring("default", 7);
 
-	return temp;
+	return savestring(alt_profile, strlen(alt_profile));
 }
 
 static inline char *
 gen_user_name(void)
 {
-	char *temp = (char *)NULL;
-
 	if (!user.name)
-		temp = savestring(UNKNOWN_STR, sizeof(UNKNOWN_STR) - 1);
-	else
-		temp = savestring(user.name, strlen(user.name));
+		return savestring(UNKNOWN_STR, sizeof(UNKNOWN_STR) - 1);
 
-	return temp;
+	return savestring(user.name, strlen(user.name));
 }
 
 static inline char *
@@ -362,7 +463,7 @@ add_string(char **tmp, const int c, char **line, char **res, size_t *len)
 	free(*tmp);
 }
 
-#if !defined(__HAIKU__) && !defined(__OpenBSD__) && !defined(__ANDROID__)
+#ifndef NO_WORDEXP
 static inline void
 reset_ifs(const char *value)
 {
@@ -375,46 +476,52 @@ reset_ifs(const char *value)
 static inline void
 substitute_cmd(char **line, char **res, size_t *len)
 {
-	const int tmp = strcntchr(*line, ')');
-	if (tmp == -1) return; /* No ending bracket */
+	char *p = strchr(*line, ')');
+	if (!p)
+		return; /* No ending bracket */
 
-	const size_t tmp_len = strlen(*line) + 2;
-	char *tmp_str = xnmalloc(tmp_len, sizeof(char));
-	snprintf(tmp_str, tmp_len, "$%s", *line);
+	/* Extract the command to be executed */
+	const char c = p[1];
+	p[1] = '\0';
+	const size_t cmd_len = strlen(*line) + 2;
+	char *cmd = xnmalloc(cmd_len, sizeof(char));
+	snprintf(cmd, cmd_len, "$%s", *line); /* Reinsert leading '$' */
+	p[1] = c;
 
-	tmp_str[tmp + 2] = '\0';
-	*line += tmp + 1;
+	/* Set LINE after the ending bracket to continue processing */
+	*line = p + 1;
 
 	char *old_value = xgetenv("IFS", 1);
 	setenv("IFS", "", 1);
 
 	wordexp_t wordbuf;
-	if (wordexp(tmp_str, &wordbuf, 0) != FUNC_SUCCESS) {
-		free(tmp_str);
-		reset_ifs(old_value);
-		free(old_value);
-		return;
-	}
+	const int ret = wordexp(cmd, &wordbuf, 0);
+
 	reset_ifs(old_value);
 	free(old_value);
-	free(tmp_str);
+	free(cmd);
 
-	if (wordbuf.we_wordc) {
-		for (size_t j = 0; j < wordbuf.we_wordc; j++) {
-			*len += strlen(wordbuf.we_wordv[j]);
-			if (!*res) {
-				*res = xnmalloc(*len + 2, sizeof(char));
-				*(*res) = '\0';
-			} else {
-				*res = xnrealloc(*res, *len + 2, sizeof(char));
-			}
-			xstrncat(*res, strlen(*res), wordbuf.we_wordv[j], *len + 2);
+	if (ret != 0)
+		return;
+
+	if (wordbuf.we_wordc == 0)
+		goto END;
+
+	for (size_t j = 0; j < wordbuf.we_wordc; j++) {
+		*len += strlen(wordbuf.we_wordv[j]);
+		if (!*res) {
+			*res = xnmalloc(*len + 2, sizeof(char));
+			*(*res) = '\0';
+		} else {
+			*res = xnrealloc(*res, *len + 2, sizeof(char));
 		}
+		xstrncat(*res, strlen(*res), wordbuf.we_wordv[j], *len + 2);
 	}
 
+END:
 	wordfree(&wordbuf);
 }
-#endif /* !__HAIKU__ && !__OpenBSD__ && !__ANDROID__ */
+#endif /* !NO_WORDEXP */
 
 static inline char *
 gen_emergency_prompt(void)
@@ -537,6 +644,270 @@ gen_nesting_level(const int mode)
 	return p;
 }
 
+static char *
+get_color_attribute(const char *line)
+{
+	if (!line || !line[0] || line[1] != ':')
+		return (char *)NULL;
+
+	switch (line[0]) {
+	case 'b': return "1;"; /* Bold */
+	case 'd': return "2;"; /* Dim */
+	case 'i': return "3;"; /* Italic */
+	case 'n': return "0;"; /* Normal/reset */
+	case 'r': return "7;"; /* Reverse */
+	case 's': return "9;"; /* Strikethrough */
+	case 'u': return "4;"; /* Underline */
+	case 'B': /* fallthrough */
+	case 'D': return "22;"; /* Disable bold/dim: normal intensity */
+	case 'I': return "23;"; /* Disable italic */
+	case 'R': return "27;"; /* Disable reverse */
+	case 'S': return "29;"; /* Disable strikethrough */
+	case 'U': return "24;"; /* Disable underline */
+	case 'K': return "49;"; /* Disable background (terminal default) */
+	case 'N': return "39;"; /* Disable foreground (terminal default) */
+	default: return (char *)NULL;
+	}
+}
+
+/* Return 1 if the string S is valid hex color, or 0 otherwise. */
+static int
+is_valid_hex(const char *s)
+{
+	if (!s || !*s)
+		return 0;
+
+	size_t i;
+	for (i = 0; s[i]; i++) {
+		if ( !( (s[i] >= '0' && s[i] <= '9')
+		|| (s[i] >= 'a' && s[i] <= 'f')
+		|| (s[i] >= 'A' && s[i] <= 'F') ) )
+			return 0;
+	}
+
+	return (i == 3 || i == 6);
+}
+
+/* Convert a color notation ("%{color}") into an actual color escape
+ * sequence. Return this latter on success or NULL on error (invalid
+ * color notation). */
+char *
+gen_color(char **line)
+{
+	if (!*line || !*(*line))
+		return (char *)NULL;
+
+	/* At this point LINE is "{color}" */
+	char *l = (*line) + 1; /* L is now "color}" */
+
+	const int bg = (l[0] == 'k' && l[1] == ':' && l[2]);
+	char *attr = bg == 0 ? get_color_attribute(l) : (char *)NULL;
+	if (bg == 1 || attr)
+		l += 2; /* Remove background/attribute prefix ("x:") */
+
+	/* Is color bright? */
+	const int br = (l[0] == 'b' && l[1] == 'r' && l[2]);
+	if (br == 1)
+		l += 2;
+
+	/* Disable attribute? */
+	const int attr_off = (l[0] == 'n' && l[1] == 'o' && l[2]);
+	if (attr_off == 1)
+		l += 2;
+
+	char *p = strchr(l, '}');
+	if (!p)
+		return (char *)NULL;
+
+	*p = '\0'; /* Remove trailing '}': now we have "color" */
+
+#define C_START RL_PROMPT_START_IGNORE
+#define C_END   RL_PROMPT_END_IGNORE
+#define C_ESC   0x1b
+#define C_LEN   25 /* 25 == max color length (rgb) */
+
+#define GEN_COLOR(s1, s2) (snprintf(temp, C_LEN, "%c%c[%s%sm%c", C_START, \
+	C_ESC, attr ? attr : "", bg == 1 ? (s1) : (s2), C_END));
+#define GEN_ATTR(s) (snprintf(temp, C_LEN, "%c%c[%s%sm%c", C_START, C_ESC, \
+	attr ? attr : "", (s), C_END))
+
+	char *temp = xnmalloc(C_LEN, sizeof(char));
+	int n = -1;
+
+	/* 'bold' and 'blue' are used more often than 'black': check them first. */
+	if (l[0] == 'b' && strcmp(l, "bold") == 0) {
+		GEN_ATTR(attr_off ? "22" : "1");
+	} else if (l[0] == 'b' && strcmp(l, "blue") == 0) {
+		GEN_COLOR(br ? "104" : "44", br ? "94" : "34");
+	} else if (l[0] == 'b' && strcmp(l, "black") == 0) {
+		GEN_COLOR(br ? "100" : "40", br ? "90" : "30");
+	/* 'reset' is used more often than 'red' and 'reverse': check it first. */
+	} else if (l[0] == 'r' && strcmp(l, "reset") == 0) {
+		GEN_ATTR("0");
+	} else if (l[0] == 'r' && strcmp(l, "red") == 0) {
+		GEN_COLOR(br ? "101" : "41", br ? "91" : "31");
+	} else if (l[0] == 'r' && strcmp(l, "reverse") == 0) {
+		GEN_ATTR(attr_off ? "27" : "7");
+	} else if (l[0] == 'g' && strcmp(l, "green") == 0) {
+		GEN_COLOR(br ? "102" : "42", br ? "92" : "32");
+	} else if (l[0] == 'y' && strcmp(l, "yellow") == 0) {
+		GEN_COLOR(br ? "103" : "43", br ? "93" : "33");
+	} else if (l[0] == 'm' && strcmp(l, "magenta") == 0) {
+		GEN_COLOR(br ? "105" : "45", br ? "95" : "35");
+	} else if (l[0] == 'c' && strcmp(l, "cyan") == 0) {
+		GEN_COLOR(br ? "106" : "46", br ? "96" : "36");
+	} else if (l[0] == 'w' && strcmp(l, "white") == 0) {
+		GEN_COLOR(br ? "107" : "47", br ? "97" : "37");
+	} else if (l[0] == 'd' && strcmp(l, "dim") == 0) {
+		GEN_ATTR(attr_off ? "22" : "2");
+	} else if (l[0] == 'i' && strcmp(l, "italic") == 0) {
+		GEN_ATTR(attr_off ? "23" : "3");
+	} else if (l[0] == 'u' && strcmp(l, "underline") == 0) {
+		GEN_ATTR(attr_off ? "24" : "4");
+	} else if (l[0] == 's' && strcmp(l, "strike") == 0) {
+		GEN_ATTR(attr_off ? "29" : "9");
+	} else if (l[0] == 'f' && l[1] == 'g' && strcmp(l + 2, "reset") == 0) {
+		GEN_ATTR("39");
+	} else if (l[0] == 'b' && l[1] == 'g' && strcmp(l + 2, "reset") == 0) {
+		GEN_ATTR("49");
+	} else if (IS_DIGIT(l[0]) && (!l[1] || (is_number(l + 1)
+	&& (n = atoi(l)) <= 255))) {
+		if (!l[1])
+			n = l[0] - '0';
+		snprintf(temp, C_LEN, "%c%c[%s%s;5;%dm%c",
+			C_START, C_ESC, attr ? attr : "",
+			bg == 1 ? "48" : "38", n, C_END);
+	} else if (l[0] == '#' && is_valid_hex(l + 1)) {
+		/* Fallback values in case get_rgb() returns prematurely (error) */
+		int a = -1, r = 100, g = 100, b = 100;
+		get_rgb(l + 1, &a, &r, &g, &b);
+		snprintf(temp, C_LEN, "%c%c[%s%s;2;%d;%d;%dm%c",
+			C_START, C_ESC, attr ? attr : "",
+			bg == 1 ? "48" : "38", r, g, b, C_END);
+	} else {
+		*p = '}'; /* Restore the trailing '}' */
+		free(temp);
+		return (char *)NULL;
+	}
+
+	*p = '}'; /* Restore the trailing '}' */
+	*line = p; /* Set LINE to the end of the color notation */
+	return temp;
+}
+
+#ifndef NO_WORDEXP
+static char *
+check_mod_paths_cache(const char *name)
+{
+	size_t i = 0;
+
+	static int init = 0;
+	if (init == 0) { /* Initialize the cache */
+		init = 1;
+		for (i = 0; i < MAX_PMOD_PATHS; i++) {
+			p_mod_paths[i].path[0] = '\0';
+			p_mod_paths[i].name = (char *)NULL;
+		}
+	}
+
+	for (i = 0; i < MAX_PMOD_PATHS && p_mod_paths[i].name; i++) {
+		if (*name == *p_mod_paths[i].name
+		&& strcmp(name + 1, p_mod_paths[i].name + 1) == 0)
+			return &p_mod_paths[i].path[0];
+	}
+
+	return (char *)NULL;
+}
+
+static void
+cache_pmod_path(const char *mod_path)
+{
+	if (!mod_path || !*mod_path || p_mod_paths_n == MAX_PMOD_PATHS)
+		return;
+
+	xstrsncpy(p_mod_paths[p_mod_paths_n].path, mod_path, strlen(mod_path) + 1);
+
+	char *p = strrchr(p_mod_paths[p_mod_paths_n].path, '/');
+	if (p && p[1])
+		p_mod_paths[p_mod_paths_n].name = p + 1;
+
+	p_mod_paths_n++;
+}
+
+static char *
+get_prompt_module_path(const char *name)
+{
+	char *cached_path = check_mod_paths_cache(name);
+	if (cached_path)
+		return cached_path;
+
+	struct stat a;
+	static char m_path[PATH_MAX];
+
+	if (plugins_dir && *plugins_dir) {
+		snprintf(m_path, sizeof(m_path), "%s/%s", plugins_dir, name);
+		if (stat(m_path, &a) != -1) {
+			cache_pmod_path(m_path);
+			return &m_path[0];
+		}
+	}
+
+	if (data_dir && *data_dir) {
+		snprintf(m_path, sizeof(m_path), "%s/%s/plugins/%s",
+			data_dir, PROGRAM_NAME, name);
+		if (stat(m_path, &a) != -1) {
+			cache_pmod_path(m_path);
+			return &m_path[0];
+		}
+	}
+
+	return (char *)NULL;
+}
+
+static void
+run_prompt_module(char **line, char **res, size_t *len)
+{
+	char *p = strchr(*line, '}');
+	if (!p)
+		return;
+
+	*p = '\0';
+
+	const char *p_path = get_prompt_module_path(*line + 1);
+	if (p_path) {
+		char cmd[PATH_MAX + 3];
+		snprintf(cmd, sizeof(cmd), "(%s)", p_path);
+
+		char *ptr = &cmd[0];
+		substitute_cmd(&ptr, res, len);
+	}
+
+	*p = '}';
+	*line = p + 1;
+}
+#endif /* !NO_WORDEXP */
+
+static char *
+gen_last_cmd_time(char **line)
+{
+	if (last_cmd_time < (double)conf.prompt_b_min)
+		goto END;
+
+	const int precision = conf.prompt_b_precision;
+	const int len = snprintf(NULL, 0, "%.*f", precision, last_cmd_time);
+	if (len < 0)
+		goto END;
+
+	char *temp = xnmalloc((size_t)len + 1, sizeof(char));
+	snprintf(temp, (size_t)len + 1, "%.*f", precision, last_cmd_time);
+
+	return temp;
+
+END:
+	(*line)++;
+	return (char *)NULL;
+}
+
 /* Decode the prompt string (encoded_prompt global variable) taken from
  * the configuration file. */
 char *
@@ -551,8 +922,15 @@ decode_prompt(char *line)
 	int c;
 
 	while ((c = (int)*line++)) {
+		/* Color notation: "%{color}" */
+		if (c == '%' && *line == '{' && line[1]) {
+			temp = gen_color(&line);
+			if (temp)
+				add_string(&temp, c, &line, &result, &result_len);
+		}
+
 		/* We have an escape char */
-		if (c == '\\') {
+		else if (c == '\\') {
 			/* Now move on to the next char */
 			c = (int)*line;
 			switch (c) {
@@ -605,9 +983,12 @@ decode_prompt(char *line)
 				temp = gen_octal(&line, &c); goto ADD_STRING;
 
 			case 'c': /* Program name */
-				temp = savestring(PROGRAM_NAME, strlen(PROGRAM_NAME));
+				temp = savestring(PROGRAM_NAME, sizeof(PROGRAM_NAME) - 1);
 				goto ADD_STRING;
 
+			case 'b':
+				temp = gen_last_cmd_time(&line); goto ADD_STRING;
+
 			case 'P': /* Current profile name */
 				temp = gen_profile(); goto ADD_STRING;
 
@@ -640,6 +1021,7 @@ decode_prompt(char *line)
 				temp = gen_mode(); goto ADD_STRING;
 
 			case 'p': /* fallthrough */ /* Abbreviated if longer than PathMax */
+			case 'f': /* fallthrough */ /* Abbreviated, fish-like */
 			case 'w': /* fallthrough */ /* Full PWD */
 			case 'W': /* Short PWD */
 				if (!workspaces[cur_ws].path) {	line++;	break; }
@@ -670,20 +1052,25 @@ ADD_STRING:
 			}
 		}
 
-		/* If not escape code, check for command substitution, and if not,
+		/* If not an escape code, check for command substitution, and if not,
 		 * just add whatever char is there. */
 		else {
 			/* Remove non-escaped quotes */
 			if (c == '\'' || c == '"')
 				continue;
 
-#if !defined(__HAIKU__) && !defined(__OpenBSD__) && !defined(__ANDROID__)
+#ifndef NO_WORDEXP
 			/* Command substitution */
 			if (c == '$' && *line == '(') {
 				substitute_cmd(&line, &result, &result_len);
 				continue;
 			}
-#endif /* !__HAIKU__ && !__OpenBSD__ && !__ANDROID__ */
+
+			if (c == '$' && *line == '{') {
+				run_prompt_module(&line, &result, &result_len);
+				continue;
+			}
+#endif /* !NO_WORDEXP */
 
 			const size_t new_len = result_len + 2
 				+ (wrong_cmd ? (MAX_COLOR + 6) : 0);
@@ -758,7 +1145,7 @@ print_user_message(void)
 	while (*s) {
 		if (*s == '\\' && *(s + 1)) {
 			s++;
-			if (*s >= '0' && *s <= '7' && (tmp = gen_octal(&s, &c))) {
+			if (*s >= '0' && *s <= '7' && (tmp = gen_octal(&s, &c))) { /* NOLINT */
 				fputs(tmp, stdout);
 				free(tmp);
 			} else if (*s == 'e' && (tmp = gen_escape_char(&s, &c))) {
@@ -863,27 +1250,18 @@ setenv_prompt(void)
 	if (prompt_notif == 1)
 		return;
 
-	/* Set environment variables with CliFM state information
-	 * (sel files, trash, stealth mode, messages) to be handled by
-	 * the prompt itself. */
-	char t[MAX_INT_STR];
-	snprintf(t, sizeof(t), "%d", (int)sel_n);
-	setenv("CLIFM_STAT_SEL", t, 1);
+	/* Set environment variables with clifm state information
+	 * (sel files, trash, stealth mode, messages, workspace, and last exit
+	 * code) to be handled by the prompt itself. */
+	setenv("CLIFM_STAT_SEL", xitoa((long long)sel_n), 1);
 #ifndef _NO_TRASH
-	snprintf(t, sizeof(t), "%d", trash_n > 0 ? (int)trash_n : 0);
-	setenv("CLIFM_STAT_TRASH", t, 1);
+	setenv("CLIFM_STAT_TRASH", xitoa((long long)trash_n), 1);
 #endif /* !_NO_TRASH */
-	snprintf(t, sizeof(t), "%d", (int)msgs.error);
-	setenv("CLIFM_STAT_ERROR_MSGS", t, 1);
-	snprintf(t, sizeof(t), "%d", (int)msgs.warning);
-	setenv("CLIFM_STAT_WARNING_MSGS", t, 1);
-	snprintf(t, sizeof(t), "%d", (int)msgs.notice);
-	setenv("CLIFM_STAT_NOTICE_MSGS", t, 1);
-
-	snprintf(t, sizeof(t), "%d", cur_ws + 1);
-	setenv("CLIFM_STAT_WS", t, 1);
-	snprintf(t, sizeof(t), "%d", exit_code);
-	setenv("CLIFM_STAT_EXIT", t, 1);
+	setenv("CLIFM_STAT_ERROR_MSGS", xitoa((long long)msgs.error), 1);
+	setenv("CLIFM_STAT_WARNING_MSGS", xitoa((long long)msgs.warning), 1);
+	setenv("CLIFM_STAT_NOTICE_MSGS", xitoa((long long)msgs.notice), 1);
+	setenv("CLIFM_STAT_WS", xitoa((long long)cur_ws + 1), 1);
+	setenv("CLIFM_STAT_EXIT", xitoa((long long)exit_code), 1);
 	setenv("CLIFM_STAT_ROOT", user.uid == 0 ? "1" : "0", 1);
 	setenv("CLIFM_STAT_STEALTH", (xargs.stealth_mode == 1) ? "1" : "0", 1);
 }
@@ -1017,17 +1395,95 @@ log_and_record(char *input)
 	if (record_cmd(input) == 1)
 		add_to_cmdhist(input);
 }
-/*
-void
+
+/* UTF-8 version of get_prompt_len(). */
+static int
+get_rprompt_len_utf8(char *rprompt)
+{
+	if (!rprompt || !*rprompt)
+		return 0;
+
+	char *nl = strchr(rprompt, '\n');
+	if (nl)
+		*nl = '\0';
+
+	static wchar_t buf[NAME_MAX];
+	*buf = L'\0';
+	if (mbstowcs(buf, rprompt, NAME_MAX) == (size_t)-1)
+		return 0;
+
+	size_t i = 0;
+	int len = 0;
+
+	while (buf[i]) {
+		if (buf[i] == '\x1b' && buf[i + 1] == '[') {
+			wchar_t *tmp = wcschr(buf + i + 1, L'm');
+			if (tmp)
+				i += (size_t)(tmp - (buf + i) + 1);
+		} else if (buf[i] == 001) {
+			wchar_t *tmp = wcschr(buf + i, L'\002');
+			if (tmp)
+				i += (size_t)(tmp - (buf + i) + 1);
+		} else {
+			len += wcwidth(buf[i]);
+			i++;
+		}
+	}
+
+	return len;
+}
+
+/* Return the printable length of the string RPROMPT. Zero is returned on error. */
+static int
+get_rprompt_len(char *rprompt)
+{
+	char *p = rprompt;
+	while (*p) {
+		if ((*p & 0xc0) == 0xc0 || (*p & 0xc0) == 0x80)
+			return get_rprompt_len_utf8(rprompt);
+		p++;
+	}
+
+	p = rprompt;
+	int len = 0;
+
+	while (*p) {
+		if (*p == '\n') {
+			*p = '\0';
+			break;
+		} else if (*p == '\x1b' && p[1] == '[') {
+			char *tmp = strchr(p, 'm');
+			if (tmp)
+				p = tmp + 1;
+		} else if (*p == 001) {
+			char *tmp = strchr(p, '\002');
+			if (tmp)
+				p = tmp + 1;
+		} else {
+			len++;
+			p++;
+		}
+	}
+
+	return len;
+}
+
+static void
 print_right_prompt(void)
 {
-//	get_cursor_position(STDIN_FILENO, STDOUT_FILENO);
-	get_cursor_position(0, 1);
-	char *p = decode_prompt(right_prompt);
-	printf("%*s", term_cols, p);
-	printf("\x1b[%d;%dH", curline, curcol);
-	free(p);
-} */
+	char *rprompt = decode_prompt(conf.rprompt_str);
+	const int len = rprompt ? get_rprompt_len(rprompt) : 0;
+	if (len <= 0 || len >= term_cols) {
+		free(rprompt);
+		return;
+	}
+
+	MOVE_CURSOR_RIGHT(term_cols);
+	MOVE_CURSOR_LEFT(len);
+	fputs(rprompt, stdout);
+	MOVE_CURSOR_LEFT(term_cols);
+	free(rprompt);
+}
 
 /* Some commands take '!' as parameter modifier: quick search, 'filter',
  * and 'sel', in which case history expansion must not be performed.
@@ -1115,6 +1571,10 @@ prompt(const int prompt_flag)
 		? decoded_prompt : EMERGENCY_PROMPT);
 	free(decoded_prompt);
 
+	if (conf.rprompt_str && *conf.rprompt_str
+	&& conf.prompt_is_multiline == 1 && term_caps.suggestions == 1)
+		print_right_prompt();
+
 	if (prompt_flag == PROMPT_UPDATE || prompt_flag == PROMPT_UPDATE_RUN_CMDS) {
 		rl_set_prompt(the_prompt);
 		free(the_prompt);
@@ -1127,9 +1587,6 @@ prompt(const int prompt_flag)
 	 * prompt contains dynamic values. */
 	prompt_offset = UNSET;
 
-/*	if (right_prompt && *right_prompt)
-		print_right_prompt(); */
-
 	UNHIDE_CURSOR;
 
 	/* Print the prompt and get user input */
@@ -1177,17 +1634,24 @@ list_prompts(void)
 static int
 switch_prompt(const size_t n)
 {
-	if (prompts[n].regular) {
-		free(conf.encoded_prompt);
-		conf.encoded_prompt = savestring(prompts[n].regular, strlen(prompts[n].regular));
-	}
+	free(conf.encoded_prompt);
+	free(conf.wprompt_str);
+	free(conf.rprompt_str);
+	conf.encoded_prompt = conf.wprompt_str = conf.rprompt_str = (char *)NULL;
 
-	if (prompts[n].warning) {
-		free(conf.wprompt_str);
+	if (prompts[n].regular)
+		conf.encoded_prompt = savestring(prompts[n].regular, strlen(prompts[n].regular));
+
+	if (prompts[n].warning)
 		conf.wprompt_str = savestring(prompts[n].warning, strlen(prompts[n].warning));
+
+	if (prompts[n].right) {
+		conf.rprompt_str = savestring(prompts[n].right, strlen(prompts[n].right));
+		conf.prompt_is_multiline = prompts[n].multiline;
 	}
 
 	prompt_notif = prompts[n].notifications;
+	set_prompt_options();
 
 	if (xargs.warning_prompt == 0)
 		return FUNC_SUCCESS;
@@ -1243,6 +1707,55 @@ set_default_prompt(void)
 	return FUNC_SUCCESS;
 }
 
+/* Read environment variables controling options for the '\b', '\f', and
+ * '\p' prompt codes and set the appropriate values. */
+void
+set_prompt_options(void)
+{
+	char *val = (char *)NULL;
+	int n = 0;
+
+	const char *np = conf.encoded_prompt; /* Normal/Regular prompt */
+	const char *wp = conf.wprompt_str;    /* Warning prompt */
+	const char *rp = conf.rprompt_str;    /* Right prompt */
+
+#define CHECK_PROMPT_OPT(s) ((np && *np && strstr(np, (s)) != NULL) \
+	|| (wp && *wp && strstr(wp, (s)) != NULL)                       \
+	|| (rp && *rp && strstr(rp, (s)) != NULL))
+
+	const int b_is_set = CHECK_PROMPT_OPT("\\b");
+	const int f_is_set = CHECK_PROMPT_OPT("\\f");
+	const int p_is_set = CHECK_PROMPT_OPT("\\p");
+
+	conf.prompt_b_is_set = b_is_set;
+
+	if (f_is_set == 1) {
+		val = getenv("CLIFM_PROMPT_F_DIR_LEN");
+		if (val && is_number(val) && (n = atoi(val)) > 0 && n < INT_MAX)
+			conf.prompt_f_dir_len = n;
+
+		val = getenv("CLIFM_PROMPT_F_FULL_LEN_DIRS");
+		if (val && is_number(val) && (n = atoi(val)) > 0 && n < INT_MAX)
+			conf.prompt_f_full_len_dirs = n;
+	}
+
+	if (b_is_set == 1) {
+		val = getenv("CLIFM_PROMPT_B_PRECISION");
+		if (val && IS_DIGIT(*val) && !val[1])
+			conf.prompt_b_precision = *val - '0';
+
+		val = getenv("CLIFM_PROMPT_B_MIN");
+		if (val && is_number(val) && (n = atoi(val)) < INT_MAX)
+			conf.prompt_b_min = n;
+	}
+
+	if (conf.prompt_p_max_path == UNSET && p_is_set == 1) {
+		val = getenv("CLIFM_PROMPT_P_MAX_PATH");
+		if (val && is_number(val) && (n = atoi(val)) > 0 && n < INT_MAX)
+			conf.prompt_p_max_path = n;
+	}
+}
+
 static int
 edit_prompts_file(char *app)
 {
@@ -1264,16 +1777,7 @@ edit_prompts_file(char *app)
 
 	const time_t old_time = a.st_mtime;
 
-	int ret = FUNC_FAILURE;
-	if (app && *app) {
-		char *cmd[] = {app, prompts_file, NULL};
-		ret = launch_execv(cmd, FOREGROUND, E_NOFLAG);
-	} else {
-		open_in_foreground = 1;
-		ret = open_file(prompts_file);
-		open_in_foreground = 0;
-	}
-
+	int ret = open_config_file(app, prompts_file);
 	if (ret != FUNC_SUCCESS)
 		return ret;
 
@@ -1282,12 +1786,12 @@ edit_prompts_file(char *app)
 		return errno;
 	}
 
-	if (conf.autols == 1)
-		reload_dirlist();
-
 	if (old_time == a.st_mtime)
 		return FUNC_SUCCESS;
 
+	if (conf.autols == 1)
+		reload_dirlist();
+
 	ret = load_prompts();
 	print_reload_msg(_("File modified. Prompts reloaded\n"));
 
