@@ -93,6 +93,8 @@ __BEGIN_DECLS
 char *prompt(const int prompt_flag);
 char *decode_prompt(char *line);
 int  prompt_function(char **args);
+char *gen_color(char **line);
+void set_prompt_options(void);
 
 __END_DECLS
 
