@@ -435,7 +435,7 @@ get_new_perms(const char *str, const int diff)
 {
 	const int poffset_bk = prompt_offset;
 	prompt_offset = 3;
-	xrename = 2; /* Disable TAB completion for this prompt */
+	alt_prompt = 2; /* Disable TAB completion for this prompt */
 	rl_nohist = 1;
 
 	if (diff == 1) {
@@ -449,7 +449,7 @@ get_new_perms(const char *str, const int diff)
 
 	char *new_perms = secondary_prompt(m, str);
 
-	xrename = rl_nohist = 0;
+	alt_prompt = rl_nohist = 0;
 	prompt_offset = poffset_bk;
 
 	if (diff == 0 && new_perms && *str == *new_perms
@@ -613,7 +613,7 @@ get_new_ownership(const char *str, const int diff)
 {
 	const int poffset_bk = prompt_offset;
 	prompt_offset = 3;
-	xrename = 3; /* Allow completion only for user and group names */
+	alt_prompt = 3; /* Allow completion only for user and group names */
 	rl_nohist = 1;
 
 	if (diff == 1) {
@@ -627,7 +627,7 @@ get_new_ownership(const char *str, const int diff)
 
 	char *new_own = secondary_prompt(m, str);
 
-	xrename = rl_nohist = 0;
+	alt_prompt = rl_nohist = 0;
 	prompt_offset = poffset_bk;
 
 	if (diff == 0 && new_own && *str == *new_own && strcmp(str, new_own) == 0) {
@@ -1076,7 +1076,7 @@ print_file_perms(const struct stat *attr, const char file_type_char,
 }
 
 static void
-print_file_name(char *filename, const char *color, const int follow_link,
+print_filename(char *filename, const char *color, const int follow_link,
 	const mode_t mode, char *link_target)
 {
 	char *wname = wc_xstrlen(filename) == 0
@@ -1918,7 +1918,7 @@ do_stat(char *filename, const int follow_link)
 #endif /* LINUX_FILE_XATTRS */
 
 	print_file_perms(&attr, file_type, ctype, xattr);
-	print_file_name(filename, color, follow_link, attr.st_mode, link_target);
+	print_filename(filename, color, follow_link, attr.st_mode, link_target);
 	print_file_details(filename, &attr, file_type, file_perm, xattr);
 	print_file_mime(*link_target ? link_target : filename);
 	print_timestamps(*link_target ? link_target : filename, &attr);
