@@ -31,9 +31,9 @@ int  initialize_readline(void);
 int  is_quote_char(const char c);
 char **my_rl_completion(const char *text, int start, int end);
 char *my_rl_path_completion(const char *text, int state);
-int  rl_get_y_or_n(const char *_msg);
-char *rl_no_hist(const char *prompt);
-char *secondary_prompt(const char *_prompt, const char *line);
+int  rl_get_y_or_n(const char *msg_str);
+char *rl_no_hist(const char *prompt_str);
+char *secondary_prompt(const char *prompt_str, const char *line);
 
 __END_DECLS
 
