@@ -236,6 +236,7 @@ remotes_unmount(char *name)
 		return FUNC_FAILURE;
 
 	/* Get out of mountpoint before unmounting */
+	int reload_files = 0;
 	size_t mlen = strlen(remotes[i].mountpoint);
 	if (strncmp(remotes[i].mountpoint, workspaces[cur_ws].path, mlen) == 0) {
 		if (mlen > 0 && remotes[i].mountpoint[mlen - 1] == '/') {
@@ -264,12 +265,15 @@ remotes_unmount(char *name)
 		*p = '/';
 
 		if (conf.autols == 1)
-			reload_dirlist();
+			reload_files = 1;
 	}
 
 	if (launch_execl(remotes[i].unmount_cmd) != FUNC_SUCCESS)
 		return FUNC_FAILURE;
 
+	if (reload_files == 1)
+		reload_dirlist();
+
 	remotes[i].mounted = 0;
 	return FUNC_SUCCESS;
 }
@@ -290,16 +294,7 @@ remotes_edit(char *app)
 
 	const time_t mtime_bfr = attr.st_mtime;
 
-	int ret = FUNC_SUCCESS;
-	if (app && *app) {
-		char *cmd[] = {app, remotes_file, NULL};
-		ret = launch_execv(cmd, FOREGROUND, E_NOFLAG);
-	} else {
-		open_in_foreground = 1;
-		ret = open_file(remotes_file);
-		open_in_foreground = 0;
-	}
-
+	const int ret = open_config_file(app, remotes_file);
 	if (ret != FUNC_SUCCESS)
 		return ret;
 
