@@ -64,7 +64,7 @@ struct search_t {
 static int
 exec_find(char *name, char *_path, char *method, char *pattern)
 {
-	if (follow_symlinks == 1) {
+	if (conf.follow_symlinks == 1) {
 		char *cmd[] = {name, "-L", _path, method, pattern, NULL};
 		return launch_execv(cmd, FOREGROUND, E_NOSTDERR);
 	}
