@@ -66,7 +66,7 @@ int
 save_sel(void)
 {
 	if (selfile_ok == 0 || config_ok == 0 || !sel_file)
-		return FUNC_FAILURE;
+		return (xargs.stealth_mode == 1 ? FUNC_SUCCESS : FUNC_FAILURE);
 
 	if (sel_n == 0) {
 		if (unlink(sel_file) == -1) {
@@ -545,7 +545,7 @@ construct_sel_path(char *sel_path)
 	char tmpdir[PATH_MAX + 1];
 	xstrsncpy(tmpdir, sel_path, sizeof(tmpdir));
 
-	if (*sel_path == '.' && realpath(sel_path, tmpdir) == NULL) {
+	if (*sel_path == '.' && xrealpath(sel_path, tmpdir) == NULL) {
 		xerror("sel: '%s': %s\n", sel_path, strerror(errno));
 		return (char *)NULL;
 	}
@@ -616,11 +616,16 @@ get_sel_file_size(const size_t i, int *status)
 	if (lstat(sel_elements[i].name, &attr) == -1)
 		return (off_t)-1;
 
-	const int base = xargs.si == 1 ? 1000 : 1024;
 	if (S_ISDIR(attr.st_mode)) {
+		fputs(dn_c, stdout);
 		fputs(_("Calculating file size... "), stdout); fflush(stdout);
+		fputs(df_c, stdout);
+#ifdef USE_DU1
 		sel_elements[i].size = (off_t)(dir_size(sel_elements[i].name,
-			0, status) * base);
+			0, status) * (xargs.si == 1 ? 1000 : 1024));
+#else
+		sel_elements[i].size = dir_size(sel_elements[i].name, 0, status);
+#endif /* USE_DU1 */
 		putchar('\r'); ERASE_TO_RIGHT; fflush(stdout);
 	} else {
 		sel_elements[i].size = (off_t)FILE_SIZE(attr);
@@ -832,7 +837,7 @@ list_selected_files(void)
 		return;
 	}
 
-	if (conf.clear_screen == 1)
+	if (conf.clear_screen > 0)
 		CLEAR;
 
 	if (conf.pager == 0)
@@ -1125,7 +1130,7 @@ static char **
 get_desel_input(size_t *n)
 {
 	printf(_("\n%sEnter 'q' to quit or 'e' to edit the selections file\n"
-		"File(s) to be deselected (ex: 1 2-6, or *):\n"), df_c);
+		"File(s) to be deselected (e.g.: 1 2-6, or *):\n"), df_c);
 
 	char dp[(MAX_COLOR * 2) + 7];
 	snprintf(dp, sizeof(dp), "\001%s\002>\001%s\002 ", mi_c, tx_c);
