@@ -288,7 +288,7 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_DL_C256  "\x1b[38;5;243m"   /* Dividing line */
 #define DEF_EL_C256  "\x1b[0;36m"   /* ELN's */
 #define DEF_EM_C256  "\001\x1b[1;31m\002" /* Error msg indicator */
-#define DEF_FC_C256  "\x1b[0;38;5;246m" /* Files counter */
+#define DEF_FC_C256  "\x1b[0;38;5;247m" /* Files counter */
 #define DEF_LI_C256  "\001\x1b[1;32m\002" /* Sel files indicator (prompt) */
 #define DEF_LI_CB256 "\x1b[1;32m"   /* Sel files indicator (files list) */
 #define DEF_MI_C256  "\x1b[1;36m"   /* Misc */
@@ -323,8 +323,8 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 /* Suggestions */
 #define DEF_SB_C256  "\x1b[2;33m"   /* Shell built-ins */
 #define DEF_SC_C256  "\x1b[2;36m"   /* Aliases and binaries in PATH */
-#define DEF_SD_C256  "\x1b[38;5;243m"   /* Internal commands description */
-#define DEF_SH_C256  "\x1b[38;5;243m"   /* Commands history */
+#define DEF_SD_C256  "\x1b[38;5;240m"   /* Internal commands description */
+#define DEF_SH_C256  "\x1b[38;5;240m"   /* Commands history */
 #define DEF_SF_C256  "\x1b[2;4;36m" /* ELN's, bookmark, file, and directory names */
 #define DEF_SP_C256  "\x1b[2;31m"   /* Suggestions pointer (12 > filename) */
 #define DEF_SX_C256  "\x1b[2;32m"   /* Internal commands and parameters */
@@ -489,7 +489,6 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_MAX_HIST 1000
 #define DEF_MAX_JUMP_TOTAL_RANK 100000
 #define DEF_MAX_LOG 1000
-#define DEF_MAX_PATH 40
 #define DEF_MAX_PRINTSEL 0
 #define DEF_MIN_JUMP_RANK 10
 #define DEF_MIN_NAME_TRIM 20
@@ -504,6 +503,11 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_PRINTSEL 0
 #define DEF_PRINT_REMOVED_FILES 1
 #define DEF_PRIVATE_WS_SETTINGS 0
+#define DEF_PROMPT_B_MIN 0
+#define DEF_PROMPT_B_PRECISION 2
+#define DEF_PROMPT_F_DIR_LEN 1
+#define DEF_PROMPT_F_FULL_LEN_DIRS 1
+#define DEF_PROMPT_P_MAX_PATH 40
 /* "xfpIsm" =
  * xattrs/caps/ACLs, files counter, perms, owner/grp names, size (human), mtime */
 #define DEF_PROP_FIELDS "xfpIsm"
@@ -546,6 +550,7 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_TIMESTAMP_MARK 0
 #define DEF_TIPS 1
 #define DEF_TRASRM 0
+#define DEF_TRASH_FORCE 1
 #define DEF_TRIM_NAMES 1
 #define DEF_WELCOME_MESSAGE 1
 
