@@ -34,6 +34,9 @@
 #include "listing.h"
 #include "messages.h" /* SORT_USAGE */
 
+#define F_SORT(a, b)      ((a) == (b) ? 0 : ((a) > (b) ? 1 : -1))
+#define F_SORT_DIRS(a, b) ((a) == (b) ? 0 : ((a) < (b) ? 1 : -1))
+
 int
 skip_files(const struct dirent *ent)
 {
@@ -140,150 +143,83 @@ namecmp(char *s1, char *s2)
 }
 
 static inline int
-sort_by_extension(const char *n1, const char *n2, const int n1dir,
-	const int n2dir)
+sort_by_extension(struct fileinfo *pa, struct fileinfo *pb)
 {
-	int ret = 0;
-	char *aext = (char *)NULL, *bext = (char *)NULL, *val;
+	char *e1 = (char *)NULL;
+	char *e2 = (char *)NULL;
 
-	/* If the entry is a directory, we don't take it as having an extension,
-	 * even if it has a dot in its name. */
-	val = n1dir == 0 ? strrchr(n1, '.') : (char *)NULL;
-	if (val && val != n1)
-		aext = val + 1;
-
-	val = n2dir == 0 ? strrchr(n2, '.') : (char *)NULL;
-	if (val && val != n2)
-		bext = val + 1;
-
-	if (aext || bext) {
-		if (!aext)
-			ret = -1;
-		else if (!bext)
-			ret = 1;
-		else
-			ret = strcasecmp(aext, bext);
+	if (pa->dir == 0) {
+		if (pa->ext_name) {
+			e1 = pa->ext_name + (pa->ext_name[1] != '\0');
+		} else {
+			char *p = strrchr(pa->name, '.');
+			if (p && p[1])
+				e1 = p + 1;
+		}
 	}
 
-	return ret;
-}
-
-static inline int
-sort_by_size(struct fileinfo *pa, struct fileinfo *pb)
-{
-	const off_t as = pa->size, bs = pb->size;
-
-	if (as > bs)
-		return 1;
-
-	if (as < bs)
-		return (-1);
-
-	return 0;
-}
-
-static inline int
-sort_by_time(const time_t a, const time_t b)
-{
-	int ret = 0;
-
-	if (a > b) {
-		ret = 1;
-	} else {
-		if (a < b)
-			ret = -1;
+	if (pb->dir == 0) {
+		if (pb->ext_name) {
+			e2 = pb->ext_name + (pb->ext_name[1] != '\0');
+		} else {
+			char *p = strrchr(pb->name, '.');
+			if (p && p[1])
+				e2 = p + 1;
+		}
 	}
 
-	return ret;
-}
-
-static inline int
-sort_by_inode(const ino_t a, const ino_t b)
-{
-	int ret = 0;
-
-	if (a > b) {
-		ret = 1;
-	} else {
-		if (a < b)
-			ret = -1;
-	}
-
-	return ret;
-}
-
-static inline int
-sort_by_owner(const uid_t a, const uid_t b)
-{
-	int ret = 0;
-
-	if (a > b) {
-		ret = 1;
-	} else {
-		if (a < b)
-			ret = -1;
-	}
-
-	return ret;
-}
-
-static inline int
-sort_by_group(const gid_t a, const gid_t b)
-{
-	int ret = 0;
-
-	if (a > b) {
-		ret = 1;
-	} else {
-		if (a < b)
-			ret = -1;
-	}
-
-	return ret;
-}
-
-static inline int
-sort_by_blocks(const blkcnt_t a, const blkcnt_t b)
-{
-	int ret = 0;
-
-	if (a > b) {
-		ret = 1;
-	} else {
-		if (a < b)
-			ret = -1;
-	}
-
-	return ret;
-}
-
-static inline int
-sort_by_links(const nlink_t a, const nlink_t b)
-{
-	int ret = 0;
-
-	if (a > b) {
-		ret = 1;
-	} else {
-		if (a < b)
-			ret = -1;
-	}
-
-	return ret;
-}
-
-static inline int
-sort_dirs(const int a, const int b)
-{
-	if (b != a) {
-		if (b)
+	if (e1 || e2) {
+		if (!e1)
+			return (-1);
+		if (!e2)
 			return 1;
-		return (-1);
+
+		return strcasecmp(e1, e2);
 	}
 
 	return 0;
 }
 
+static inline int
+sort_by_owner(struct fileinfo *pa, struct fileinfo *pb)
+{
+	if (pa->uid_i.name && pb->uid_i.name)
+		return namecmp(pa->uid_i.name, pb->uid_i.name);
+
+	return F_SORT(pa->uid, pb->uid);
+}
+
+static inline int
+sort_by_group(struct fileinfo *pa, struct fileinfo *pb)
+{
+	if (pa->gid_i.name && pb->gid_i.name)
+		return namecmp(pa->gid_i.name, pb->gid_i.name);
+
+	return F_SORT(pa->gid, pb->gid);
+}
+
+static inline int
+sort_by_type(struct fileinfo *pa, struct fileinfo *pb)
+{
+	const mode_t m1 = pa->type;
+	const mode_t m2 = pb->type;
+
+	const int e1 = (pa->type == DT_REG && pa->exec == 1);
+	const int e2 = (pb->type == DT_REG && pb->exec == 1);
+
+	if (e1 > e2)
+		return 1;
+	if (e2 > e1)
+		return (-1);
+
+	if (m1 > m2)
+		return 1;
+	if (m2 > m1)
+		return (-1);
+
+	return sort_by_extension(pa, pb);
+}
+
 int
 entrycmp(const void *a, const void *b)
 {
@@ -293,7 +229,7 @@ entrycmp(const void *a, const void *b)
 	int st = conf.sort;
 
 	if (conf.list_dirs_first == 1) {
-		ret = sort_dirs(pa->dir, pb->dir);
+		ret = F_SORT_DIRS(pa->dir, pb->dir);
 		if (ret != 0)
 			return ret;
 	}
@@ -302,24 +238,25 @@ entrycmp(const void *a, const void *b)
 		st = SNAME;
 
 	switch (st) {
-	case STSIZE: ret = sort_by_size(pa, pb); break;
+	case STSIZE: ret = F_SORT(pa->size, pb->size); break;
 	case SATIME: /* fallthrough */
 	case SBTIME: /* fallthrough */
 	case SCTIME: /* fallthrough */
-	case SMTIME: ret = sort_by_time(pa->time, pb->time); break;
+	case SMTIME: ret = F_SORT(pa->time, pb->time); break;
 	case SVER: ret = xstrverscmp(pa->name, pb->name); break;
-	case SEXT:
-		ret = sort_by_extension(pa->name, pb->name, pa->dir, pb->dir); break;
-	case SINO: ret = sort_by_inode(pa->inode, pb->inode); break;
-	case SOWN: ret = sort_by_owner(pa->uid, pb->uid); break;
-	case SGRP: ret = sort_by_group(pa->gid, pb->gid); break;
-	case SBLK: ret = sort_by_blocks(pa->blocks, pb->blocks); break;
-	case SLNK: ret = sort_by_links(pa->linkn, pb->linkn); break;
+	case SEXT: ret = sort_by_extension(pa, pb); break;
+	case SINO: ret = F_SORT(pa->inode, pb->inode); break;
+	case SOWN: ret = sort_by_owner(pa, pb); break;
+	case SGRP: ret = sort_by_group(pa, pb); break;
+	case SBLK: ret = F_SORT(pa->blocks, pb->blocks); break;
+	case SLNK: ret = F_SORT(pa->linkn, pb->linkn); break;
+	case STYPE: ret = sort_by_type(pa, pb); break;
 	default: break;
 	}
 
 	if (!ret)
 		ret = namecmp(pa->name, pb->name);
+
 	if (!conf.sort_reverse)
 		return ret;
 
@@ -386,6 +323,7 @@ num_to_sort_name(const int n)
 	case SGRP:   return "group";
 	case SBLK:   return "blocks";
 	case SLNK:   return "links";
+	case STYPE:  return "type";
 	default:     return "unknown";
 	}
 }
