@@ -138,6 +138,44 @@ count_chars(const char *restrict s, const char c)
 	return n;
 }
 
+/* Return the number of words found in the current readline buffer. */
+size_t
+count_words(size_t *start_word, size_t *full_word)
+{
+	size_t words = 0, w = 0, first_non_space = 0;
+	char q = 0;
+	char *b = rl_line_buffer;
+
+	for (; b[w]; w++) {
+		/* Keep track of open quotes. */
+		if (b[w] == '\'' || b[w] == '"')
+			q = q == b[w] ? 0 : b[w];
+
+		if (!first_non_space && b[w] != ' ') {
+			words = 1;
+			*start_word = w;
+			first_non_space = 1;
+			continue;
+		}
+
+		if (w > 0 && b[w] == ' ' && b[w - 1] != '\\') {
+			if (!*full_word && b[w - 1] != '|'
+			&& b[w - 1] != ';' && b[w - 1] != '&')
+				*full_word = w; /* Index of the end of the first full word (cmd). */
+			if (b[w + 1] && b[w + 1] != ' ')
+				words++;
+		}
+
+		/* If a process separator char is found, reset variables so that we
+		 * can start counting again for the new command. */
+		if (!q && cur_color != hq_c && w > 0 && b[w - 1] != '\\'
+		&& ((b[w] == '&' && b[w - 1] == '&') || b[w] == '|' || b[w] == ';'))
+			words = first_non_space = *full_word = 0;
+	}
+
+	return words;
+}
+
 /* Get the last occurrence of the (non-escaped) character C in STR (whose
  * length is LEN). Return a pointer to it if found or NULL if not. */
 char *
@@ -633,27 +671,6 @@ strcntchr(const char *str, const char c)
 	return (-1);
 }
 
-/* Returns the index of the last appearance of C in STR, if any, and
- * -1 if C was not found or STR is NULL. */
-int
-strcntchrlst(const char *str, const char c)
-{
-	if (!str)
-		return (-1);
-
-	int i = 0;
-
-	int p = -1;
-	while (*str) {
-		if (*str == c)
-			p = i;
-		i++;
-		str++;
-	}
-
-	return p;
-}
-
 /* Get substring in STR before the last appearance of C. Returns
  * substring  if C is found and NULL if not (or if C was the first
  * char in STR). */
@@ -1232,7 +1249,7 @@ check_shell_functions(const char *str)
 	if (!str || !*str)
 		return 0;
 
-	if (int_vars == 0) { /* Take assignements as shell functions */
+	if (conf.int_vars == 0) { /* Take assignements as shell functions */
 		const char *s = strchr(str, ' ');
 		const char *e = strchr(str, '=');
 		if (!s && e)
@@ -1820,6 +1837,50 @@ expand_sel_keyword(char ***substr)
 		(*substr)[0][1] = '\0';
 }
 
+static int
+expand_workspace(char **name)
+{
+	char *ws_name = *name + 2;
+
+	if (is_number(ws_name)) {
+		const int n = MAX_WS > 9 ? atoi(ws_name) : *ws_name - '0';
+		if (n <= 0 || n > MAX_WS || !workspaces[n - 1].path)
+			return FUNC_FAILURE;
+
+		char *q = escape_str(workspaces[n - 1].path);
+		char *tmp = q ? q : workspaces[n - 1].path;
+		const size_t tmp_len = strlen(tmp);
+		*name = xnrealloc(*name, tmp_len + 1, sizeof(char));
+		xstrsncpy(*name, tmp, tmp_len + 1);
+		free(q);
+
+		return FUNC_SUCCESS;
+	}
+
+	char *deq_str = unescape_str(ws_name, 0);
+	char *tmp_name = deq_str ? deq_str : ws_name;
+	size_t i = 0;
+	for (i = 0; i < MAX_WS; i++) {
+		if (!workspaces[i].path || !workspaces[i].name
+		|| *tmp_name != *workspaces[i].name
+		|| strcmp(tmp_name, workspaces[i].name) != 0)
+			continue;
+
+		char *q = escape_str(workspaces[i].path);
+		char *tmp = q ? q : workspaces[i].path;
+		const size_t tmp_len = strlen(tmp);
+		*name = xnrealloc(*name, tmp_len + 1, sizeof(char));
+		xstrsncpy(*name, tmp, tmp_len + 1);
+		free(q);
+		free(deq_str);
+
+		return FUNC_SUCCESS;
+	}
+
+	free(deq_str);
+	return FUNC_FAILURE;
+}
+
 /* Expand the bookmark NAME into the corresponding bookmark path.
  * Returns FUNC_SUCCESS if the expansion took place or FUNC_FAILURE otherwise */
 static int
@@ -2757,7 +2818,7 @@ parse_input_str(char *str)
 			/* If user defined variable send the whole string to
 			 * exec_cmd(), which will take care of storing the
 			 * variable. */
-			if (!(flags & IS_USRVAR_DEF) && int_vars == 1 && str[i] == '='
+			if (!(flags & IS_USRVAR_DEF) && conf.int_vars == 1 && str[i] == '='
 			&& i > 0 && str[i - 1] != '\\' && str[0] != '=') {
 				if (check_int_var(str) == 1)
 					flags |= IS_USRVAR_DEF;
@@ -2864,7 +2925,7 @@ parse_input_str(char *str)
 		char *lb_tmp = rl_line_buffer;
 		if (rl_dispatching == 0 && fusedcmd_ok == 1)
 			rl_line_buffer = substr[0];
-		if (should_expand_eln(substr[i]) == 1)
+		if (should_expand_eln(substr[i], substr[0]) == 1)
 			eln_expand(&substr, i);
 		rl_line_buffer = lb_tmp;
 
@@ -2953,18 +3014,27 @@ parse_input_str(char *str)
 				continue;
 		}
 
+			/* ######################################
+			 * #     2.9) WORKSPACE EXPANSION       #
+			 * ###################################### */
+
+		if (*substr[i] == 'w' && substr[i][1] == ':' && substr[i][2]) {
+			if (expand_workspace(&substr[i]) == FUNC_SUCCESS)
+				continue;
+		}
+
 			/* ###################################
-			 * #   2.9) USER DEFINED VARIABLES   #
+			 * #   2.10) USER DEFINED VARIABLES   #
 			 * ###################################*/
 
-		if (int_vars == 1 && usrvar_n > 0) {
+		if (conf.int_vars == 1 && usrvar_n > 0) {
 			if (substr[i][0] == '$' && substr[i][1] && substr[i][1] != '('
 			&& substr[i][1] != '{')
 				expand_int_var(&substr[i]);
 		}
 
 			/* ###################################
-			 * #  2.10) SYMLINKS IN VIRTUAL DIR  #
+			 * #  2.11) SYMLINKS IN VIRTUAL DIR  #
 			 * ################################### */
 
 		/* We are in STDIN_TMP_DIR: Expand symlinks to target */
@@ -2979,13 +3049,13 @@ parse_input_str(char *str)
 	/* The following expansions expand into MULTIPLE fields */
 
 				/* ###########################
-				 * #   2.11) SEL EXPANSION   #
+				 * #   2.12) SEL EXPANSION   #
 				 * ########################### */
 
 	expand_sel_keyword(&substr);
 
 				/* #################################
-				 * #     2.12) TAGS EXPANSION      #
+				 * #     2.13) TAGS EXPANSION      #
 				 * ################################# */
 
 #ifndef _NO_TAGS
@@ -2993,20 +3063,20 @@ parse_input_str(char *str)
 #endif /* _NO_TAGS */
 
 				/* ################################
-				 * #    2.13) FILE TYPE (=CHAR)   #
+				 * #    2.14) FILE TYPE (=CHAR)   #
 				 * ################################ */
 
 	expand_file_type(&substr);
 
 				/* ##################################
-				 * #   2.14) MIME TYPE (@PATTERN)   #
+				 * #   2.15) MIME TYPE (@PATTERN)   #
 				 * ################################## */
 #ifndef _NO_MAGIC
 	expand_mime_type(&substr);
 #endif /* !_NO_MAGIC */
 
 				/* ###############################
-				 * #    2.15) BOOKMARKS (b:)     #
+				 * #    2.16) BOOKMARKS (b:)     #
 				 * ############################### */
 
 	expand_bookmarks(&substr);
@@ -3178,13 +3248,14 @@ savestring(const char *restrict str, size_t size)
 	if (!str)
 		return (char *)NULL;
 
-	char *ptr = (char *)NULL;
-	ptr = malloc((size + 1) * sizeof(char));
-
+	char *ptr = malloc((size + 1) * sizeof(char));
 	if (!ptr)
 		return (char *)NULL;
 
-	xstrsncpy(ptr, str, size + 1);
+	const char *ret = memccpy(ptr, str, '\0', size + 1);
+	if (!ret)
+		ptr[size] = '\0';
+
 	return ptr;
 }
 
