@@ -445,7 +445,7 @@ calculate_suggestion_lines(int *baej, const size_t suggestion_len)
 	|| suggestion.type == JCMD_SUG_NOACD || suggestion.type == BACKDIR_SUG
 	|| suggestion.type == SORT_SUG || suggestion.type == WS_NUM_SUG
 	|| suggestion.type == FUZZY_FILENAME || suggestion.type == DIRHIST_SUG
-	|| suggestion.type == FASTBACK_SUG
+	|| suggestion.type == FASTBACK_SUG || suggestion.type == WS_NUM_PREFIX_SUG
 	|| (suggestion.type == COMP_SUG && (flags & BAEJ_SUGGESTION))) {
 		/* 3 = 1 (one char forward) + 2 (" >") */
 		cuc += 3;
@@ -656,7 +656,8 @@ get_reg_file_color(const char *filename, const struct stat *attr,
 	if (FILE_SIZE_PTR(attr) == 0) return ef_c;
 	if (attr->st_nlink > 1)	return mh_c;
 
-	const char *ext = check_ext == 1 ? strrchr(filename, '.') : (char *)NULL;
+	const char *ext =
+		conf.check_ext == 1 ? strrchr(filename, '.') : (char *)NULL;
 	if (!ext || ext == filename)
 		return fi_c;
 
@@ -1498,43 +1499,6 @@ is_last_word(void)
 	return lw;
 }
 
-/* Return the number of words found in the current readline buffer. */
-static size_t
-count_words(size_t *start_word, size_t *full_word)
-{
-	size_t words = 0, w = 0, first_non_space = 0;
-	char q = 0;
-	char *b = rl_line_buffer;
-	for (; b[w]; w++) {
-		/* Keep track of open quotes. */
-		if (b[w] == '\'' || b[w] == '"')
-			q = q == b[w] ? 0 : b[w];
-
-		if (!first_non_space && b[w] != ' ') {
-			words = 1;
-			*start_word = w;
-			first_non_space = 1;
-			continue;
-		}
-		if (w > 0 && b[w] == ' ' && b[w - 1] != '\\') {
-			if (!*full_word && b[w - 1] != '|'
-			&& b[w - 1] != ';' && b[w - 1] != '&')
-				*full_word = w; /* Index of the end of the first full word (cmd). */
-			if (b[w + 1] && b[w + 1] != ' ') {
-				words++;
-			}
-		}
-		/* If a process separator char is found, reset variables so that we
-		 * can start counting again for the new command. */
-		if (!q && cur_color != hq_c && w > 0 && b[w - 1] != '\\'
-		&& ((b[w] == '&' && b[w - 1] == '&') || b[w] == '|' || b[w] == ';')) {
-			words = first_non_space = *full_word = 0;
-		}
-	}
-
-	return words;
-}
-
 static void
 turn_it_wrong(void)
 {
@@ -1677,7 +1641,7 @@ get_last_word(const char *last_space)
 }
 
 static int
-check_workspaces(char *word, size_t wlen)
+check_workspaces(char *word, size_t wlen, const int type)
 {
 	if (!word || !*word || !workspaces)
 		return NO_MATCH;
@@ -1685,7 +1649,8 @@ check_workspaces(char *word, size_t wlen)
 	if (*word >= '1' && *word <= MAX_WS + '0' && !*(word + 1)) {
 		const int a = atoi(word);
 		if (a > 0 && workspaces[a - 1].name) {
-			suggestion.type = WS_NUM_SUG;
+			suggestion.type = type == WS_PREFIX_SUG
+				? WS_NUM_PREFIX_SUG : WS_NUM_SUG;
 			print_suggestion(workspaces[a - 1].name, 0, sf_c);
 			return PARTIAL_MATCH;
 		}
@@ -1709,7 +1674,7 @@ check_workspaces(char *word, size_t wlen)
 
 		if (TOUPPER(*w) == TOUPPER(*workspaces[i].name)
 		&& strncasecmp(w, workspaces[i].name, l) == 0) {
-			suggestion.type = WS_NAME_SUG;
+			suggestion.type = type;
 			char *p = escape_str(workspaces[i].name);
 			print_suggestion(p ? p : workspaces[i].name, wlen, sf_c);
 			free(p);
@@ -1900,7 +1865,7 @@ check_bookmark_names(char *word, const size_t len)
 }
 
 static int
-check_backdir(void)
+check_backdir(char *start)
 {
 	if (!workspaces || !workspaces[cur_ws].path)
 		return NO_MATCH;
@@ -1914,7 +1879,7 @@ check_backdir(void)
 	if (q)
 		*q = '\0';
 
-	char *lb = rl_line_buffer + 3;
+	char *lb = start + 3;
 	char *ds = strchr(lb, '\\') ? unescape_str(lb, 0) : lb;
 
 	/* Find the query string in the list of parent directories. */
@@ -2031,6 +1996,9 @@ rl_suggestions(const unsigned char c)
 		rl_line_buffer[full_word] = ' ';
 	}
 
+	/* A pointer to the beginning of the last word (command name) */
+	char *s = rl_line_buffer + start_word;
+
 	char *word = (words_num == 1 && c != ' ' && first_word)
 		? first_word : last_word;
 	size_t wlen = strlen(word);
@@ -2058,7 +2026,7 @@ rl_suggestions(const unsigned char c)
 	}
 
 	/* '~' or '~/' */
-	if (word && *word == '~' && (!word[1] || (word[1] == '/' && !word[2]))) {
+	if (*word == '~' && (!word[1] || (word[1] == '/' && !word[2]))) {
 		if (wrong_cmd)
 			recover_from_wrong_cmd();
 
@@ -2077,7 +2045,7 @@ rl_suggestions(const unsigned char c)
 		 * ######################################*/
 
 	/* Fastback */
-	if (word && *word == '.' && word[1] == '.' && (!word[2] || word[2] == '.')
+	if (*word == '.' && word[1] == '.' && (!word[2] || word[2] == '.')
 	&& (printed = check_fastback(word)) != NO_MATCH)
 		goto SUCCESS;
 
@@ -2147,17 +2115,17 @@ rl_suggestions(const unsigned char c)
 	/* 3.d) Let's suggest non-fixed parameters for internal commands
 	 * Only if second word or more (first word is the command name). */
 
-	switch (words_num > 1 ? *lb : '\0') {
+	switch (words_num > 1 ? *s : '\0') {
 	case 'b': /* Bookmark names */
-		if (bm_n > 0 && lb[1] == 'm' && lb[2] == ' ') {
-			if (!(*(lb + 3) == 'a' && *(lb + 4) == ' ')
-			&& strncmp(lb + 3, "add", 3) != 0) {
+		if (bm_n > 0 && s[1] == 'm' && s[2] == ' ') {
+			if (!(*(s + 3) == 'a' && *(s + 4) == ' ')
+			&& strncmp(s + 3, "add", 3) != 0) {
 				if ((printed = check_bookmark_names(word, wlen)) != NO_MATCH) {
 					goto SUCCESS;
 				} else {
 					if (suggestion.printed)
 						clear_suggestion(CS_FREEBUF);
-					if (*(lb + 3) != '-') /* Might be --help, let it continue. */
+					if (*(s + 3) != '-') /* Might be --help, let it continue. */
 						goto FAIL;
 				}
 			} else if (words_num > 5) {
@@ -2167,19 +2135,19 @@ rl_suggestions(const unsigned char c)
 		}
 
 		/* Backdir function (bd) */
-		else if (lb[1] == 'd' && lb[2] == ' ' && lb[3]) {
-				if (*(lb + 3) == '/' && !*(lb + 4)) {
+		else if (s[1] == 'd' && s[2] == ' ' && s[3]) {
+				if (*(s + 3) == '/' && !*(s + 4)) {
 					/* The query string is a single slash: do nothing. */
 					goto FAIL;
 				}
-				if ((printed = check_backdir()) != NO_MATCH)
+				if ((printed = check_backdir(s)) != NO_MATCH)
 					goto SUCCESS;
 		}
 		break;
 
 	case 'c': /* Color schemes */
-		if (conf.colorize == 1 && color_schemes && lb[1] == 's'
-		&& lb[2] == ' ') {
+		if (conf.colorize == 1 && color_schemes && s[1] == 's'
+		&& s[2] == ' ') {
 			if ((printed = check_color_schemes(word, wlen)) != NO_MATCH)
 				goto SUCCESS;
 		}
@@ -2187,7 +2155,7 @@ rl_suggestions(const unsigned char c)
 
 	case 'd': /* Dirhist command (dh) */
 		if (words_num == 2 && old_pwd && dirhist_total_index > 0 && wlen > 0
-		&& lb[1] == 'h' && lb[2] == ' ' && !strchr(word, '/')) {
+		&& s[1] == 'h' && s[2] == ' ' && !strchr(word, '/')) {
 			if ((printed = check_dirhist(word, wlen)) != NO_MATCH)
 				goto SUCCESS;
 			else
@@ -2196,8 +2164,9 @@ rl_suggestions(const unsigned char c)
 		break;
 
 	case 'j': /* j command */
-		if (lb[1] == ' '  || ((lb[1] == 'c'	|| lb[1] == 'p') && lb[2] == ' ')) {
-			if ((printed = check_jcmd(full_line)) != NO_MATCH) {
+		if (s[1] == ' ' || ((s[1] == 'c' || s[1] == 'p') && s[2] == ' ')) {
+//			if ((printed = check_jcmd(full_line)) != NO_MATCH) {
+			if ((printed = check_jcmd(s)) != NO_MATCH) {
 				zero_offset = 1;
 				goto SUCCESS;
 			} else {
@@ -2207,7 +2176,7 @@ rl_suggestions(const unsigned char c)
 		break;
 
 	case 'n': /* 'net' command: remotes */
-		if (remotes && lb[1] == 'e' && lb[2] == 't' && lb[3] == ' ') {
+		if (remotes && s[1] == 'e' && s[2] == 't' && s[3] == ' ') {
 			if ((printed = check_remotes(word, wlen)) != NO_MATCH)
 				goto SUCCESS;
 		}
@@ -2215,9 +2184,9 @@ rl_suggestions(const unsigned char c)
 
 	case 'p': /* Profiles */
 #ifndef _NO_PROFILES
-		if (profile_names && words_num == 3 && lb[1] == 'f' && lb[2] == ' '
-		&& (strncmp(lb + 3, "set ", 4) == 0 || strncmp(lb + 3, "del ", 4) == 0
-		|| strncmp(lb + 3, "rename ", 7) == 0)) {
+		if (profile_names && words_num == 3 && s[1] == 'f' && s[2] == ' '
+		&& (strncmp(s + 3, "set ", 4) == 0 || strncmp(s + 3, "del ", 4) == 0
+		|| strncmp(s + 3, "rename ", 7) == 0)) {
 			if ((printed = check_profiles(word, wlen)) != NO_MATCH)
 				goto SUCCESS;
 			else
@@ -2225,7 +2194,7 @@ rl_suggestions(const unsigned char c)
 		}
 #endif /* !_NO_PROFILES */
 
-		if (lb[1] == 'r' && strncmp(lb, "prompt set ", 11) == 0) {
+		if (s[1] == 'r' && strncmp(s, "prompt set ", 11) == 0) {
 			printed = check_prompts(word, wlen);
 			if (prompts_n > 0 && printed != NO_MATCH)
 				goto SUCCESS;
@@ -2233,7 +2202,7 @@ rl_suggestions(const unsigned char c)
 		break;
 
 	case 's': /* Sort */
-		if (((lb[1] == 't' && lb[2] == ' ') || strncmp(lb, "sort ", 5) == 0)
+		if (((s[1] == 't' && s[2] == ' ') || strncmp(s, "sort ", 5) == 0)
 		&& is_number(word)) {
 			if (words_num > 2)
 				goto FAIL;
@@ -2245,12 +2214,12 @@ rl_suggestions(const unsigned char c)
 
 #ifndef _NO_TAGS
 	case 't': /* Tag command */
-		if ((lb[1] == 'a' || lb[1] == 'u') && lb[2] == ' ') {
+		if ((s[1] == 'a' || s[1] == 'u') && s[2] == ' ') {
 			if (*word == ':' && *(word + 1)
 			&& (printed = check_tags(word + 1, wlen - 1, TAGC_SUG)) != NO_MATCH)
 				goto SUCCESS;
-		} else if ((lb[1] == 'l' || lb[1] == 'm' || lb[1] == 'n'
-		|| lb[1] == 'r' || lb[1] == 'y') && lb[2] == ' ') {
+		} else if ((s[1] == 'l' || s[1] == 'm' || s[1] == 'n'
+		|| s[1] == 'r' || s[1] == 'y') && s[2] == ' ') {
 			printed = check_tags(word, wlen, TAGS_SUG);
 			if (*word && printed != NO_MATCH)
 				goto SUCCESS;
@@ -2259,10 +2228,10 @@ rl_suggestions(const unsigned char c)
 #endif /* _NO_TAGS */
 
 	case 'w': /* Workspaces */
-		if (lb[1] == 's' && lb[2] == ' ') {
+		if (s[1] == 's' && s[2] == ' ') {
 			if (words_num > 2)
 				goto FAIL;
-			if ((printed = check_workspaces(word, wlen)) != NO_MATCH)
+			if ((printed = check_workspaces(word, wlen, WS_NAME_SUG)) != NO_MATCH)
 				goto SUCCESS;
 		}
 	break;
@@ -2288,6 +2257,12 @@ rl_suggestions(const unsigned char c)
 			goto SUCCESS;
 	}
 
+	/* Workspaces (w:) */
+	if (*word == 'w' && word[1] == ':' && word[2]) {
+		if ((printed = check_workspaces(word + 2, wlen - 2, WS_PREFIX_SUG)) != NO_MATCH)
+			goto SUCCESS;
+	}
+
 #ifndef _NO_TAGS
 	/* 3.d.4) Tag names (t:) */
 	if (*lb != ';' && *lb != ':' && *word == 't' && *(word + 1) == ':'
@@ -2390,7 +2365,7 @@ rl_suggestions(const unsigned char c)
 				clear_suggestion(CS_FREEBUF);
 
 			if (*lb != ';' && *lb != ':' && *word >= '1' && *word <= '9') {
-				if (should_expand_eln(word) == 1
+				if (should_expand_eln(word, first_word) == 1
 				&& (printed = check_eln(word, flag)) > 0)
 					goto SUCCESS;
 			}
@@ -2494,8 +2469,10 @@ CHECK_FIRST_WORD:
 
 	word = first_word ? first_word : last_word;
 
-	/* Skip 'b:' (bookmarks), 's:' (sel files) and 't:' (tags) constructs. */
-	if ((*word == 'b' || *word == 's' || *word == 't') && *(word + 1) == ':')
+	/* Skip 'b:' (bookmarks), 's:' (sel files) 't:' (tags) and 'w:'
+	 * (workspaces) constructs. */
+	if ((*word == 'b' || *word == 's' || *word == 't' || *word == 'w')
+	&& *(word + 1) == ':')
 		goto NO_SUGGESTION;
 
 	if (!word || !*word
