@@ -71,15 +71,15 @@ typedef char *rl_cpvfunc_t;
 # include "suggestions.h"
 #endif /* !_NO_SUGGESTIONS */
 
-#define CPR     "\x1b[6n" /* Cursor position report */
-#define CPR_LEN (sizeof(CPR) - 1)
+#ifndef _NO_FZF
+# define CPR_CODE "\x1b[6n" /* Cursor position report */
+# define CPR_LEN  (sizeof(CPR_CODE) - 1)
 
-#define SHOW_PREVIEWS(c) ((c) == TCMP_PATH || (c) == TCMP_SEL \
+# define SHOW_PREVIEWS(c) ((c) == TCMP_PATH || (c) == TCMP_SEL \
 || (c) == TCMP_RANGES || (c) == TCMP_DESEL || (c) == TCMP_JUMP \
 || (c) == TCMP_TAGS_F || (c) == TCMP_GLOB || (c) == TCMP_FILE_TYPES_FILES \
 || (c) == TCMP_BM_PATHS || (c) == TCMP_UNTRASH || (c) == TCMP_TRASHDEL)
 
-#ifndef _NO_FZF
 static char finder_in_file[PATH_MAX + 1];
 static char finder_out_file[PATH_MAX + 1];
 
@@ -151,7 +151,7 @@ get_cursor_position(int *c, int *l)
 	if (enable_raw_mode(STDIN_FILENO) == -1) return FUNC_FAILURE;
 
 	/* 1. Ask the terminal about cursor position */
-	if (write(STDOUT_FILENO, CPR, CPR_LEN) != CPR_LEN)
+	if (write(STDOUT_FILENO, CPR_CODE, CPR_LEN) != CPR_LEN)
 		{ disable_raw_mode(STDIN_FILENO); return FUNC_FAILURE; }
 
 	/* 2. Read the response: "ESC [ rows ; cols R" */
@@ -384,7 +384,7 @@ fzftab_color(char *filename, const struct stat *attr)
 			return nf_c;
 
 		char *cl = get_file_color(filename, attr);
-		if (check_ext == 0 || cl != fi_c)
+		if (conf.check_ext == 0 || cl != fi_c)
 			return (cl ? cl : fi_c);
 
 		/* If trashed file, remove the trash extension, so we can get the
@@ -753,12 +753,12 @@ static size_t
 get_preview_win_width(const int offset)
 {
 	size_t w = 0;
-	size_t l = longest_prev_entry + 8 + (fzf_border_type <= 0 ? 0
+	const size_t l = longest_prev_entry + 8 + (fzf_border_type <= 0 ? 0
 		/* fzf_border_type == 1 (right or left): this takes 2 extra columns.
 		 * fzf_border_type == 2 (rounded, sharp, bold, block, thinblock,
 		 * double, or vertical): this takes 4 extra columns. */
 		: (fzf_border_type == 1 ? 2 : 4));
-	int total_win_width = term_cols - offset;
+	const int total_win_width = term_cols - offset;
 
 	if (l < (size_t)total_win_width)
 		w = (size_t)total_win_width - l;
@@ -1143,7 +1143,8 @@ store_completions(char **matches)
 
 	if (ct == TCMP_TAGS_S || ct == TCMP_TAGS_U || ct == TCMP_SORT
 	|| ct == TCMP_BOOKMARK || ct == TCMP_CSCHEME || ct == TCMP_NET
-	|| ct == TCMP_PROF || ct == TCMP_PROMPTS || ct == TCMP_BM_PREFIX)
+	|| ct == TCMP_PROF || ct == TCMP_PROMPTS || ct == TCMP_BM_PREFIX
+	|| ct == TCMP_WS_PREFIX || ct == TCMP_WORKSPACES)
 		no_file_comp = 1; /* We're not completing file names. */
 
 	char *norm_prefix = (char *)NULL;
@@ -1245,7 +1246,6 @@ get_query_str(char *lw)
 	case TCMP_RANGES:           /* fallthrough */
 	case TCMP_SEL:              /* fallthrough */
 	case TCMP_BM_PATHS:         /* fallthrough */
-	case TCMP_TAGS_F:           /* fallthrough */
 	case TCMP_GLOB:             /* fallthrough */
 	case TCMP_CMD_DESC:         /* fallthrough */
 	case TCMP_FILE_TYPES_OPTS:  /* fallthrough */
@@ -1254,6 +1254,7 @@ get_query_str(char *lw)
 		break;
 
 	case TCMP_TAGS_T: /* fallthrough */
+	case TCMP_WS_PREFIX: /* fallthrough */
 	case TCMP_BM_PREFIX:
 		query = (lw && *lw && lw[1] && lb[2]) ? lw + 2 : (char *)NULL;
 		break;
@@ -1287,8 +1288,13 @@ get_query_str(char *lw)
 		break;
 
 	case TCMP_JUMP:
-		tmp = lb ? strchr(lb, ' ') : (char *)NULL;
-		query = (tmp && *tmp && tmp[1]) ? tmp + 1 : (char *)NULL;
+		if (lb && *lb == 'j' && lb[1] == ' ') {
+			query = lb[2] ? lb + 2 : (char *)NULL;
+		} else {
+			tmp = lb ? strstr(lb, "j ") : (char *)NULL;
+			query = (tmp && *tmp && tmp[1] && tmp[2])
+				? tmp + 2 : (char *)NULL;
+		}
 		break;
 
 	default: query = lw; break;
@@ -1552,7 +1558,7 @@ get_finder_offset(const char *query, const char *text, char **matches,
 
 	else if (ct == TCMP_JUMP) {
 		if (query) {
-			if (lb && *lb && lb[1] == ' ') {
+			if (lb && *lb == 'j' && lb[1] == ' ') {
 				/* The command is "j" */
 				finder_offset = prompt_offset - 1;
 			} else {
@@ -1633,7 +1639,7 @@ get_finder_offset(const char *query, const char *text, char **matches,
 	&& ct != TCMP_CMD_DESC && ct != TCMP_FILE_TYPES_OPTS
 	&& ct != TCMP_FILE_TYPES_FILES && ct != TCMP_MIME_LIST
 	&& ct != TCMP_TAGS_F && ct != TCMP_TAGS_T && ct != TCMP_TAGS_C
-	&& ct != TCMP_DIRHIST)
+	&& ct != TCMP_DIRHIST && ct != TCMP_WS_PREFIX)
 		finder_offset++; /* Last char is space */
 
 	while (finder_offset > term_cols)
@@ -1661,15 +1667,15 @@ do_some_cleanup(char **buf, char **matches, const char *query,
 	size_t *prefix_len)
 {
 	enum comp_type ct = cur_comp_type;
+	char *lb = rl_line_buffer;
 
 	/* TCMP_HIST might be either search or command history */
 	int cmd_hist = (ct == TCMP_HIST && rl_line_buffer
-		&& (*rl_line_buffer != '/' || rl_line_buffer[1] != '*'));
+		&& (*lb != '/' || lb[1] != '*'));
 
 	if (rl_point < rl_end && ct != TCMP_PATH && ct != TCMP_CMD) {
-		char *s = rl_line_buffer
-			? get_last_chr(rl_line_buffer, ' ', rl_point) : (char *)NULL;
-		int start = s ? (int)(s - rl_line_buffer + 1) : 0;
+		char *s = lb ? get_last_chr(lb, ' ', rl_point) : (char *)NULL;
+		int start = s ? (int)(s - lb + 1) : 0;
 		rl_delete_text(start, rl_point);
 		rl_point = start;
 	}
@@ -1683,20 +1689,34 @@ do_some_cleanup(char **buf, char **matches, const char *query,
 		*buf = tmp;
 	}
 
-	else if ((ct == TCMP_HIST && cmd_hist == 0) || ct == TCMP_JUMP) {
+	else if (ct == TCMP_HIST && cmd_hist == 0) {
 		rl_delete_text(0, rl_end);
 		rl_point = rl_end = 0;
 	}
 
+	else if (ct == TCMP_JUMP) {
+		if (*lb == 'j' && lb[1] == ' ') {
+			rl_delete_text(0, rl_end);
+			rl_point = rl_end = 0;
+		} else {
+			char *tmp = strstr(lb, "j ");
+			if (tmp && tmp[1] && tmp[2]) {
+				rl_point = (int)(tmp - lb + 2);
+				rl_delete_text(rl_point, rl_end);
+				rl_end = rl_point;
+			}
+		}
+	}
+
 	else if (cmd_hist == 1 || ct == TCMP_RANGES || ct == TCMP_SEL
 	|| ct == TCMP_TAGS_F || ct == TCMP_GLOB
 	|| ct == TCMP_BM_PATHS || ct == TCMP_BM_PREFIX
 	|| ct == TCMP_TAGS_T || ct == TCMP_DIRHIST) {
-		char *s = rl_line_buffer ? get_last_chr(rl_line_buffer,
+		char *s = lb ? get_last_chr(lb,
 			(ct == TCMP_GLOB && words_num == 1)
 			? '/' : ' ', rl_end) : (char *)NULL;
 		if (s) {
-			rl_point = (int)(s - rl_line_buffer + 1);
+			rl_point = (int)(s - lb + 1);
 			rl_delete_text(rl_point, rl_end);
 			rl_end = rl_point;
 		} else if (cmd_hist == 1 || ct == TCMP_BM_PATHS || ct == TCMP_TAGS_F
@@ -1708,9 +1728,8 @@ do_some_cleanup(char **buf, char **matches, const char *query,
 	}
 
 	else if (ct == TCMP_FILE_TYPES_FILES || ct == TCMP_CMD_DESC) {
-		char *s = rl_line_buffer
-			? get_last_chr(rl_line_buffer, ' ', rl_end) : (char *)NULL;
-		rl_point = !s ? 0 : (int)(s - rl_line_buffer + 1);
+		char *s = lb ? get_last_chr(lb, ' ', rl_end) : (char *)NULL;
+		rl_point = !s ? 0 : (int)(s - lb + 1);
 		rl_delete_text(rl_point, rl_end);
 		rl_end = rl_point;
 		ERASE_TO_RIGHT;
@@ -2217,6 +2236,7 @@ AFTER_USUAL_COMPLETION:
 		&& cur_comp_type != TCMP_CMD_DESC
 		&& cur_comp_type != TCMP_OWNERSHIP
 		&& cur_comp_type != TCMP_DIRHIST
+		&& (cur_comp_type != TCMP_WS_PREFIX || !matches[1])
 
 		&& (cur_comp_type != TCMP_BM_PATHS || !matches[1])
 
@@ -2243,10 +2263,13 @@ AFTER_USUAL_COMPLETION:
 			/* Let's keep the backslash, used to bypass alias names. */
 			if (c == TCMP_CMD && text && *text == '\\' && *(text + 1))
 				start++;
+			if (c == TCMP_WS_PREFIX)
+				start += 2;
 
 			rl_begin_undo_group();
 			rl_delete_text(start, rl_point);
 			rl_point = start;
+
 #ifndef _NO_HIGHLIGHT
 			if (conf.highlight && !wrong_cmd) {
 				size_t k, l = 0;
