@@ -3,7 +3,7 @@
 /*
  * This file is part of CliFM
  * 
- * Copyright (C) 2016-2023, L. Abramovich <leo.clifm@outlook.com>
+ * Copyright (C) 2016-2024, L. Abramovich <leo.clifm@outlook.com>
  * All rights reserved.
 
  * CliFM is free software; you can redistribute it and/or modify
@@ -27,8 +27,8 @@
 
 __BEGIN_DECLS
 
-int  tab_complete(const int);
-void reinsert_slashes(char *);
+int  tab_complete(const int what_to_do);
+void reinsert_slashes(char *str);
 
 __END_DECLS
 
